// JUMA-TRX2 EEPROM save structures
// Juha Niinikoski, OH2NLT 28.01.2007

// EEPROM structure separated to own file 28.01.2007

// User power on values, EEPROM storage
// Squelch variable added 08.04.2007 
// RF attenuator bits added 17.05.2007
// CW side tone added 01.02.2008
// Number of VFOs increased 08.03.2008
// Calibration values for id_mult, batt_mult, and s_mtr_cal changed from long to integer. A.Ryan 5B4AIY - 21/OCT/2012
// Removed rev_pwr_mult from calibration settings. Never used. A.Ryan 5B4AIY - 23/OCT/2012
// defval - 162 16-bit words, comprising 41 32-bit long integers, plus 80 16-bit integers.
// calval - 23 16-bit words, comprising 1 32-bit long integer, plus 15 16-bit integers, plus 12 8-bit characters.

struct defval
	{
	long vfo[40];					// VFO, 0 = A, 1 = B, 2 = Reserved/C, 3 = D etc... Reserved is used for Split Mode, C is Multi-Memory Mode
	int cw_shift;					// TX CW shift
	int cw_sidetone;				// CW side tone pitch (tone generator units)
	int step_idx;					// Tuning step index - 5B4AIY
	int vfo_sel;					// VFO select, A = 0, B = 1, Split = 2 or C. (Depends upon max_vfo. If max_vfo = 2, Split Mode)
	int max_vfo;					// Number of memory locations in use (2 = A+B/Split Mode, 3 - 26 = Multi-Memory Mode)
	int mode[40];					// Operating mode, 0 = LSB, 1 = USB, 2 = CW, 3 = CWR, Tune = 4 - 5B4AIY
	int rit_on;						// RIT Flag, 0 = OFF, 1 = ON
	int agc_speed;					// AGC speed, 1 = Fast 0 = Slow
	int nb;							// Noise blanker (Not Used)
	int proc_on_off;				// Speech processor ON / OFF, 1 = On, 0 = Off
	int filter;						// Filter select, 0 = Narrow, 1 = Wide, 2 = Transmit
	int contrast;					// LCD display contrast, pwm4
	int back_light;					// LCD back light, pwm3
	int back_light_timer;			// LCD back light off timer, 0 = Not In Use 
	int scaf_filters[4];			// SCAF filter clock dividers, [0] = Narrow, [1] = Wide, [2] = TX, [3] = Spare
	int keyer;						// Keyer operating mode - 5B4AIY
	int serial_mode;				// Serial interface operating mode - 5B4AIY
	int af_input;					// MIC input level, 0 = LINE, 1 = MIC
	int sq;							// Squelch, 1 = In Use
	int br;							// Baud rate index
	int S_Meter_Type;				// Type of S-Meter to display. 0 = Graphic 1 = Numeric - 5B4AIY
	int OOB_Check;					// Out-Of-Band Check flag. 0 = Disable 1 = Enable - 5B4AIY
	int Auto_SB;					// Auto Sideband Select flag. 0 = Disable, 1 = Enable - 5B4AIY
	int Freq_Display;				// Display Frequency choice, 0 = Old, 1 = New 2 = Fixed 1Hz, 3 Fixed 10Hz - 5B4AIY
	int	Band_SW;					// Rapid Band Switch Mode 0 = Default, 1 = User Frequencies (Unlocked) 2 = User Frequencies (Locked) - 5B4AIY
	int RIT_Include;				// Include the RIT shift in the frequency display, 0 = NO, 1 = YES - 5B4AIY
	int Tune_Attenuation;			// Attenuator used in TUNE mode, 0 - 3 dB - 5B4AIY
	int VFO_Adjust;					// Adjust VFO frequency to nearest step boundary. 0 = OFF, 1 = 10Hz, 2 = 10/100Hz, 3 = All - 5B4AIY
	int Hold_Time;					// Used in numeric S-Meter to reduce jitter - 5B4AIY
	unsigned int CW_Speed;			// Default keyer speed. Bit 15 = Locked Flag. Default Value, Locked, 20wpm - 5B4AIY
	unsigned long VFO_Lock;			// VFO Lock Status. Bit = 0, Unlocked, Bit = 1 Locked - 5B4AIY
	int CW_CWR_Swap;				// 0 = Original operation, 1 = PWR button swaps CWR back to CW - 5B4AIY
	int Display_Type;				// Graphic Scale Type 0 = Original 1 = Large Markers 2 = Small Markers - 5B4AIY
	int	CW_Release;					// CW Release timer. Min = 250mS, Max = 1,500mS - 5B4AIY
	int	Power_Meter;				// RF O/P Power display, 0 = Watts, 1 = dBm - 5B4AIY
	unsigned int cw_annunciation;	// CW Annunciation selection and speed. Speed is set in the upper byte; mode in the lower byte - 5B4AIY
	unsigned int VFO_Equalisation;	// VFO Equalisation selection. 0 = Off, 1 = Split, 2 = Split+Simplex - 5B4AIY
	unsigned int d_csum;			// Checksum
	};

// System calibration values
struct calval
	{
	long ref_osc;					// Reference oscillator frequency
	int id_mult;					// Drain current meter calibration - 5B4AIY
	int batt_mult;					// Battery voltage meter calibration - 5B4AIY
	int s_mtr_cal;					// S-meter calibration factor - 5B4AIY
	int swr_delay;					// Re-uses the old rev_pwr_mult entry, which was never used. - 5B4AIY
	int fwd_pwr_mult;				// Forward power meter calibration - 5B4AIY
	int	beep_len;					// Tone marker length(ms) - 5B4AIY
	unsigned char rf_atn_bits[12];	// PA board RF attenuator select bits, see rf_filt_attn[] for details. Locations 12 and 13 spare - 5B4AIY
	int splash;						// Flag to display splash screen on power-up. - 5B4AIY
	int button_mode;				// Long Push Button Mode. 0 = Hold, 1 = Latch - 5B4AIY
	int swr_trip;					// High SWR trip point (Nominally 300 = 3.00) - 5B4AIY
	int alarm_flags;				// Bit 0 = Over-current, Bit 1 = Over-voltage, Bit 2 = Under-voltage, 0 = disabled - 5B4AIY
	int overvoltage_trip;			// Over-voltage trip (Nominally 2765 = 14.5V) - 5B4AIY
	int overcurrent_trip;			// Over-current trip (Nominally 2455 = 2.5A) - 5B4AIY
	int undervoltage_trip;			// Under-voltage trip (Nominally 2095 = 11.0V) - 5B4AIY
	int Band_Limits;				// Frequency limits, 0 = IARU Region 1, 1 = USA (Extra Class), 2 = USA (General Class) - 5B4AIY
	unsigned int c_csum;			// Checksum
	};

