/*
 JUMA-TRX2 Receiver Controller & DDS
 Juha Niinikoski, OH2NLT 22.11.2006

 MPLAB C30 version 2.05.6
 MCU dsPIC30F6014A

 Project started 22.11.2006
 User interface & calibration displays 01.12.2006
 Split & RIT logic 02.12.2006
 Main board 74HC595 SPI interface added 03.11.2006
 Keyer code added 08.12.2006
 Keyer operating mode select added 10.12.2006
 Power off button timer & factory default load 12.12.2006
 Button tones 13.12.2006
 SWR calculations 19.12.2006
 All sorts of user interface modifications, EEPROM checksum 26.12.2006
 Service mode separated to different module 27.12.2006
 SWR alarm, fwd voltage bar graph, tune start beep 30.12.2006
 Yaesu CAT emulator, first test version 12.01.2007
 VFO lock function added 18.01.2007
 Iambic mode B added to keyer code 27.01.2007
 EEPROM structure separated to own trx2_eeprom.h file 28.01.2007
 ISD17240 Voice memory code tests 11.03.2007
 External keyboard module added 12.03.2007
 ISD17240 Voice memory installed flag, more memory banks & user interface changes 17.03.2007
 ISD17240 Voice memory Rev.B board definition changes 21.03.2007
 S-meter scale improvement. S9 marker and end stopper added 03.04.2007
 Squelch code 08.04.2007
 All-Band PA filter select logic & user interface tones improved 15.04.2007
 PA RF attenuator test 23.04.2007
 PA RF filter & attenuator selector code 17.05.2007
 MODE stored separately for both VFO's 17.05.2005
 PA RF attenuator (Power level) bits to EEPROM save 02.06.2007
 Different upper frequency limit for normal and service mode 03.06.2007
 MODE and VFO changes disabled when TX on, when Split selected Keyer and Tune operation corrected 06.06.2007
 Version changed to 1.00, first release package 19.06.2007
 RS232 test loop added 09.07.2007, v1.01 

 Interrupt driven RS232 RX driver & baud rate select 22.01.2008, test version
 Some Service mode displays changed
 Mute test function corrected
 Yaesu CAT module freq calculations fine tuned 23.01.2008, test version 1.02 
 CW TX side tone SCAF setup added 25.01.2008
 Yaesu CAT set frequency VFO select corrected, CW shift adjustment added 31.01.2008
 Compiler bug work around in uart.c module 01.02.2008
 CW pitch adjustment 300 - 1100Hz added 01.02.2008
 AUX UART2 interface & AUX Voice memory control added, leave UART1 for other use 02.02.2008 
 PWR display peak hold logic 07.02.2008
 RIT display changed 08.02.2008
 Yaesu CAT set operating mode command VFO indexing corrected 09.02.2008, v1.02
 DDS test code 06.03.2008
 Number of VFO memory banks increased 08.03.2008, v1.03 test version
 Startup changed to show version instead of date 11.03.2008, v1.03
 Bug fixes, Split mode CW keyer problem, CW left on if VFO pressed while keying  03.07.2008, v1.04 Test
 LCD back light timer code added 03.07.2008 v1.04
 TRX2 command protocol 14.08.2008 v1.05
 More TRX2 protocol commands 17.08.2008 v1.05
 UART1 init sequence changed to be compatible with later silicon 30.10.2008 v1.05
 In serial test.c bar graph test 'B' changed to 'b', better PA100 protocol compatibility  15.11.2008 v1.05
 TRX2 protocol bug fixed, own timer (pa100_tx_tmr) added 15.11.2008 v1.05
 TRX2 protocol capture start condition added 16.11.2008 v1.05
 UART module data type cast corrections 18.11.2008 v1.05
 Yaesu CAT Read TX status command 0xF7 bug corrected, squelch bit added to 0xE7 response 28.01.2009 v1.06 test
 Undocumented feature discovered from Yaesu 897 CAT protocol
 0xE7 response is 0xFF when TX and 0xF7 response is 0xFF when RX 29.01.2009 v1.06 test
 Dirty patch for undocumented Yaesu commands 00 xx 00 00 BB to get HRD working 30.01.2009 v1.06 test
 TX / PTT control added to JUMA-TRX2 protocol 17.04.2009 v1.06 test
 K250 & K600 filter switch points changed 18.04.2009 v1.06 test
 Split mode VFO copy strategy changed. Visible VFO is copied to another 18.04.2009 v1.06 test
 Memory can be selected keeping VFO button down and turning encoder knob 19.04.2009 v1.06
 DEFAULT_TX filter changed to 2,6kHz (2586Hz), 19.04.2009 v1.06

 ---------------------------------------- 5B4AIY Modifications ----------------------------------------

 Changed Brown-Out voltage from 2.0V to 2.7V. In v3.30b of the compiler, the file p30F6014A.inc now reserves
 the 2 volt value. - 5B4AIY
 Added Rapid band Switch feature - 5B4AIY
 Added additional memories for User Amateur Band frequency storage - 5B4AIY
 Added Help feature to serial test and fixed two bugs - 5B4AIY
 Added out-of-band frequency detection and transmitter inhibit - 5B4AIY
 Added auto sideband select - 5B4AIY
 Added an additional tuning rate of 1Hz, as well as user selectable frequency display format - 5B4AIY
 Changed DDS synthesiser calculation to be in decimal - 5B4AIY
 Added out-of-band annunciator to main display - 5B4AIY
 Greatly improved the accuracy of the measurement system - 5B4AIY
 Added user selectable alarms - 5B4AIY
 Greatly optimised the code - 5B4AIY
 Added VFO frequency rounding - 5B4AIY
 Added notification of mode/filter changes to all display screens - 5B4AIY
 Added Auto-Equalise to Serial Test Suite - 5B4AIY
 Added VFO copy feature - 5B4AIY
 Added extended commands to TRX-2 protocol so that the TRX-Manager program could work with this transceiver using
 a native command set rather than an emulation. - 5B4AIY
 Added CWR mode and completely changed how the CW modes work. - 5B4AIY
 Added prompted exit to menus and power down - 5B4AIY
 Corrected a minor error in the out-of-band detection. The flag was set when the carrier was actually on the band
 edge rather than outside the band. Thus, for example, on 20m 14.000000MHz was considered out of band rather than
 13.999999MHz. Similarly, 14.350000MHz was considered out of band rather than 14.350001MHz. This has now been fixed
 by a trivial change in the check_freq() function. - 5B4AIY A. Ryan 30/MAY/2012
 Collected all the User Configuration selections and System Setup code into individual small functions, and then assembled
 into two arrays. The configuration select code greatly simplified as a result. - 5B4AIY
 Modified out-of-band annunciator to blink instead of remain steady - 5B4AIY
 Modified Band Limits to account for USA General Class as well as Extra Class - 5B4AIY
 Relocated Band Limits adjustment from User Configuration to System Setup, this will cause a checksum error on
 initial start-up as the mapping will have changed. - 5B4AIY
 Fixed minor bug. I had not appreciated that US amateurs are allowed to use all of the 160m segment down to 1800kHz - 5B4AIY
 Fixed trivial bug in Serial Test Suite 'b' command. This test confirms that the character generator RAM in the LCD has been
 loaded with the correct data for the bar graphs, as well as displaying the complete character set. It uses sprintf() to
 format a string which is placed in the display buffer. The function lcd_putst() is then passed the address of the buffer
 and it will display the string. If the character to display is a NULL byte, then since sprintf() merely copies the
 character to the buffer, when lcd_putst() attempts to display the buffer contents it discovers this NULL byte which it
 correctly interprets as the string terminator. This has now been fixed, and for a NULL byte the character is changed to
 a space, since the NULL byte is a non-displayable character anyway. Adrian Ryan - 5B4AIY 23/JUN/12
 Finally fixed out-of-band bug. See comments at line 4667. Adrian Ryan - 5B4AIY - 24/JUN/12
 Modified the Yaesu CAT code. Saved 594 bytes by optimising the 03 command substituting bin2bcd() and bcd2bin() functions
 instead of the in-line code. Adrian Ryan - 5B4AIY - 25/JUN/12
 Also inserted a 'special' command that can be used with the LDG-817 Auto-Tuner. It is commented-out in this version.
 Tidied up the code in dm_0() and dm_3() so that the space or stopper bar character is now directly displayed. A.Ryan - 5B4AIY - 05/JUL/12
 Tidied up some code in lcd-trx2.c A.Ryan - 5B4AIY - 06/JUL/12
 Removed an unnecessary test in the disp_rit() function in lcd-trx2.c A.Ryan - 5B4AIY - 08/JUL/12
 Note: lcd_spc() is a macro definition in juma_trx2.h A. Ryan 31/JUL/2012
 Added command to serial_Y_cat.c to permit operation with LDG Z-817 auto-tuner. A.Ryan - 5B4AIY - 28/AUG/2012
 Added error messages to trap handler. A. Ryan - 5B4AIY - 12/SEP/12
 Cleaned up some code by making variables static instead of global. A.Ryan - 5B4AIY - 25/SEP/2012
 Revised S-Meter scale calculation to simplify it and remove excessive precision.
 The previous S-Meter calibration constant can be converted to the new value as follows:
 New Calibration Factor = 65536 / Old Factor. For the original transceiver using the ST112 transistor, the
 default calibration factor was 1920, its new value would be: 65536/1920 = 34.
 With the new transistor, my calibration factor was 3900, thus my new factor is 65536/3900 = 17.
 Changed SWR alarm behaviour. If in the TUNE mode, then High SWR alarm is delayed by an adjustable time to allow
 you to tune an antenna manually. The time limits are from 1 to 10 seconds, or disabled. If the delay is disabled,
 then the actual delay reverts to the normal delay time of 500mS.
 Changed SWR display. The pseudo-analog graphic meter now displays SWR as a fraction of the trip limit.
 Added limits displays. The pseudo-analog now displays voltage as a suppressed-zero voltmeter, the lower scale
 limit being the under-voltage trip, full-scale is the over-voltage trip. The ammeter is displayed as a fraction
 of your over-current trip. These limits displays are only visible in the transmit mode, in receive the S-Meter
 is displayed. The RF power indication now shows true power, and the scale is 10W maximum although the digital
 display will still indicate powers in excess of this.
 The mapping of the EEPROM has been rationalised. The calibration settings for id_mult, batt_mult, and s_mtr_cal were
 changed from long to int. A.Ryan - 5B4AIY - 21/OCT/2012
 Optimised and rationalised the adjustments. The encoder sensitivity is now set to normal, medium or slow depending
 upon the parameter being adjusted. For example, the backlighting and contrast adjustments were far too fast, and
 have now been slowed down. The adjustments for other parameters are similarly set to more reasonable values
 especially the On/Off adjustments or others where the actual values are either zero or one.
 Fixed a minor low-level bug. In the Calibration Menu, the mode was accidentally set to CWR, it has now been
 corrected to the TUNE mode.
 Fixed a minor bug. In the Calibration Menu, the default values would only be saved if an explicit save operation
 was performed rather than being restored and save automatically. This is now fixed. If there is a checksum
 both the calibration and the configuration values are restored and saved. A.Ryan - 5B4AIY - 26/OCT/2012
 Fixed minor bug. In the Serial Test Suite the value of the long SWR delay time was not correctly displayed.
 Optimised the serial_test() function by collecting some common code into a function. A.Ryan - 5B4AIY - 11/NOV/2012
 Added fast attack/slow release peak power display to complement the same display in the linear amplifier. A.Ryan - 5B4AIY - 20/NOV/2012
 Build 12. Fixed minor bug in default settings. The Long SWR Delay was accidentally set to a huge value.
 This has now been fixed, and the default value of 5 seconds is used.
 Slight re-arrangement of order of User Configuration settings. The S-Meter Hold Time setting now follows the
 S-Meter Selection setting. A.Ryan 24/NOV/2012

 V1.09a
 Build 1 Changed CW Release Time from 7 * CW Period to an adjustable time from 200mS to 1,500mS for Laurent Labourie.
 Note: This only applies to the CW Straight mode! A.Ryan - 5B4AIY - 26/NOV/2012
 Build 2
 Replaced a number of single-line functions with macros. (See juma-trx2.h) A.Ryan - 5B4AIY - 30/NOV/2012
 Modified the User Configuration prompts to be rather more attractive.
 Altered the display contrast to have a minimum value of 50.
 Moved function display_out_of_band() to lcd-trx2.c
 Set the minimum CW Release time to 200mS. A.Ryan - 5B4AIY - 30/NOV/2012
 Build 3
 The CW Release Delay page is now only visible if the keyer mode is set to STRAIGHT. A.Ryan - 5B4AIY - 2/DEC/2012
 Build 4
 Moved the CW Release Delay menu item so that it follows the Keyer Mode selection. A.Ryan - 5B4AIY - 3/DEC/2012

 V1.09b
 Build 1
 Fixed very minor display bug. When using the multi-memory VFO option, the lock and tuning rate status was lost
 when using the fast memory select with the VFO knob, and was restored when the VFO button was released.
 The lock status of each VFO and the current tuning rate are now continuously displayed.
 Fixed subtle bug in the Extended TRX-2 Protocol. If the Extended Mode command was used, it would respond the
 first time, but then ignore subsequent commands. A.Ryan - 5B4AIY - 05/JAN/2013
 Build 2
 Removed tuning rate from multi-memory status display. The tuning rate does not change, and as the status
 is already written to the display memory, there is no need to constantly over-write it. This saved 18 bytes of
 code that was simply address calculation and character retrieval. A.Ryan - 5B4AIY - 06/JAN/2013
 Build 3
 Simplified the default restoral in the service menu. A long push is no longer required, instead
 a normal prompted exit is given. This also allowed for a simplification of the default restoral via the MODE
 button when powering up. The save_settings() function was modified to add another button test to the PWR button
 test to permit the removal of a number of lines of redundant code.
 Added a global variable - RS_232_Mode - a pointer to a function taking void and returning void, whose value
 is set once during initialisation or if the User Configuration variable: eeprom.defval.serial_mode is changed.
 This avoids a needless loop invariant address calculation in the main loop.
 Removed redundant test when checking the keyer mode to skip a display page.
 Moved some system status flags initialisations to the declaration section.
 Moved the setting of split_flag from lcd_0() to the start of the main loop, this permitted a great simplification
 of the Split Mode logic, especially the setting of the cw_active flag. A.Ryan - 5B4AIY - 14/JAN/2013
 Build 4
 The display LCD code has been moved to the top of the main loop. This prevents a spurious, very very brief
 display of 'VFOC' when changing from VFO-B to the Split mode.
 The DDS load and SPI bus activate code moved to the end of the main loop so that it executes after all the
 frequency and mode changes have been made. A.Ryan - 5B4AIY - 15/JAN/2013
 Build 5
 Relocated all the prompts from service.c, isd1700.c, and juma-trx2.c to the data segment. The prompts in
 serial_test.c are too numerous to bother with. A.Ryan 16/JAN/2013
 Build 6
 Put all the prompts from service.c, isd1700.c, and juma-trx2.c back where they were. The relocation had no
 effect on the cycle time of the main loop. Corrected declaration of pointer: *user_band_prompt so that it
 points to const chars, thus avoiding a compiler warning. Corrected declaration of putst2() argument (uart2.c)
 so that it points to const chars avoiding the same compiler warning. Improved the construction of
 putst2() so that it is more concise. A.Ryan - 5B4AIY - 17/JAN/2013
 Build 7
 Reduced the length of lcdpbuff[] from 40 bytes to 20 bytes. This buffer is exclusively used by sprintf()
 to format LCD display strings. All the uses utilise defined length strings, and thus there is no possibility
 of over-running the buffer, even 20 bytes gives us a safety margin.
 Added const qualifier to standard format messages in serial_trx2.c 
 Removed function: set_cgram() from lcd-trx2.c - never referenced. Optimised set_ch_bits()
 Fixed minor bug in Serial Test. The Bar Graph test would not display an end-of-bar symbol if the
 S-Meter was set to numeric. This is now fixed. A.Ryan - 5B4AIY - 23/JAN/2013
 Build 8
 Optimised auto_equalise() removing some redundant code and a function only referenced once.
 Minor optimisation of adjust_rf_attenuator() Removed find_rf_filt_idx() function and incorporated it
 as in-line code in send_packet_to_74hc595(). It was only ever called by this function.
 Collected literal text strings in isd1700.c to constant character arrays.
 Removed init_spi2() in isd1700.c, and made it in-line code. It was only ever called once.
 Collected literal text strings in serial_ext_kb.c to constant character arrays.
 Collected literal text strings in serial_trx2.c to constant character arrays.
 Eliminated send_cat() in serial_Y_cat.c, and made it in-line code. Only called once.
 Optimised ms_delay() in tmr5delay.c by more concise construction.
 Modified RIT frequency format descriptor in Kenwood CAT module to remove redundant + correction. A.Ryan - 5B4AIY - 24/JAN/2013
 Build 9
 Revised the Kenwood CAT logic. Removed a lot of redundant code and simplified the split logic.
 Introduced the select_state() function to set the state of the transceiver from the commanded transmit
 and receive VFO selection. A.Ryan - 5B4AIY - 26/JAN/2013

 v1.09c
 Build 1
 Extended the command set of the Yaesu, Kenwood, and TRX-2 serial protocols.
 The Yaesu emulation now contains the F8 Extended Display, E0 Tuning Rate adjustment, and the PKT mode
 in the mode command which turns the TUNE mode on. (See serial_Y_cat.c for details)
 The Kenwood emulation now contains the XD Extended Display, and has also been extensively re-written.
 The tx_buffer[] has been removed, along with the clr_tx_buffer() function, no longer required,
 The TRX-2 protocol is enhanced with the Y Extended Display. This module has been significantly
 optimised. Removed the set_FREQ() from the serial_trx2.c and made it in-line. Only called once.
 Re-wrote the check_freq() function to eliminate the switch-case and perform the General Class band
 checks in a single go. This entailed adding some dummy values to the lower_segment_limit[] and
 upper_segment_limit[] arrays, but saved a significant amount of code. A.Ryan - 5B4AIY - 27/JAN/2013
 Build 2
 Fixed inoperative VFO lock bug in Yaesu CAT module. Fixed bug in Auto-Inform. If the latency was set
 to something other than 1, then the VFO mode would not automatically be changed to A+B (Split).
 Removed filter_nop_char() in serial_trx2.c and replaced with simplified in-line code. Only called once.
 Removed several calls to clr_buffer() in serial_trx2() and used single call at end of composite switch-case.
 Simplified the get_num() in serial_trx2.c. Since only a single ASCII character is ever being converted,
 it is simpler to calculate the number by subtracting the character '0' from the byte. The limit has been
 modified to eliminate the unnecessary +1 addition in the limit check by simply increasing the
 value in each of the called instances. Fixed minor bug in frequency reporting, the '=' symbol was missing.
 A.Ryan - 5B4AIY - 30/JAN/2013
 Build 3
 Fixed minor bug. During the boot sequence, the Voice Memory message is sent out before the serial port has
 been set to its final speed. This message has now been removed from the isd1700.c module to the juma-trx2.c
 module, and the boot messages section considerably simplified and improved. A.Ryan - 5B4AIY - 6/FEB/2013
 Build 4
 Modified the serial_Y_cat.c. The clear_cat() now returns the command index as zero. The initialisation
 code has been considerably simplified. Unnecessary code to clear the buffer removed. A.Ryan - 5B4AIY - 10/FEB/2013
 Build 5
 Initialised variable: low_voltage_warning to zero, and removed unnecessary code.
 Removed variable: ultemp, only ever used once, replaced with in-line code. A.Ryan - 5B4AIY - 16/FEB/2013
 Build 6
 Added a fully decoded SPI bus data display to the Serial Test Suite to replace the existing display. 19/FEB/2013
 Build 7
 Removed redundant double variable v in service.c and modified W_Fmt message in lcd-trx2.c
 Re-organised timers_pwm.c. Set maximum backlight to 1000 in juma-trx2.h. Set initial backlight
 and contrast levels to their default values in the initialisation routine. A.Ryan - 5B4AIY - 04/MAR/2013
 Build 8
 Fixed minor bug. When using the backlight timer option, the backlighting was not turned on if an alarm occurred.
 This has now been fixed. A.Ryan - 5B4AIY - 22/MAY/2013

 v1.10a
 Build 1
 Modified the Squelch. In the previous firmware if the backlight timer and squelch features were used, if a signal
 exceeded the squelch threshold the backlight was not turned on. There are now two modes. Squelch-A operates as before,
 Squelch-B turns the backlight on if the received signal is above the squelch threshold. A.Ryan - 5B4AIY - 25/MAY/2013
 Build 2
 The backlight timer was previously adjustable in 1 second increments. I seriously doubt that anyone ever used an
 interval of less than 5 seconds. The timer now increments in 5-second intervals. A.Ryan - 5B4AIY - 27/MAY/2013

 The accuracy of the current measurement could be improved by incorporating the idle and backlighting currents with
 the measured PA current. The principle is based upon measurements made of the currents drawn by the transceiver
 in the receive and transmit states, with the backlighting on and off and at various settings, as well as on
 the various amateur bands. In the receive state, the lowest current occurs on 160m and with the backlighting off.
 The currents are essentially constant over the 11.0V - 15.0V input voltage range, and comprise three components:

 1. The fixed idle current, measured as 380mA
 2. The variable backlighting current, 10mA at a backlighting setting of 50 (minimum) up to 70mA at 1000 (maximum)
 3. The increase in current as the various amateur bands are engaged:
	Band	Current
	160m	0
	80m		10mA
	40m		20mA
	30m		25mA
	20m		35mA
	17m		40mA
	15m		50mA
	12m		55mA
	10m		60mA

 Since there is already a variable, band_in_use that registers the current band, then by declaring an array of values
 these can be indexed by band_in_use to arrive at the band current factor:
 
 const char band_current[] = { 0, 0, 10, 20, 25, 35, 40, 50, 55, 60 };
 Ib = band_current[band_in_use]
 
 Although the current increases as the audio output increases, as there is no connection to the microprocessor there
 is no real way that this can be accommodated.
 
 In the transmit mode, the current comprises the previous idle current and band current, but in addition, the bias
 current of the driver and amplifier stages which vary with supply voltage. With the backlighting set to minimum the
 measured transmit currents were:
 
	11.0V 620mA
	14.7V 760mA

 Since the transmit driver stage and amplifier current is actually measured, it is only necessary to add the previous
 idle current and band current to the measured driver and amplifier current to arrive at the total current.

 Thus, in receive, if the idle current is Ic, and the backlighting current Il, and the band factor Ib, then
 the displayed current is: Ic + Il + Ib
 If the backlighting is off, the Il term is set to zero.
 Ib is derived from either an array entry or from a calculation related to the VFO frequency.
 The backlighting current is derived from a simple ratiometric calculation based on the backlighting intensity setting.
  
	Il = 7 + 60 * Bl / 950 mA
  
 Thus, the display current is:
  
	Id	= 0.38 + Il + Ib
 
 and this current is also added to the current measured from the driver/amplifier board in transmit.
 Build 3
 Added display_screen() function to optimise displays, and changed format descriptor for s9_msg to eliminate
 unnecessary spaces.

 1.10b
 Build 1
 Optimised the power down sequence. The counted down sequence has been removed, as it was completely redundant.
 The new sequence has a choice of Prompted power down, where you can choose to save the current configuration,
 or an immediate power off without saving anything, or an immediate power off and where the configuration is
 always saved. A.Ryan - 5B4AIY - 03/JUN/2013
 Build 2
 Fixed minor bug. If the "Save State" power-off sequence was chosen, the saved message was not sent to the serial
 port if the TEST mode had been selected. A.Ryan - 5B4AIY - 04/JUN/2013

 1.10c
 Build 1
 Fixes bug in Service Menu. The measurement for the drain current was not being made. Also altered the drain current
 display to have a peak reading long hold ammeter rather than a running average. In the Service Mode, the peak hold
 is inhibited, and an instantaneous display is used. A.Ryan - 5B4AIY - 22/JUN/2013
 Build 2
 Removed duplicate code and used the get_pwr() function instead. Set the TUNE attenuation to -1dB in the auto-equalise
 mode to get a more accurate representation of the PA gain variation. Modified the display_s_meter() function. It
 now takes an integer parameter describing the S-Meter type, 0 = Graphic, 1 = Numeric. A.Ryan - 5B4AIY - 23/JUN/2013

 1.10d
 Build 1
 Every other amateur transceiver that I know although permitting split frequency operation, does not permit the frequencies
 to be on different bands. This version of the firmware fixes this anomaly, so that when setting the transceiver
 to the 'A/B + Split' mode if the Rapid Bandswitch facility is used then the frequencies are checked and if the
 A and B VFOs are not set to the same amateur band, then if VFO-A is the active VFO, VFO-B is forced to the same frequency
 and mode. Similarly if VFO-B is the active VFO, then VFO-A is forced to the same frequency/mode. If someone actually
 has a use for cross-band operation whereby you use VFO-B as the transmit VFO, and VFO-A as the receive, but they
 are tuned to different bands, then this is still possible if you copy a frequency from one of the VFO memories
 into the active VFO. A.Ryan - 5B4AIY - 17/JUL/2013 - Happy Birthday, Emma!
 Build 2
 Replaced select_nearest_band() with check_freq() when checking split mode Rapid Band-Switch frequency assignments.
 This eliminates the possibility of a non-adjustment when the inactive VFO frequency is only 'near' the amateur band,
 rather than being in-band. A.Ryan - 5B4AIY - 18/JUL/2013
 Build 3
 Cleaned up some code in timers_pwm.c associated with the auto-keyer by adding the function _cw_active(int). A.Ryan - 5B4AIY - 04/AUG/2013

 1.10e
 Build 1
 Added Vibroplex mode to the CW feature set. In this mode the keyer will produce automatic dots, but only manual dashes,
 emulating the famous Vibroplex 'bug' key. This mode is primarily designed for a single paddle key. If a dual-paddle key
 is connected, then squeezing both paddles causes the symbol to stop. A.Ryan - 5B4AIY - 05/AUG/2013
 Build 2
 Optimised the keyer logic by only reading the state of the DOT/DASH I/O ports once and assigning the values to dot and
 dash local variables. A.Ryan - 5B4AIY - 05/AUG/2013
 Build 3
 Optimised the play dot code in the Vibroplex keyer logic to remove a redundant test and use the _play_dot() function
 instead. A.Ryan - 5B4AIY - 07/AUG/2013
 Build 4
 Removed the unnecessary duplication of the cancel key for the prompted exit. Only the PWR button now aborts the save
 operation, the FILTER button has been eliminated. A.Ryan - 5B4AIY - 09/AUG/2013
 Build 5
 Modified the RS-232 mode selection logic so that the Voice Memory is only selectable if the optional module is
 actually present. A.Ryan 5B4AIY - 17/AUG/2013

 1.10f
 Build 1
 optimised the Voice Memory Command functions. In the previous versions, both UART1 and UART2 when used as the VM
 control ports had essentially the same command parsers. Since there should never be a situation where both UARTs
 are used to control the VM, this duplication of code is unnecessary, and wasteful. The command parser was implemented
 as the _VM_Command() function, and utilised by both the serial_ext_kb() and uart2_ext_kb() functions. Appropriate logic
 was inserted into the uart2_ext_kb() function to ensure that it would only control the VM if UART1 was not set to the
 Voice Memory serial mode.
 Build 2
 Removed redundant "Voice Memory Not Installed" message and test. With v1.10e Build 5 if the Voice Memory is not installed,
 then this message would never print, since UART1 could never be set to the Voice Memory mode if the module was not installed.
 In the uart2_ext_kb() function, there is now a test, and if the VM is not installed, then the function simply returns.
 In addition, removed all the UART1 Voice Memory messages. These are redundant as the LCD displays what is happening,
 and if triggered by UART2 commands, would simply confuse any terminal activity associated port 1. In any case, when
 using either the external keyboard or the Windows VM Controller program, none of the messages would be displayed.
 These changes saved 879 bytes of memory. A.Ryan - 5B4AIY - 18/AUG/2013
 Build 3
 Completely removed the uart2_ext_kb.c file. After the previous changes, the only thing left in this file was the
 uart2_ext_kb() function. The code for this function has now been moved into the serial_ext_kb.c file where it more
 properly belongs. A.Ryan - 5B4AIY - 19/AUG/2013

 1.10g
 Build 1
 Optimises a lot of functions in isd1700.c Collected common code and made into functions: _disp_meter(), and
 check_stop(). Fixed display bug. Fixed bug where graphic S-meter and Power meter scales were not being fully displayed.
 When the S-Meter was set to NUMERIC, the end-of-scale bar was missing when transmitting from Voice Memory - fixed.
 Fixed bug where numeric S-meter was always displayed when recording from receiver audio. Fixed out-of-band transmit
 from the voice memory bug. A.Ryan - 5B4AIY - 20/AUG/2013
 Build 2
 More optimisation of isd1700.c Removed the display_time() function, it was only called once, incorporated the code
 in the calling function, display_meter(). Rationalised the display of the record from RX audio. Added code to the
 check_stop() function so that the serial buffers are flushed. Fixed minor bug. On switch-on, very briefly, the first time
 through the main loop, the transceiver is in the TX mode until the I/O status is correctly read. Presetting PTT_IN to the RX
 mode in the declaration section fixes this. Relocated the UART1/UART2 buffer flush to be immediately after initialising
 the UARTs. Fixed bug related to squelch settings. Added code to turn backlight on when using the Voice Memory, and checks
 so that if the mode is not LSB/USB, as well as if the frequency is out-of-band then an error message is displayed.
 A.Ryan - 5B4AIY - 22/AUG/2013
 Build 3
 More Voice Memory optimisation. Modified tx_rx_16_spi2() and tx_rx_56_spi2() so that they no longer return any data.
 In all previous versions the return data was discarded anyway. Modified tx_rx_32_spi2() so that the returned data
 is masked to 8 bits. The return data is only ever used during the device initialisation to determine the device ID
 when called by init_isd1700(). Changed operation so that when recording from receiver audio, the memory is preset to
 M0, and the command is immediately executed. Added code to display error messages if the transceiver is not in a speech
 mode (LSB/USB) or if the frequency is out-of-band if the Transmit command is issued. Removed two spurious memory address
 setup commands. A.Ryan - 5B4AIY - 23/AUG/2013
 Build 4
 Changed the elapsed time display of the Voice Memory. In a RECORD mode, the time now decrements to zero. In a REPLAY
 mode, the time increments to either the maximum memory value, or the actual message recording time, whichever occurs
 first. Memory 0 is 120 seconds, Memory 1 is 20 seconds, Memories 2 through 8 are 10 seconds, and Memory 9 is 14 seconds.
 Note that as the Voice Memory chip clock is not synchronised with the main system's clock, and further, as it is generated
 by means of a resistor, the tolerances associated with both the chip's timing logic as well as that of the resistor means
 that the memory slot times are only an approximation. A.Ryan - 5B4AIY - 11/SEP/2013
 Build 5
 Added termination prompt to UART1/2 cross-copy test in serial_test.c and collected the common code for the PA Filter
 attenuator test into a single module. A.Ryan - 5B4AIY - 14/SEP/2013
 Build 6
 Added array slot_time[] in isd1700.c and used this to calculate the slot times to display.
 This saved 39 bytes. A.Ryan - 5B4AIY - 25/SEP/2013
 Build 7
 Modified check_freq() so that only a single parameter is passed, and the second frequency parameter is derived in the function.
 This was done because the original version passed two frequency parameters, the upper and lower frequency, but they were always
 identical, so it made more sense to only pass one as this reduced the amount of complex address calculation. This modification
 saved 15 bytes. A.Ryan - 5B4AIY - 30/OCT/2013
 Build 8
 Modified get_one_zero(), get_value(), and set_decade_value() so that they are now passed a pointer to the values they modify
 rather than the value itself. This avoids a lot of duplicate address re-calculation for the configuration and calibration memory
 values, and saved 60 bytes. A.Ryan - 5B4AIY - 20/NOV/2013
 Build 9
 Modified Service Mode. The save settings logic was somewhat convoluted. Now, the FAST/VFAST switch is tested first, then the
 check for the maximum or normal page is made. This eliminated some redundant logic tests and saved 82 bytes. A.Ryan - 5B4AIY - 3/DEC/2013
 
 1.10h
 Build 1
 Added Fast Page Switch feature to Service & Calibration mode. Fixed minor bug. The service mode print-out if the serial
 mode was TEST was not occurring - fixed. A.Ryan - 5B4AIY - 03/DEC/2013
 Build 2
 Modified User Configuration and Service beeps so that an acknowledgement beep is always given in these modes, even when the
 beep length is set to zero. A.Ryan - 5B4AIY - 04/DEC/2013
 Build 3
 No code changes. Discovered that the contents of file: lcd-trx2.h was duplicated in file: lcd-trx2.c, as well as being used
 in other files. Removed spurious re-definitions in lcd-trx2.c and included the header file instead. A.Ryan - 5B4AIY - 24/DEC/2013
 Build 4
 Modified the RIT_fmt[] descriptor to include the leading letter 'R', and also the disp_rit() function. A.Ryan - 5B4AIY - 24/DEC/2013
 Build 5
 Removed header file lcd-trx2.h and incorporated its contents into juma-trx2.h. A.Ryan - 5B4AIY - 27/DEC/2013
 Build 6
 Removed set_cur_lcd() function, and replaced it with lcd_cmd(). Changed all the cursor positioning commands
 so that the intrinsic OR operation was already implemented. Optimised initlcd(). Changed old_data to be a
 static unsigned int in exchg_data_spi1() rather than static local. Removed local variable spi_rx_data_available
 never used. A.Ryan - 5B4AIY - 03/JAN/2014
 Build 7
 Optimised the SPI Interrupt routine. Added explanation of how the SPI bus operates in spi1.c. A.Ryan - 5B4AIY - 09/JAN/2014
 Build 8
 There is a redundant test in SPI interrupt. After a considerable amount of testing, it was obvious that the SPI1OV
 flag is always set after sending data to the SPI bus. Therefore, there is no need to test this flag, the dummy
 read operation is always required to clear the flag. However, the test is retained to preserve the latch pulse width.
 Modified the disp_meter() function for a more efficient form. This saved 123 bytes! A.Ryan - 5B4AIY - 10/JAN/2014
 Build 9
 Removed SWITCH-CASE construct for rapid bandswitch select and replaced with simpler IF construct. Removed a number
 of single-use temporary variables, and replaced with a common temporary variable. A.Ryan - 5B4AIY - 16/JAN/2014
 Build 10
 Added a few more manifest constants to juma-trx2.h Slightly changed the logic by which the TX Filter is recognised when
 exiting the User Configuration menu. In previous versions the filter was recognised by being > 2, now it is explicitly
 checked for equality to the constant TX_FILTER. A.Ryan - 5B4AIY - 23/JAN/2014

 1.10i
 Build 1
 Modified the Rapid Bandswitch feature to display its current mode. A.Ryan - 5B4AIY - 26/JAN/2014
 Build 2
 Modified set_range() in service.c so that order of minimum and maximum parameter values corresponds with those in
 get_value() for the sake of consistency. Modified SWR display to show 'SWR--.-' in receive and when no valid
 SWR measurement available. Modified max_min() so that it now takes a pointer to the value, and directly adjusts it
 via this pointer, returning void. A.Ryan - 5B4AIY - 28/JAN/2014
 Build 3
 Added the feature to save the current display page when saving the state of the transceiver. This makes use of the
 spare EEPROM location eeprom.defval.mode[39] which is an integer object, currently unused. A.Ryan - 5B4AIY - 31/JAN/2014
 Build 4
 Modified the previous feature to enable the user to select either the last selected page, or to have a selectable
 fixed default page displayed on start-up. A.Ryan - 5B4AIY - 01/FEB/2014
 Build 5
 Eliminated the complex SWITCH-CASE construct in display_settings() in favour of an indexed array. Added feature
 to allow selectable start-up display page or the last displayed page. A.Ryan - 5B4AIY - 2/FEB/2014
 Build 6
 Modified the prompts for the Start-Up Display Page feature, and added additional information to the Serial Test
 to display the actual last page that has been saved. Removed the No/Yes prompt message, only used by the
 'Include RIT' setup. Used the existing Off/On message instead. A.Ryan - 5B4AIY - 4/FEB/2014
 Build 7
 Re-organised the order of the configuration pages so that the Power Off Mode and Display Page Select are next to each
 other. This is because the Display Page Select is now determined by the Power Off Mode. If the mode is IMMEDIATE then
 as no state save occurs, it makes no sense to allow the display page to be set to the Last Page. Thus the new logic
 checks the value of the Power Down mode, and if it is set to IMMEDIATE and the Display Page is set to Last Page, then
 the Display Page is reset to the default, MODE B/W, and the maximum allowed value for the display page is then
 PA CURRENT.
 Build 8
 Minor adjustment of prompt messages, and a major rationalisation of format descriptors for the User Configuration
 display pages.
 
 1.10j
 Build 1
 Finally fixed the spurious previous/next page select Fast Page Switch bug in the Calibration and
 User Configuration menus. A.Ryan - 5B4AIY - 08/FEB/2014
 Build 2
 Added SCAF_CLK definition to juma-trx2.h Since this constant is derived from the FCY constant, which is defined as an
 unsigned long integer, and the SCAF clock variable is a signed long integer, a type conversion occurs, which, whilst
 it does not alter the length of the code, does effect a minor change. This does not seem to affect the operation of the
 SCAF filter, so the actual clock frequency obviously ends up the same. A.Ryan - 5B4AIY - 09/FEB/2014
 Build 3
 Fixed User Configuration page skip bug. When moving the Power Down mode select, I omitted to change the page skip value.
 Removed redundant variables in several EEPROM save and restore functions. The return values were always discarded.
 Modified the way the Immediate power down mode operates. A flag has been added to show that a change has been made to
 either the User Frequency or VFO memories, and if this flag is set and the power down mode is Immediate, then you will
 now receive a prompt when you power down to save the settings. A.Ryan - 5B4AIY - 25/FEB/2014
 Build 4
 Modified the way the Rapid Band Switch User frequencies and VFO frequencies are saved. In this version the save is now
 automatic, and is in the power_off() module. The previous IMMEDIATE mode power-down prompt is removed. A.Ryan - 5B4AIY - 26/FEB/2014
 Build 5
 Added a prompt to the Erase voice memory command. A.Ryan - 5B4AIY - 01/MAR/2014

 1.10k
 Build 1
 Modified the way the Press & Hold functions operate. All the P & H functions now latch the page so that you no longer need
 two hands to operate the Rapid Band Switch, VFO Memory Copy, Multi-Memory VFO Select, User Configuration Fast Page Select,
 or the Calibration Fast Page Select functions. With this version, press the appropriate button until the long beep sounds,
 release the button and the function will stay selected. Rotate the VFO knob to select the desired page/band/VFO/Memory, then
 cancel the page hold either by a brief press of the page select button originally used, or the PWR button. For the VFO select,
 User Configuration Fast Page Switch or Calibration Page Switch since these pages do not indicate any differently in the fast
 page switch mode, a rapid warning beep is given. For the Rapid Band Switch and VFO Memory Copy functions, since these pages
 intrinsically display their functions, no warning beep is given. A.Ryan - 5B4AIY - 03/MAR/2014
 Build 2
 For the sake of consistency, added the warning beep to both the Rapid Band Switch and VFO Memory Copy functions.
 Modified the adjust_rf_attenuator() function. It now only requires the selection of the TUNE mode, press the PTT switch,
 briefly press the PWR button, and the function is engaged without having to hold the PWR button. A warning beep is also
 given to remind you that the function is latched. To save the new settings and exit, release the PTT switch.
 Changed the LONG_PUSH timer to 650mS, and the VERY_LONG_PUSH timer to 1,200mS. A.Ryan - 5B4AIY - 04/MAR/2014
 Build 3
 Replaced various temporary variables in main loop with temporary local variables, and removed the need to 'fix'
 spurious mode/filter/vfo changes. A.Ryan - 5B4AIY - 09/MAR/2014
 Build 4
 Fixed major bug. When using the W command in the TRX-2 protocol this would provoke an Adress Trap Error! because the arguments
 passed to the max_min() were incorrect. Updated the J command. Updated the B command to use the current Default/User frequency
 settings. A.Ryan - 5B4AIY - 10/MAR/2014
 Build 5
 Used svc_flag to both remain in and exit from Service & Calibration Mode. Eliminated redundant variable in
 send_packet_to_74hc595(). The variable i was used to calculate the value for the rf_filt_idx, so why not use rf_filt_idx
 directly? Altered the sequence of configuration pages to place the AF I/P source select before the Speech Processor On/Off page.
 Also altered the logic so that if the AF I/P Source is LINE, then the Speech Processor On/Off page is skipped. When sending
 the configuration data to the SPI bus in the function: send_packet_to_74hc595(), if the audio input source is set to
 LINE then the speech processor is automatically turned off. A.Ryan - 5B4AIY - 17/MAR/2014
 Build 6
 Modified send_packet_to_74hc595() and exchg_data_spi1() functions. The determination whether to initiate an SPI data transfer
 is now made in the send_packet_to_74hc595() function rather than previously in the exchg_data_spi1() function. This simplifies
 the code. Modified the glitch removal times, and incorporated the glitch suppression in the Rapid Band Switch code. Modified
 the times slightly. The glitch which occurs when switching down into the 17m band is still persistent, and resists suppression.
 Apart from the start-up glitch, all the others are now well suppressed. Fixed final spurious button push action. By re-arranging
 the code in power_off() the spurious VFO Lock operation has been eliminated, along with its corrective code. Incorporated the
 skip_page() in both the User Configuration and Calibration menus. Added a button make de-bounce to the power_off() function.
 This prevents a spurious VFO lock operation when powering down. A.Ryan - 5B4AIY - 21/MAR/2014

 1.10m
 Build 1
 There is no 1.10l as the letter ell 'l' and the figure one '1' are almost indistinguishable on the LCD.
 Used a spare EEPROM location in the Calibration & Setup area to store a flag to allow the long push buttons to operate either
 as they did originally, Press & Hold, or in the new mode, Latched. This applies to the RBS (RIT button), VFO Memory Copy
 (MODE button in the normal operating mode), VFO Select (VFO button in the VFO Multi-Memory mode), and Fast Page Select (MODE
 button in either the Calibration & Setup or the User Configuration menus). Altered the band attenuator so that it no longer
 beeps when latched, as the displayed page should be a sufficient reminder, and it is no longer considered one of the Long Push
 Second Mode buttons. This also required a modification to the Serial Test Suite. A.Ryan - 5B4AIY - 24/MAR/2014
 Build 2
 Complete re-write of User Configuration Menu. Removed the set_value and display_settings function arrays, and combined them into
 a single display_cfg function array. This now means that the Service & Calibration and User Configuration menus are essentially
 the same construction, with the same indexing and adjustment logic. 477 bytes of code saved! A.Ryan - 5B4AIY - 24/MAR/2014
 Build 3
 Updated Serial Test Suite to incorporate the new user feature, selectable long button mode. Re-sized the rf_attn[] array from
 16 to 14 bytes so that the next two bytes could be used as an integer for the button mode flag in the calibration memory
 section of the EEPROM. By this means a checksum error on initial load is avoided, but the user MUST enter the Calibration
 and Setup mode and step to the Long Push Button Mode page and then save the current settings. This will force the memory area
 used by this integer to be over-written with the correct value. Otherwise the long push button function will not work
 correctly. Added additional logic to force the correct value for hold_latch even if the user fails to update the EEPROM.
 Added logic to the MODE section to absolutely prevent a spurious execution of the VFO Memory Copy code. Although I had
 never seen this occur, there was a small 'window of opportunity' for this to occur. A.Ryan - 5B4AIY - 25/MAR/2014
 Build 4
 Changed the splash screen so that the Region Setting and the Long Push Button Mode is displayed. Modified check_freq() to
 eliminate a redundant variable i. If variable band is used as the loop counter then i is unnecessary. Minor rationalisation
 of frequency limits for USA General Class band limits. A. Ryan - 5B4AIY - 25/MAR/2014
 Build 5
 Added user selectable display of the splash screen on power-up in the System Calibration & Setup menu. A.Ryan - 5B4AIY - 27/MAR/2014
 Build 6
 More minor optimisations in display_s_meter(), and power_off(), removal of unreferenced functions. Removed lcd_1(), relocated
 the backlight on command to the display_cfg_page() function, and substituted this function in the lcd_dsp[] array. Fixed
 subtle bug that allowed the filter bandwidth to be changed by one step in the Fast Page Switch mode. Minor optimisation
 in set_flag() in service.c, in encoder_get_coarse() in enc-trx.c. Modified putch() and putch2() so that they take an
 unsigned char and convert to an unsigned int to load their respective transmit registers, eliminating a redundant mask
 operation. (See Character To Int Conversion table in uart.c) A.Ryan - 5B4AIY - 03/APR/2014
 Build 7
 Modified rs_232Test() function to fix bug. If a loop-back plug was inserted and the RS-232 Loopback Test selected on power-up,
 the serial message would be looped forever. This has now been fixed. A.Ryan - 5B4AIY - 07/APR/2014
 Build 8
 Added update to the A_equals_B_flag when performing a Rapid Band Switch operation to fix a discrepancy in the Auto-Update
 protocol for TRX-Manager. Removed redundant Get_Character() function from Serial Test Suite. A.Ryan - 5B4AIY - 16/APR/2014

 v1.10n
 Build 1
 Modified the logic so that Rapid Band Switch, VFO memory Copy, and User Mode frequency storage is permissible when Split Mode
 is active. Since Rapid Band Switch is inhibited during transmit, as are the other operations, if band switching is performed,
 then it will be VFO-A which is changed, and this will force VFO-B to be synchronised if its frequency is not in the same band.
 Similarly, when copying frequencies using the VFO Memory Copy function, the source or destination VFO is always VFO-A as
 appropriate. When copying a frequency into the User Band Switch Memory, it is the VFO-A frequency which is used. A.Ryan - 5B4AIY - 17/APR/2014
 Build 2
 Simplified the low voltage pre-limit warning calculation. Simplified switch selection logic. Collected all the button de-bounce
 delays and associated encoder resets into a single function. A.Ryan - 5B4AIY - 18/APR/2014
 
 v1.10p
 Build 1
 Major re-write of the front panel button logic. An inspection of the code revealed that there were numerous duplicated logic
 tests, a number of redundant flags and local variables, and duplicated logic. The first steps set the long push timer, set the
 short push flag, and reset the latch flag. The first test performed is to determine whether the transceiver is in the Transmit
 or the Receive mode. In the Transmit mode, all buttons with the exception of the PWR button are ignored. In the Receive mode,
 the next test is to determine if Display Mode 0 is true. The RIT, VFO, VFAST buttons are only active in this mode. The other
 buttons are active in this mode as well as Display Mode 1 (Configuration Mode). If a button is pressed, the first check is to
 loop whilst it is pressed to determine if the long push timer has timed-out, indicating that this is a Long Push function.
 If the timer has expired, a number of actions occur, including resetting the short push flag. The actual actions are dependant
 on which button has been pressed. Generally speaking, once the long push timer has expired, the action then breaks out of the
 loop and proceeds either to wait until the button has been released, or to immediately execute the long push function. If the
 button is released before the long push timer has expired, then this is a short push function, the short push flag will be TRUE
 and the function will execute. The short push flag is not strictly necessary, the long push timer could be used. However, there
 is an inherent flaw in this. If the button is held until the long push timer reaches 1 and then released, and if an interrupt
 occurs just before the timer is tested, then neither the long push nor the short push function will execute. The window of
 opportunity is extremely short, and the probability of occurrence low, but it could happen, thus the short push flag is used to
 obviate this extremely remote possibility. A.Ryan - 5B4AIY - 19/APR/2014
 Build 2
 Removed redundant reset of encoder_event in VFO logic - this flag is reset in get_encoder() as well as encoder_reset(), and
 thus an additional reset is not required. Modified DISPLAY/CONFIG Long Push to display the current User Configuration page
 as soon as the Long Push is recognised instead of waiting until the button is released. Minor re-structuring of short push
 and long push code in button logic. A.Ryan - 5B4AIY - 20/APR/2014
 Build 3
 Added immediate warning beep for long push Latched mode select, with an immediate long beep for the Press & Hold mode selection.
 This improves the mode recognition for the user. Previously there was no obvious difference between Latched or Push & Hold
 mode when the button was pressed, you would have had to release it. Now, if the mode is Latched, then as soon as the long push
 is recognised, you will hear the warning beeps. If the Press & Hold mode is in effect, you will hear a single long beep.
 As a consequence, there is now no real reason to have the splash screen display the Long Push mode, as the tones will
 serve to remind you. Rationalised the construction of the button recognition, so that as far as possible the logic is
 consistent for all the button recognition code. Updated the button recognition code in service.c as well as optimising the
 various tone production code in the button module. Added synch_beep() to synchronise the warning beep for the Latched Mode.
 If the button was released when the decay counter had almost expired then with the button de-bounce delay there would have
 been an extra long time before the warning beep repeated. The new function eliminates this annoyance. A.Ryan - 5B4AIY - 23/APR/2014
 Build 4
 Restructured the main loop collecting all the transmit and receive code fragments together eliminating duplicated logic tests.
 Fixed some annoyances. If the PWR button was briefly pressed whilst in the User Configuration mode, it would toggle the active
 VFO's lock status - fixed. If the transceiver was in the CWR mode, and the CW/CWR Swap feature was enabled, if the User Configuration
 mode was selected, and the filter bandwidth adjustment page used, the first press of the FILTER button would re-select the CW mode
 and then the second and subsequent pushes would select the filters - fixed. Fixed the 'Not Moved' bug once and for all. Combined
 all the frequency offsets into the offset variable in the RECEIVE mode, eliminating some untidy code. Added code to the 'd'
 function in the Serial Test Suite that now verifies that the DDS frequency calculation is correct. Eliminated the annoying
 double beep when pressing the DISPLAY button to select the User Configuration mode. Added a timer to the 1mS main interrupt.
 The swr_al_delay timer now replaces the previous main loop counter for the long SWR alarm delay timing. As this only added
 three instructions, taking about 400nS, it was a worthwhile move. A.Ryan - 5B4AIY - 25/APR/2014
 Build 5
 Improved display_bar_meter() and get_pwr() so display_pwr_meter() was redundant - removed. Now that the graphic meter display
 has been optimised, removed the redundant test for numeric/graphic S-Meter from draw_s_meter() in lcd-trx.c and optimised the
 code in _disp_meter() in isd1700.c A.Ryan - 5B4AIY - 11/MAY/2014
 Build 6
 Removed meter_value[] array of function pointers. Although this was an elegant way of doing things, it was also 30 bytes more
 code compared with a simple function using IF statements. Optimised kbhit(), getch(), kbhit2(), getch2().
 Minor improvement to the Test LCD Write ASCII test. A.Ryan - 5B4AIY - 23/MAY/2014
 Build 7
 Modified the way the VFO lock function works. In the previous firmware you had to change the VFO mode from A+B/Split to
 VFO Multi-Memory mode, select the VFO and lock/unlock, and then re-select the A+B/Split mode. This is no longer necessary.
 In the A+B/Split mode, select the Split mode, and press the VFO/A=B button until the long push timer expires, then use the
 VFO knob to select the VFO memory, and briefly press the PWR button to toggle its lock status. Added procedure first_line()
 to clean up some code, and added a prompt to the VFO Select function. A.Ryan - 5B4AIY - 28/JUL/2014
 Build 8
 Modified the way the VFO Lock function works in the Multi-VFO Mode. Previously you could only lock the active VFOs. This
 version now permits locking the inactive VFOs used as VFO memories as well. A.Ryan - 5B4AIY - 29/JUL/2014
 Build 9
 Modified dds_send_one() in ad9850.c to use a more efficient loop. Re-arranged code in clear_cat() in serial_Y_cat.c to
 eliminate a redundant operation. Added stop() to isd1700.c A.Ryan - 5B4AIY - 02/AUG/2014
 
 v1.10q
 Build 1
 Combined all serial receive buffers, and removed redundant functions.
 Rationalised the Service module exit. Previously you had to briefly press the VFAST button, but for the Configuration module
 you used a long push of the DISPLAY/CONFIG button. This was inconsistent. This version now uses a long push of the DISPLAY/CONFIG
 button as the exit for the Service module as well. Eliminated the redundant Restore Defaults page in the System Calibration & Setup
 menu, as there is already a main boot item that covers this very rarely used function.
 Removed redundant assignment in wait_lcd_ready() in lcd-trx2.c, modified code to use simpler DO-WHILE loop. Modified the delay time
 in wait_lcd_ready(). The original 2uS delay is needlessly long. The minimum setup delay time is 320nS, but the minimum delay time
 from the interrupt system is 1uS.
 Modified the mode/filter blink feature. Previously whenever either the mode or the filter was changed, this would be indicated with
 a double blink on all display pages. Now, the blink only occurs on the pages 1 through 4, the home or normal display page no longer
 blinks, the new mode or filter is simply displayed. A.Ryan - 5B4AIY - 3/SEP/2014
 Build 2
 Eliminated a redundant prompt array from service.c Improved A-D Converter display in Serial Test Suite. A.Ryan - 5B4AIY - 5/SEP/2014
 Build 3
 Changed the way the User Configuration initial display works. It now displays a message: "User Configuration" as long as the
 DISPLAY/CONFIG button is held, and then drops into the User Configuration menu when released. A.Ryan - 5B4AIY - 13/SEP/2014
 Build 4
 Simplified the function display_out_of_band() in lcd-trx2.c A.Ryan - 5B4AIY - 28/SEP/2014
 Build 5
 Simplified frequency display logic in lcd-trx2.x. The functions now use pointers rather than passing values. A.Ryan - 5B4AIY - 01/OCT/2014
 Build 6
 Final optimisation of display_freq() function in lcd-trx2.c A.Ryan - 5B4AIY - 03/OCT/2014
 Build 7
 Complete re-design of display_freq(). This saved 348 bytes. Removed redundant call to init_scaf_clock() when entering Service
 & Calibration module. Changed VFO Lock symbol from '*' to Octal 353. A.Ryan - 5B4AIY - 20/OCT/2014
 Build 8
 Modified serial_trx2() so that a check is now performed for an excessively long command. Although the previous version would
 not cause a buffer over-run, if an excessively long command string was received then the buffer pointer would remain at the
 maximum value until a CR was received, when the command string would be parsed. This could lead to spurious mode/VFO changes,
 especially when connected to a PA-100D when it was being calibrated. On the exit from the PA-100D calibration mode, the amplifier
 would start its normal initialisation sequence and if its frequency detection mode was set to either F-SENSE or FT-817 mode and
 the serial test mode enabled, if the TRX-2 was connected to the serial port, then the PA-100D start-up serial test messages
 could be misinterpreted as commands. By removing the '=' character from the PA-100D serial start-up message, as well as
 this modification, this is now prevented. A.Ryan - 5B4AIY - 09/NOV/2014

 v1.11a
 Build 1
 Added feature to allow the display of output power in dBm as well as Watts. This uses an additional word of the EEPROM,
 and so will cause a Checksum Error on initial load. Minor adjustment of POWER_BAR_CONSTANT. Note that in the Service Mode
 the output power displayed when calibrating the power meter is always in Watts. In either the manual band attenuator adjust
 or the Auto-Equalise mode, the power is display in either dBm, or Watts, depending upon the User Configuration setting.
 The Auto-Equalise mode now displays the averaged power in both watts and dBm. A.Ryan - 5B4AIY - 24/NOV/2014
 Build 2
 Replaced FOR-NEXT loop with DO-WHILE in: dds_load() (ad9850.c), draw_s_meter() (lcd-trx2.c), chk_state() (serial_trx2.c),
 bar-graph test (serial_test.c), send_packet_to_74hc595(), get_average_pwr(), auto_equalise() (juma-trx2.c). Minor adjustment
 to the default RF attenuator settings, the 1MHz band is now set to maximum attenuation. Changed the attenuation setting
 used in the Auto-Equalise function from -1dB to -3dB, and increased the number of power samples from 10 to 100. This has
 improved the repeatability of the equalisation, and reduced the stress on the driver and PA stages. Removed a redundant
 WHILE loop in auto_equalise(). A.Ryan - 5B4AIY - 09/DEC/2014

 v1.20a
 Build 1
 Completely re-designed the auto-equalise() function. The function now includes considerably more error checking, and in addition
 permits the function to be invoked from the front panel as well as remotely from a terminal via the Serial Test Suite.
 The function now displays the calculated attenuation on the LCD when invoked from the front panel, and an additional page has
 been added to the System Calibration menu to allow the user to adjust any of the attenuator settings. This facility is also
 available from the front panel when the TUNE mode is invoked. To invoke the automatic band equalisation from the front panel,
 from the power OFF state, press and hold the FAST/VFAST button, and power up the transceiver. Continue holding the button until
 the message:
 
   Automatic RF
 O/P Equalisation

 is displayed. At this point release the button and the prompt:

     Proceed?
 PWR:No  MODE:Yes

 will be displayed. Briefly press the MODE button to begin, or the PWR button to abort. If the MODE button is pressed, you will
 receive the prompt:

  Press and hold
 PTT to start ...

 Press and hold the PTT switch, and the display will show the graphic output power graph and digital averaged output power on the
 first line of the display, and the frequency at which the measurement was made on the second line. The procedure will cycle through
 the bands from 10m down to 160m measuring the output powers, and will then calculate the attenuation values for each band to ensure
 optimum equalisation of the output power. At the conclusion of the process, you will receive the prompt:

   Release PTT
  to complete...
 
 When you release the PTT switch, the display will change and on the first line will be the current attenuation settings and on the
 second line will be the message requesting you to press the PWR button to exit. The current attenuation settings will be displayed
 in the form:
 
  17m 110010000
 
 The band displayed is the reference band. This is the band which had the lowest output power and is used as the reference for all
 the other bands. The 9-digit number represents the attenuation values from 1db to 3dB for the various bands, in the order
 160m, 80m, 40m, 30m, 20m, 17m, 15m, 12m, 10m. The reference band digit will be blinking. This presentation is also used in the
 System Calibration & Setup menu. In this menu, to select a band, briefly press the FILTER button. The band will be incremented and
 will cycle around to the first band. If the FILTER button is held, then an automatic increment will occur. Once you have selected
 the desired band, its attenuation can be adjusted with the VFO knob. The selected band's digit will also blink. If you either abort
 the process by releasing the PTT switch prior to completion, or if an error occurs, you will receive an abort message. A.Ryan - 5B4AIY - 31/DEC/2014
 Build 2
 Removed variable: audio_src. This was used to save the current audio source selection in the TUNE mode, whereupon the
 source was set to the LINE mode. This is unnecessary, as selecting the TUNE mode automatically disables the microphone
 amplifier. A.Ryan - 5B4AIY - 01/JAN/2015
 Build 3
 Minor modifications to send_packet_to_74hc595() Removed redundant hold_latch mask operation, no longer required as this
 version of the firmware will cause a checksum error on initial load, forcing the defaults to be loaded. Fixed a potential
 bug that might have caused a math error when displaying dBm. Although steps were taken to eliminate the possibility of this
 I decided a more robust approach was required, hence the implementation of display_rf_pwr(). Fixed RIT bug. Under certain
 circumstances the displayed frequency in receive would continue to follow the RIT setting, even when Include RIT was OFF,
 although the synthesiser frequency was not changed, it was merely a display fault. A.Ryan - 5B4AIY - 03/JAN/2015
 Build 5
 Changed the sense of the CW/CWR mode to agree with the Elecraft KX3. Now, as with the KX3, CW (Normal) uses LSB, and CWR
 uses USB. A.Ryan - 5B4AIY - 10/JAN/2015
 Build 6
 Modified display_atten(). The bands now display in the order: 10m, 12m, 15m, 17m, 20m, 30m, 40m, 80m, 160m to coincide
 with the order in which they are measured. A.Ryan - 5B4AIY - 11/JAN/2015
 Build 7
 Fixes minor bug in set_factory_defaults(). VFO-D and VFO-E and VF-M and VFO-N were incorrectly set to LSB.
 A.Ryan - 5B4AIY - 13/JAN/2015
 Build 8
 Moved the setting of the contrast and backlight levels to after the check for defaults by using the bl_on() function.
 Modified the bl_on() function to include setting the contrast as well as the backlight level. A.Ryan - 5B4AIY - 20/JAN/2015
 Build 9
 Minor reformatting of the calibration and configuration settings display in Serial Test Suite. A.Ryan - 5B4AIY - 09/FEB/2015
 Build 10
 Modified disp_fwd_pwr() so that when the decay timer has expired, the power is reset to zero.
 Modified disp_rf_power() to eliminate a redundant multiplication, and included this in the scaling factor of
 disp_meter() in lcd-trx2.c Minor optimisation in serial_Y_cat.c. Fixed spurious power down when exiting from a default
 restoral if PWR or MODE button is held. Fixed minor bug in Press&Hold mode in Calibration mode. Fixed bug that allowed
 the filter button to operate in the User Configuration mode even when the filter adjustment page was not selected.
 Modified the second function of the FAST/VFAST button to return tuning to the 1Hz rate if it was the very fast rate,
 the existing short push function returns to the 10Hz rate. A.Ryan - 5B4AIY - 27/FEB/2015
 Build 11
 Added functions first_line() and second_line() to replace numerous code repetitions.
 Fixed minor formatting bug. A.Ryan - 5B4AIY - 15/MAR/2015
 Build 12
 Rewrote code to combine first_line() and second_line() into the function display_line(). Eliminated clear_lcd() and
 replaced with a macro. Moved display_line() and display_screen() to lcd-trx2.c A.Ryan - 5B4AIY - 19/MAR/2015
 Build 13
 Added code to the FAST/VFAST selection to display the tuning rate without delay. A.Ryan - 5B4AIY - 01/APR/2015
 Build 14
 Added code to allow choice of splash screen on boot-up. Added feature to display firmware version when booting into
 the Calibration & Setup mode. Minor optimisation using increment_and_check(). Fixed bug that caused wrong display
 of System Settings for the Splash Screen. A.Ryan - 5B4AIY - 19/APR/2015

 1.20b
 Build 1
 This version enhances the System Calibration & Setup module to improve the adjustment of both the driver and PA stage's
 bias currents, as well as the ammeter calibration factor. In previous versions, if the driver bias was adjusted first in
 the TUNE mode this turned the driver stage on as a small-signal Class-A amplifier, and there is sufficient carrier leakage
 in this mode such that when next adjusting the PA bias current the actual current indicated included this small signal current.
 Consequently, when switching to SSB the zero-modulation current which should have been the 200mA bias current now showed
 somewhat less, as the carrier leakage signal was no longer present. In this version of the firmware in the Service mode,
 when page 2, the ammeter page is displayed, the mode is set to USB, and the microphone input is switched to the LINE mode
 for maximum attenuation. In this mode, the driver bias is first set to zero, then the PA bias is first adjusted to 100mA
 for each transistor, 200mA in total. The calibration is adjusted to read 200mA. Then the driver stage bias is set to 30mA
 for each transistor, 60mA in total. When the RF Power page is displayed the TUNE mode is selected, and the RF attenuator
 is set to zero and the carrier level can now be adjusted for 10W, and the calibration factor set to agree with an accurate
 external power meter. When the Service module is exited the original TUNE mode attenuator settings, microphone mode, and
 VFO frequency and mode are restored. A.Ryan - 5B4AIY 14/MAY/2015
 Build 2
 Removed code that saved and restored configuration data to/from local variables, and replaced it with a call to the
 function read_defval() that reads and restores the configuration data. Added wait_PWR_MODE_rls() function call to
 latched mode release to prevent re-selection of Fast Page switch if MODE or PWR button is held when de-selecting
 this mode. Removed change_VFO() and substituted in-line code. (Only called once). Moved adjust_VFO() so that it is now
 executed whenever the VFO step size is altered to avoid it being called every time through the main loop. A.Ryan - 5B4AIY - 20/MAY/2015
 
 1.20c
 Build 1
 Modified the Rapid Band Switch feature. Other transceivers, when changing amateur bands, save the current band and mode.
 In this version, if USER-A mode is selected, then the user frequencies are only saved when the FILTER button is pressed.
 If the USER-B mode is selected, whenever the Rapid Band Switch is invoked, then the current frequency and mode will be
 saved to the appropriate user memory, and restored when this band is re-selected. This also means that the configuration
 data should be saved when powering-off if you wish these changes to be saved. A.Ryan - 5B4AIY - 23/MAY/2015
 Build 2
 Changed the TUNE attenuation setting to -3dB in the Calibration & Setup mode. A.Ryan - 5B4AIY - 23/MAY/2015
 Build 3
 Removed global old_ADC and replaced by local static in get_rit(). A.Ryan - 5B4AIY - 24/MAY/2015
 Build 4
 Minor re-formatting of Serial Test Suite calibration and configuration text. Moved the initial DDS load of 0Hz to
 dds_init() as it is always called from here, and never used anywhere else. Eliminated some duplicate code in
 Serial Test Suite A-D converter and RIT frequency calculation by combining into new RIT_freq() function. Changed
 the Service frequency to 14.019300 MHz so that the Elecraft XG3 signal generator can be used on its default 20m
 setting for calibrating the S-meter. Changed the logic in the Calibration & Setup mode so that when displaying
 the RF Power Meter calibration the mode is set to TUNE to allow RF output, but is set to USB for all other pages,
 and, as in this mode the microphone source is set to LINE, then although an accidental press of the PTT switch
 will still select the transmit mode, there will not be any RF output. Also changed the logic so that page
 switching can only occur in the RECEIVE mode. Removed the type of frequency display from the 'u' command and
 added it as a separate 'F' command in the Serial Test Suite. A.Ryan - 5B4AIY - 08/JUN/2015
 Build 5
 Optimised the bottom_line() function. A.Ryan - 5B4AIY - 13/JUN/2015
 Build 6
 Optimised calc_swr() Removed set_seconds() from isd1700.c and replaced with in-line code. Simplified timer
 logic for Voice Memory seconds counter. Modified the bar-graph test in serial_test.c Added a default setting
 to set_chgen() in lcd-trx2.c A.Ryan - 5B4AIY - 28/JUN/2015
 Build 7
 Optimised set_chgen() in lcd-trx2.c 01/JUL/2015

 2.00a
 Build 1
 Completely changed the way the EEPROM checksum is calculated and verified. Added crc_16(), crc_8(), and crc_1().
 Checksum is now calculated as a 16-bit CRC. A.Ryan - 5B4AIY - 01/AUG/2015
 Build 2
 Added code to get_one_zero() to force an out-of-range value to be corrected. A.Ryan - 5B4AIY - 04/AUG/2015
 Build 3
 Modified get_one_zero() to use an existing function, get_value(). A.Ryan - 5B4AIY - 05/AUG/2015

 2.00b
 Build 1
 Modified the way that VFOs and Memories are displayed. Previously when using the SPLIT mode and executing the
 VFO frequency/mode copy function, all 'passive' VFOs (Memory locations) were displayed as VFOx where 'x' was
 the VFO letter from C to Z. Equally, when using the Multi-Memory mode 'passive' VFOs were still displayed with
 the VFO designator plus a letter, and thus it was not clear which was an 'active' VFO and which was a memory
 location. With this version, all 'passive' VFOs, which are really memories, are displayed as 'MemX' where 'X'
 is a letter designator. For example, in the SPLIT mode only VFOs A and B are active, the remainder are memories,
 and thus when copying from VFO-A to anything other than either VFO-A or VFO-B the destination is now shown as
 'MemC'. When using the Multi-Memory mode, if for example, you have partitioned the memory so that there are 4
 active VFOs, VFO-A through VFO-D, then when you select the fifth it will be displayed as 'MemE'. Similarly,
 when copying from a source to an active VFO, if the source is a memory, this will also be displayed in the
 same fashion, thus clearly identifying active VFOs and memories. A.Ryan - 5B4AIY - 13/AUG/2015
 Build 2
 Modified the display of configuration page 15. In the Multi-Memory mode, it now displays both the number of
 VFOs, as well as the number of memories. A.Ryan - 5B4AIY - 14/AUG/2015
 Build 3
 Simplified dds_load() in ad9850.c by eliminating the local variable set_val. The multiplication is now performed
 in-line, and as the microprocessor contains a barrel multiplier, this is faster than the equivalent 33 place left
 shift previously used. Modified dds_load() so that the synthesiser is only updated if the frequency has changed.
 A.Ryan - 5B4AIY - 23/AUG/2015
 Build 4
 Removed redundant assignment in get_avg_pwr(), removed superfluous test and redundant variables in snap_to_step(). A.Ryan - 5B4AIY - 13/OCT/2015
 Build 5
 Redesigned snap_to_step() saving 51 bytes. Major modifications to serial_test(). Replaced SWITCH-CASE construct used in both
 A-D and Alarm tests with indexed functions. Modified the band attenuator increment and decrement functions so that they now
 use a common display function, and will only increment to a maximum of 3dB and decrement to a minimum of 0dB instead of
 rolling around as before. Fixed minor bug - when selecting the LCD Test, if a value was entered that resolved to 3, although
 the correct character generator patterns were loaded, the wrong prompt was displayed. Improved the display of the VFO Memory
 dump. It now displays whether the memory is an active VFO or a passive memory, as well as showing whether it is locked or
 free using the '*' symbol for locked as in the normal main LCD. A.Ryan - 5B4AIY - 22/OCT/2015
 Build 6
 Removed redundant tests from check_alarm(), simplified the alarm logic. A.Ryan - 5B4AIY - 24/OCT/2015
 Build 7
 Re-designed display_alarm() and considerably simplified it. A.Ryan - 5B4AIY - 25/OCT/2015
 Build 8
 Optimised MODE/FILTER blink logic by removing some redundant tests. Fixed a minor bug. In the User Configuration mode, if
 the settings were saved when the TX Filter bandwidth was displayed, on the next power up cycle the transmit filter bandwidth
 would be displayed and selected for the receiver. Fixed. A.Ryan - 5B4AIY - 31/OCT/2015
 Build 9
 Minor optimisation of User Configuration display in serial_test.c A.Ryan - 5B4AIY - 22/DEC/2015
 Build 10
 Altered read_defval() and read_calval() to return a flag rather than the checksum in the event of an error. The returned checksum
 is never actually used, and its actual value would not enable you to diagnose what sort of EEPROM read error had occured. The flag
 returned is 0 for no error, and 1 for an error. This flag is used as an index into the eeprom_err[] message array to indicate 'OK'
 for a good read, and 'Error!' for a fault. Added the abort message display to the serial test suite Auto Equalise function so that
 if you answer N or n when prompted, the abort message is displayed instead of simply exiting the function. A.Ryan - 5B4AIY - 01/JAN/2016
 Build 11
 Swapped the sense of the alarm flag test in display_alarm(). Added a check to the calc_swr() to avoid the remote possibility of
 provoking a math trap error if the SWR is very high. A.Ryan - 5B4AIY - 10/JAN/2016

 3.00a
 Build 1
 Added CW Practice Mode. To enter this mode, from the power off state, press and hold the FILTER button, and briefly press the PWR
 button to turn the transceiver on. Continue to hold the FILTER button until the message "CW Practice Mode" is displayed. Follow the
 prompts to set the desired mode and speed. Use the CW SPEED knob to alter the speed, and the VFO knob to set the mode.
 A.Ryan - 5B4AIY - 05/MAR/2016
 Build 2
 Added a Morse character/message test feature to the Serial Test Suite. A.Ryan - 5B4AIY - 11/MAR/2016
 Build 3
 Added the CW Annunciation feature. This feature uses an additional word of the EEPROM, and thus will cause a checksum error on initial
 execution. This feature allows a visually impaired operator to determine the current status of the transceiver by means of Morse
 status characters. If this feature is turned on in the User Configuration menu, then unfortunately you will lose the Very Fast (1kHz)
 tuning rate, as there are insufficient buttons on the front panel. The feature has two modes, Full, and Frequency. In the Full mode,
 a long press of the FAST/VFAST button will cause the transceiver to send a full status message in the form:
 
 MODE FILTER VFO FREQUENCY
 
 The MODE is indicated by the letters L for LSB, U for USB, CN for CW Normal, CR for CW Reverse, and TN for the TUNE mode.
 The FILTER is indicated by the letters N for Narrow, M for Mid, and W for the Wide filter.
 The VFO is indicated by the letters V plus the current VFO letter, A - Z, or, if the SPLIT mode is in operation, then the letters SA.
 The FREQUENCY is indicated by the letter F followed by the frequency digits to a resolution of 1kHz.
 
 If the mode is set to FREQ then only the current frequency is sent.
 
 When setting up the CW Annunciation mode, the speed at which the message is sent is determined from the current setting of the CW SPEED
 pot. This speed is saved, and is used in the normal mode of the transceiver. This speed is not related to the CW Keyer speed, which can
 be quite different, if desired. If the CW SPEED pot is rotated fully anti-clockwise, then the default speed of 20wpm is used.
 A.Ryan - 5B4AIY - 09/MAR/2016
 Build 4
 Removed variables F, S, and V, and replaced them with defined constants. Optimised the send frequency function. A.Ryan - 5B4AIY - 12/MAR/2016
 Build 5
 Moved the scroll_LCD() function to lcd-trx2.c, and made it more general. A.Ryan - 5B4AIY - 14/MAR/2016
 Build 6
 Added an acknowledgement beep to wait_FILTER_rls(). Modified select_symbol(). In the previous versions, the proportion of numbers to letters
 in the MIXED CW Practice  mode was unreasonably low, less than 1:3. This was as a result of the way I was selecting characters. In this version
 if the MIXED mode is selected there is now a 50:50 chance of selecting a number or a letter for the next character. In addition, there is now
 a check made to ensure that no identical sequential characters are generated. A.Ryan - 5B4AIY - 18/MAR/2016
 Build 7
 Fix minor bug in Serial Test Suite. The LCD Timer value was displayed incorrectly. A.Ryan - 19/MAR/2016
 Build 8
 This build now allows you to capture the character groups sent during the CW Practice Mode sessions using a terminal program on a PC. For
 this to work, the TRX-2 serial port mode must be set to TEST. A.Ryan - 5B4AIY - 20/MAR/2016
 Build 9
 Fixed minor bug. The inter-character spacing was left at the CW Practice mode setting when exiting this mode. It is now reset to the normal
 value of 3. A.Ryan - 01/APR-2016
 Build 10
 Fixed minor bug. When sending the full message, the spacing between 'messages' was 10 dot times instead of 7. Fixed 'spurious beep' bug.
 In the CW ANNUCIATION mode the FILTER button was always giving an acknowledgement beep, even though it was not required. Also, in the USER
 CONFIGURATION mode, a beep was given when pressing the FILTER button even when the FILTER BW adjustment page was not displayed. The problem
 was in the wait_FILTER_rls() function, which always gave a beep when the FILTER button was released. It is now passed a flag to indicate if
 a beep is required or not. A.Ryan - 5B4AIY - 18/APR/2016
 Build 11
 Changed A-D converter delay from 500uS to 50uS to improve loop cycle time. Fixed minor bug in User Frequency memory display in Serial Test
 Suite. The frequency was converted from a 32-bit long integer to a 32-bit float in printf(), but there are not enough bits in the mantissa
 to accurately represent the frequency to 1Hz for frequencies above about 10MHz. This was exactly the same problem I encountered when
 displaying the transceiver's frequency using the NEW format to 1Hz resolution using sprintf(), and I had to use my own integer to ASCII
 conversion. A.Ryan - 5B4AIY - 11/JUL/2016
 Build 12
 Fixed bug in CW Practice Mode. If serial port was not set to Serial Test, then the CW practice would run on. A.Ryan - 5B4AIY - 13/JUL/2016
 Build 13
 Removed redundant local variable 'repeat_flag' in CW Practice Mode. Fixed leading zero suppression bug, and removed redundant
 test in disp_freq() in lcd-trx2.c Added function bl_db() (Back-Light & Debounce) on function buttons to prevent occasional short-push
 function selection on long-push operations. A.Ryan - 5B4AIY - 30/AUG/2016
 Build 14
 Further optimisation of disp_freq() by removing redundant lz flag. A.Ryan - 5B4AIY - 31/AUG/2016
 Build 15
 Improved button de-bounce logic using macro: button_debounce(button) See juma-trx2.h for details. Also fixed fatal CW Annunciation bug.
 When changing mode to LSB, at the end of the L continuous dots would be sent. Shortened button de-bounce delay for button release
 from 200mS to 105mS. If a similar technique as used for the button make de-bounce logic was used for button release, i.e. counting the
 bounces and resetting the counter, then this interfered with the tone generator (beep() function). A.Ryan - 5B4AIY - 05/SEP/2016
 Build 16
 Added announce_status() function that sounds the status beeps for MODE, FILTER, RIT, DISPLAY, VFO Lock, VFO Change, mode changes. This
 saved 104 bytes. Made the page change tones the same for Calibration and Configuration menus. Fixed another leading zero frequency
 display bug! The lz flag in disp_freq() is NOT redundant! A.Ryan - 5B4AIY - 19/SEP/2016
 Build 17
 Changed GLITCH_TIME from 100mS to 5mS. Tests showed that 2mS was slightly too short. Removed functions announce_status() and morse_practice(),
 only ever called once. Replaced with in-line code. A.Ryan - 5B4AIY - 28/OCT/2016
 Build 18
 Added feature to allow the user to select the LCD scroll direction in CW Practice Mode. Finally eliminated the last of the glitches!
 The reason that some band changes caused a glitch was that although the band number changed, the SPI data word did not, and so the
 glitch suppression was not invoked. By checking rf_filt_idx changes in the function send_packet_to_74hc595() along with checks for
 changes to the SPI data word, all the glitches can now be suppressed. Moved frequency in use calculation to the end of the main loop
 to avoid calling send_packet_to_74hc595() twice when changing bands. A.Ryan - 5B4AIY - 21/NOV/2016
 Build 19
 Minor optimisation of crc_8() function. Replaced call to debounce() in the auto equalisation procedure used on power up with a call to
 wait_PWR_MODE_rls(), and again at the exit of the CW Practice Mode. This avoids a spurious VFO lock. Collected code and added
 Switch_Off() function. A.Ryan - 5B4AIY - 06/DEC/2016
 Build 20
 Re-wrote button_debounce() macro to eliminate the very remote possibility of an infinite lock-up. In the previous version if you ever
 managed to so briefly touch the button that you entered the macro code, and then released the button, the delay time would be
 constantly reset to maximum, and you would never exit. Added an exit counter which counts the number of times the open button has been
 detected, and if it exceeds the maximum delay time, this indicates that the button press was false. See file Button Test.txt for a
 complete explanation. A.Ryan - 5B4AIY - 08/DEC/2016
 Build 21
 Optimised button_test() function by removing redundant variable exit_ctr. In this version, delay_time is now incremented by 2 and tested
 to see if it exceeds DEBOUNCE_LIMIT. If not, the function returns and delay_time is decremented and tested. If it is zero, the loop exits.
 If not, the button is again tested and if it is open, delay_time is again incremented by 2. Eventually the loop will terminate either
 because the button has remained closed, or else because an extremely short single contact closure was detected. A.Ryan - 5B4AIY - 11/DEC/2016
 Build 22
 Combined the button de-bounce and primary/secondary button function select logic. In this new version, in the macro button_debounce() the variable
 button_count is incremented if the button is detected as open, and decremented if it is closed. The function terminates either when button_count
 is zero, signifying a long button push, or when it equals DEBOUNCE_LIMIT, signifying a short push. Removed the redundant function button_test().
 A.Ryan - 5B4AIY - 08/JAN/2017
 Build 23
 Rationalised the code by removing button_timer and replacing it with the button_debounce() macro in power_off() and boot code.
 Removed button_timer from timers_pwm.c. Deleted all references to defined constants: BUTTON_DEBOUNCE, MEDIUM_PUSH, LONG_PUSH, VERY_LONG_PUSH,
 and POWER_OFF in file: juma-trx2.h. Although this increased the overall code size by 147 bytes, it improves the consistency by using the same
 code sequences for all button de-bounce and primary/secondary button function select logic. A.Ryan - 5B4AIY - 17/JAN/2017
 Build 24
 Fixed serious frequency error bug! The CW/CWR/RIT frequency offset was not cancelled in the transmit mode - fixed.
 A.Ryan - 5B4AIY - 11/APRIL/2017
 Build 25
 Minor optimisation of TX Enable/Disable logic to remove a redundant tx_enable flag negation. A.Ryan - 5B4AIY - 11/MAY/2017
 Build 26
 Removed redundant variable dds_config in ad9850.c, never referenced. A.Ryan - 5B4AIY - 08/JUL/2017
 Build 27
 Removed redundant bl_off_flag. In the previous versions, when the backlight timer was enabled, this timer was decremented in timers_pwm.c, and
 when the timer had expired, the bl_off_flag was set. Then, in the main loop this flag was used to turn the backlight off, and the flag was then
 cleared. In this version, the backlight is turned off in the _T3_interrupt routine, thus eliminating the need for the flag. As before, whenever
 the backlight is turned on, the backlight timer is set to either zero (Disabled) or to the number of seconds to remain on before being turned off.
 A.Ryan - 5B4AIY - 07/AUG/2017
 Build 28
 This fixes a minor annoyance. In previous versions it was possible to transmit/tune in the User Configuration mode, this version inhibits transmit
 when in this mode. If you attempt to transmit, then the message "TX Disabled!" is displayed. A.Ryan - 5B4AIY - 09/AUG/2017
 Build 29
 The Rapid Band-Switch feature now has another, albeit temporary, mode. In the previous versions, in User-B although you could still store a
 frequency/mode using the second function of the FILTER button as for User-A, but as soon as you changed the frequency/mode and then selected
 another band, the previous data was over-written. This meant that the second function of the FILTER button was essentially non-functional in the
 User-B mode. In this version, if you save the current frequency/mode using the second function of the FILTER button, then this will be the
 frequency and mode that is restored when you use the RBS function, as long as you do not change the band. It is intended to be used as a temporary
 'scratch-pad memory', and will be shown as MODE-C. To cancel this, either change the band and then return to the previous band, or use the second
 function of the FILTER button again, which will also cancel this temporary MODE-C. This modification uses an additional global flag, RBS_Flag, which
 is set to 2 to indicate MODE-C, or zero when clear, in which case, MODE-B will prevail. The value of '2' is used rather than 1 so that by adding
 the value of the flag to the RBS mode value we can index into the band_sw_msg[] array to show the MODE-C status. A.Ryan - 5B4AIY - 12/AUG/2017
 Build 30
 Removed the MODE-C cancel option from the FILTER button secondary function. It can only be cancelled by changing bands. A.Ryan - 5B4AIY - 13/AUG/2017
 Build 31
 Fixed minor bug. Previously, if you had VFO-A selected and VFO-B was locked and you changed bands, the frequency/mode of VFO-A was automatically
 copied to VFO-B. Similarly, if VFO-B was selected and a band change occurred, the frequency/mode was then copied to VFO-A. This has now been fixed.
 Only if the SPLIT mode has been deliberately selected will this equalisation of the VFOs occur, and only then if the inactive VFO is tuned to a
 different band. Also removed some unreachable code. In the rapid_band_switch() function a check was made to see if VFO-B was the 'active' VFO
 in the SPLIT mode, and if so, to check if VFO-A was set to the same band. Since the RBS function can only be invoked in the RECEIVE mode, this check
 would never be executed, as VFO-A is always the 'active' VFO in the SPLIT mode in receive. A.Ryan - 5B4AIY - 21/AUG/2017

 4.0a
 Build 1
 Introduced an adjustable VFO Equalisation feature. In the previous version you either had to load v3.0a/Build 30 or v3.0a/Build 31 to change the way
 that VFO equalisation occurred. With this version it is now user selectable. In the User Configuration mode, if the VFO memory mode is set to A/B+Split
 then an additional menu page is available to allow you to select how VFO frequency/mode equalisation is performed. It can be turned OFF, in which case
 it is entirely up to the operator to ensure that when SPLIT frequency mode is selected, that the RX and TX VFOs are suitably configured. If it is set
 to Split then equalisation only occurs whenever a band change is made and Split is active. If it is set to Split+Simplex then equalisation occurs
 whenever a band change is made, irrespective of whether Split mode is active. A.Ryan - 5B4AIY - 01/NOV/2017
 Build 2
 Altered the order of the VFO Equalisation, it is now: Off-Split Only-Split_Simplex. Modified the User Configuration display in the Serial Test suite
 so that when displaying the number of Active VFOs, the VFO operating mode (A/B Split/Multi-Memory) is also shown. Corrected a minor display anomaly
 in the Serial Test Suite. The order of the User Configuration display agrees with that displayed in the menu. A.Ryan - 5B4AIY - 03/NOV/2017
 Build 3
 Saved 153 bytes by using the equalise_VFO() function for both the second function of the VFO button (Copy VFO A to B or Copy VFO B to A), as well as
 its original function of equalising the VFOs. Optimised the equalise_VFO() function to eliminate redundant code. A.Ryan - 5B4AIY - 04/NOV/2017
 Build 4
 Minor optimisation to the extended Serial Test Suite. Fixed strange bug in A/B+Split TUNE mode. If VFO-B was set to TUNE, and the SPLIT mode was active,
 when the PTT switch was pressed sometimes the output power was maximum instead of using the TUNE Attenuation, and after a second or so it would reduce
 to the normal tune O/P. This did not occur if VFO-A was also set to TUNE. Since you would have to select VFO-B in order to de-select the erroneous mode,
 this version detects if TUNE is selected for VFO-B and split mode is active, and then sets the mode of VFO-B to that of VFO-A. Fixed minor bug in the
 CW Annunciation mode, an erroneous beep was sounded when the VFO was changed - fixed. Simplified the cw_status logic. A.Ryan - 5B4AIY - 26/NOV/2017
 Build 5
 When the CW Keyer Mode is set to Straight, and a real Vibroplex key connected, there is a marked tendency for 'scratchy dots'. An examination of the
 key waveform shows significant contact bounce on initial contact closure, and indeed, it would be surprising if this did not occur considering that in
 order to produce automatic dots there is a very springy contact. The bounce interval rarely extends beyond about 6mSec, and so the 1mS interrupt timer
 was modified to suppress the contact bounce. A new variable cb_suppression was introduced, and is normally set to zero. On the first detected contact
 closure this variable is set to the contact bounce suppression time, CB_SUPPRESSION_TIME, defined in juma_trx2.h. All contact closures and opens are
 now ignored until cb_suppression has been decremented to zero in the 1mS timer interrupt handler. This effectively suppresses the contact closure
 bounce without using any delays, and has no effect on the maximum speed. A.Ryan - 5B4AIY - 27/DEC/2017
 Build 6
 Further optimisation of the Vibroplex contact bounce suppression. The key_state flag can be used to ensure that the contact bounce suppression timer
 is only set once at the first contact closure detection. A.Ryan - 5B4AIY - 11/JAN/2018

 5.0a
 Build 1
 This build optimises the bandwidths when using the FL-2 active filter. This filter has both narrower bandwidths and steeper skirts compared to the previous
 filter, and therefore some adjustment of the operating parameters is required. In particular, the WIDE SCAF bandwidth setting is now redundant since the
 widest bandwidth available is determined by the active filter. Therefore, this bandwidth setting has been removed. In addition, the widest SCAF bandwidth
 has been altered for the new WIDE setting to accommodate. Whilst this version does not remap the EEPROM, it is advisable to make a note of your calibration
 and configuration settings prior to loading this firmware. A.Ryan - 5B4AIY - 01/OCT/2018
 Build 2
 Modified serial_trx2.c to retain compatibility with F6DEX's control program. Modified Kenwood_CAT.c so that the filter select command now both selects the
 desired filter as well as set its bandwidth. A.Ryan - 5B4AIY - 03/OCT/2018
 Build 3
 Modified the response to the SH (Set/Read Filter Frequency) command in Kenwood_CAT.c In the Kenwood transceiver the filter cut-off frequencies range from
 1.4kHz to 5kHz. Setting the Juma's SCAF filter to anything higher than 2.5kHz is pointless as the active filter's cut-off frequency is 2.5kHz. Therefore,
 in order to more optimally use the transceiver's capabilities the cut-off frequencies are set between 500Hz and 2.7kHz in 200Hz increments in response to
 a filter set command. Equally when reporting the frequency 500Hz is 00, and 2.7kHz is 11, and the steps are 200Hz. A.Ryan - 5B4AIY - 04/OCT/2018
 Build 4
 Modified and optimised cw_speed() to remove two redundant lines of code. A.Ryan - 5B4AIY - 06/OCT/2018
 Build 5
 Minor modifications to the Serial Test Suite to accommodate the revised bandwidth changes. Remove tone_counter delay check in the change of status beep code
 at the end of the main loop. The delay introduced to suppress mode change glitches was taken care of elsewhere, and so was unnecessary. A.Ryan - 5B4AIY - 19/NOV/2018
 Build 6
 Added an extended command to the Yaesu commands to alter the receiver bandwidth. Note: This is not part of the standard Yaesu command set. It relies on the
 CAT program accepting user-defined commands. To set the bandwidth to NARROW, the command string is: 00 00 00 00 E8. To set the bandwidth to WIDE, the command
 string is: 01 00 00 00 E8. A.Ryan - 5B4AIY - 26/NOV/2018
 Build 7
 Added an extra selection to the RS-232 Mode. In all previous versions if you did not intend to use the port you simply disconnected and left it open. However,
 if something was actually connected to the port and the Test mode had been selected, this could seriously confuse the transceiver, even leading to crashing the
 operating system. This version adds the "Disabled" selection which clears the buffer pointers every time round the main loop ensuring that no characters are
 ever received. A.Ryan - 5B4AIY - 10/MAY/2019
 Build 8
 Modified the User Configuration menu so that if the serial port mode is set to DISABLED, then the port speed adjustment page is skipped.
 A.Ryan - 5B4AIY - 30/JUN/2019
 */
// Include files
#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include <ctype.h>
#include "juma-trx2.h"						// JUMA-TRX2 hardware specific definitions
#include "DataEEPROM.h"						// EEPROM mapping
#include "trx2_eeprom.h"					// EEPROM storage structure

// Out-Of-Band Character
// (Not used in this version which blinks the decimal point when out-of-band Adrian Ryan - 5B4AIY 23/JUN/12)
//#define OUT_OF_BAND	0xA1					// Out-Of-Band character (Standard, 3x3 pixels, centre pixel blank
//#define OUT_OF_BAND	0xA5					// Out-Of-Band character (Alternative, smaller 2x2 pixels

// External Functions
extern void lcd_putch(unsigned char);       // Added - 5B4AIY
extern void ClearUSART1queue(void);			// Added - 5B4AIY, located in file: uart.c
extern void ClearUSART2queue(void);			// Added - 5B4AIY, located in file: uart2.c
extern void clear_buffer(void);				// Clear TRX-2/Kenwood/Yaesu command buffer (serial_trx2.c)
extern void serial_kenwood(void);			// Kenwood CAT protocol handler (Kenwood_CAT.c)
extern void reset_state(void);				// Juma TRX-2/PA-100D TRX-Manager Protocol state initialisation (serial_trx2.c)

extern void us_delay(unsigned int);			// Delay routines
extern void ms_delay(unsigned int);

extern void init_timers_pwm(void);			// Timers & PWM DAC
extern void init_scaf_clock(void);			// Initialise SCAF clocking
extern void set_scaf_clock(unsigned int);	// SCAF filter clock divider

extern void beep(int, int);					// Generate beep, period, length

extern void dds_load(unsigned long);
extern void dds_init(void);

extern void init_adc12(void);
extern int convert_adc12(unsigned int);		// ADC

// LCD functions (lcd-trx2.c)
extern void display_screen(const char *, const char *);
extern void display_line(int, const char *);
extern void draw_s_meter(int);
extern void lcdoutch(unsigned char);
extern void lcd_putst(register const char *);
extern void scroll_LCD(int, unsigned char);
extern void set_ch_bits(int, int);
extern void set_chgen(int);
extern void initlcd(void);
extern void lcd_cmd(unsigned char);
extern void disp_freq(long);
extern void disp_rit(int);
extern void disp_meter(double, int);		// New version - 5B4AIY (in lcd-trx2.c)

extern void InitUSART1(void);				// UART1 / Terminal Functions
extern void SetUSART1baud(int);				// Baud rate select
extern void putch(char);
extern int kbhit(void);
extern unsigned char getch(void);

extern void InitUSART2(void);				// UART2 / Secondary UART (Voice Memory Option)
extern void SetUSART2baud(int);
extern void putst2(const char *);

extern void init_spi1(void);				// SPI, main board 74HC595 I/O latch
extern void exchg_data_spi1(unsigned int);

extern void encoder_init(void);				// VFO encoder functions (enc-trxx2.c)
extern int encoder_get(void);
extern int encoder_get_coarse(int);
extern void reset_encoder(void);

extern void service(void);					// Service functions
extern void display_svc_page(void);

extern void serial_test(void);				// Serial I/O
extern void serial_yaesu(void);				// Yaesu CAT emulator
extern void serial_trx2(int);				// JUMA-TRX2 protocol
extern void serial_ext_kb(void);			// External keyboard (Voice Memory control)
extern void uart2_ext_kb(void);				// UART2 / AUX external kb handler

extern void init_isd1700(void);				// Initialise the ISD1700 voice memory system
extern void skip_page(int, int *);			// Located in service.c

// External Variables
extern int auto_inform;						// Used in serial_trx2.c
extern int A_equals_B_flag;					// Used in serial_trx2.c
extern int cw_period;						// Defines the period of a CW unit, in mSec. (timers_pwm.c)
extern int decay_counter;					// Used to define the time the peak power is displayed.
extern int no_adj;							// Adjustment inhibit flag in Calibration & Setup and User Configuration modes.
extern int cal_page;						// Point to Region Setting
extern int swr_al_dly;						// SWR alarm activation delay counter

extern unsigned int ms_counter;				// Millisecond counter in timers_pwm.c
extern unsigned char enc_event;				// VFO encoder moved flag.
extern unsigned int tone_counter;
extern unsigned int scroll_direction;		// LCD Scroll, 0 = Left, 1 = Right (lcd-trx2.c)
extern char dividing_line[];

// Processor Configuration
_FOSC(CSW_FSCM_OFF & EC);					// 30MHz clock = 7,5MHz cycle
_FWDT(WDT_OFF);                				// Turn off the Watch-Dog Timer.
//_FBORPOR(MCLR_EN & PWRT_64 & BORV_20);   	// Enable MCLR, power on timer, Brown out 2V
_FBORPOR(MCLR_EN & PWRT_64 & BORV_27);   	// Enable MCLR, power on timer, Brown out 2.7V - Changed to eliminate fatal compile time error - 5B4AIY
//_FGS(GEN_PROT);            				// Disable Code Protection, old compiler
_FBS(CODE_PROT_OFF);
_FSS(CODE_PROT_OFF);
_FGS(CODE_PROT_OFF);

// Global Variables
// ================================================================================================================
// Frequency decade steps for 180 MHz master clock
const long f_steps[] = {			// Indexed by Tuning_Step
						1,			// 0 - 1Hz
						10,			// 1 - 10Hz
						100,		// 2 - 100Hz
						1000,		// 3 - 1kHz
						10000,		// 4 - 10kHz (Not Used)
						100000		// 5 - 100kHz (Not Used)
						};

const long rf_filt_attn[] = {		// Filter change points, used to set rf_filt_idx
							K300,	// 300kHz	0
							K600,	// 600kHz	1
							M1,		// 1MHz		2
							M2,		// 2MHz		3	160m
							M4,		// 4MHz		4	80m
							M8,		// 8MHz		5	40m
							M12,	// 12MHz	6	30m
							M15,	// 15MHz	7	20m
							M19,	// 19MHz	8	17m
							M23,	// 23MHz	9	15m
							M26		// 26MHz	10	12m (10m is index = 11)
							};

const unsigned int rf_filter_bits[] = {			// Indexed by: rf_filt_idx
										0x0000,	// 0	300kHz
										0x0100,	// 1	600kHz
										0x0200,	// 2	1MHz
										0x0300,	// 3	160m
										0x0400,	// 4	80m
										0x0500,	// 5	40m
										0x0600,	// 6	30m
										0x0600,	// 7	20m
										0x0700,	// 8	17m
										0x0700,	// 9	15m
										0x0700,	// 10	12m
										0x0700	// 11	10m
										};

/* Morse Characters
 In this method, a single character is used for each Morse symbol. The upper nibble contains the length of the symbol,
 and the lower nibble contains the encoded symbol in reverse order. For example, whilst the letter Q is --.- it is
 encoded as -.--
 
 A dot is a binary zero, and a dash is a binary 1, thus the letter 'Q' (--.-) is encoded as:

 Bit 7  6  5  4  3  2  1  0
     1  0  0  0  1  0  1  1
    |_______||_____________|
        |           |
	  Length     Symbol

 The number '8' (---..) is encoded as:

 Bit 7  6  5  4  3  2  1  0
     1  0  1  0  0  1  1  1
    |_______||_____________|
        |           |
	  Length     Symbol

 The upper 3 bits of the nibble (Bits 7 - 5) will always contain a value from 1 to 5 signifying the number
 of elements to the symbol. A length from 1 to 4 indicates a letter, whilst 5 indicates it is a number.
 */
 
const unsigned char morse_symbols[] = {
						0b10111111,		// 0	0 - Numbers
						0b10111110,		// 1	1
						0b10111100,		// 2	2
						0b10111000,		// 3	3
						0b10110000,		// 4	4
						0b10100000,		// 5	5
						0b10100001,		// 6	6
						0b10100011,		// 7	7
						0b10100111,		// 8	8
						0b10101111,		// 9	9	Limit index value for numbers
						0b01000010,		// 10	A - Letters (Offset = 10)
						0b10000001,		// 11	B
						0b10000101,		// 12	C
						0b01100001,		// 13	D
						0b00100000,		// 14	E
						0b10000100,		// 15	F
						0b01100011,		// 16	G
						0b10000000,		// 17	H
						0b01000000,		// 18	I
						0b10001110,		// 19	J
						0b01100101,		// 20	K
						0b10000010,		// 21	L
						0b01000011,		// 22	M
						0b01000001,		// 23	N
						0b01100111,		// 24	O
						0b10000110,		// 25	P
						0b10001011,		// 26	Q
						0b01100010,		// 27	R
						0b01100000,		// 28	S
						0b00100001,		// 29	T
						0b01100100,		// 30	U
						0b10001000,		// 31	V
						0b01100110,		// 32	W
						0b10001001,		// 33	X
						0b10001101,		// 34	Y
						0b10000011		// 35	Z	Limit index value for letters
						};

const unsigned int morse_mode[] = {
						0b0000000010000010,	// 0 NULL-L	LSB
						0b0000000001100100,	// 1 NULL-U	USB
						0b0100000110000101,	// 2 NC		CW (Normal)
						0b0110001010000101,	// 3 RC		CW (Reverse)
						0b0100000100100001	// 4 NT		Tune
						};

const unsigned char morse_filter[] = {
						0b01000001,			// N - Narrow
						0b01100110			// W - Wide
						};

const char firmware[] = {"\n\r%s Firmware: %s Build: %s Date: %s"};
const char copyright[] = {"\n\rCopyright: Juha Niinikoski - OH2NLT & Matti Hohtola - OH7SV\n\r"};
const char added_features[] = {"(Additional features and modifications - Adrian Ryan - 5B4AIY)\n\r"};

// Standard User Interface Displays
const char Hello[] = {"%-10s%6s"};
const char Select_VFO_msg[] = {"   Select VFO   "};
const char VFO_Lock_msg[] = {"  Toggle Lock   "};
const char vfo_locked[] = {"VFO-%c is locked!"};
const char copy_vfo[] = {"Copy VFO%c %c %3s%c"};
const char out_of_band[] = {"  Out Of Band!  "};
const char TX_Disabled[] = {"  TX Disabled!  "};
const char Invalid_Mode[] = {"  Invalid Mode! "};
const char user_mem_locked[] = {"User Mem Locked!"};
const char selected_band[] = {"Band Select:%3im"};
const char save_to_band[] = {"Saved to:%6im"};
const char CW_rls_prompt[] = {"Delay:%10s"};
const char PWR_No_MODE_Yes[] = {"PWR:No  MODE:Yes"};
const char Display_Amps[] = {"  -.--A"};
const char Emergency[] = {"   Emergency    "};
const char Shutdown[] = {"    Shutdown    "};
const char Loop_Back_Test[] = {"Serial Port Test"};
const char Awaiting_Data[] = {"Awaiting data..."};
const char Overcurrent_Alm[] = {"  Over Current! "};
const char High_SWR_Alm[] = {"    High SWR!   "};
const char Over_Voltage_Alm[] = {"  High Voltage! "};
const char Under_Voltage_Alm[] = {"  Low Voltage!  "};
const char Low_Battery_Alm[] = {"  Low Battery!  "};
const char Display_TX[] = {" TX"};
const char Display_SWR[] = {"SWR--.-"};
const char Display_Splt[] = {"Splt"};
const char Display_JUMA_TRX2[] = {"JUMA-TRX2"};
const char Display_OH2NLT_OH7SV[] = {"  OH2NLT-OH7SV  "};
const char Display_ChkSumErr[] = {" Checksum Error "};
const char Display_Load_Defaults[] = {"Loading Defaults"};
const char Calibration[] =      {"  Calibration"};
const char Calibration_Mode[] = {"  Mode%7s"};
const char s9_plus_msg[] = {"S9+%2idB  "};
const char s9_msg[] = {"S%-8i"};
const char Display_Attenuator[] = {"Attenuator:%3idB"};
const char Display_RX_Data[] = {"RX Data: %c  0x%2.2X"};
const char baud_rate_msg[] = {"\n\rUART1        : %i00 Baud\n\r"};
const char Display_System_Clk[] = {"System Clock :%5i kHz\n\r"};
const char VM_Option_Found[] = {"Voice Memory : %sInstalled\n\r"};
const char Display_EEPROM_Chksum[] = {"Cal Checksum : %s\n\rUser Checksum: %s\n\rReset Counter: %d\n\r"};
const char Display_UART2_msg[] = {"JUMA-TRX2 UART2 fixed at 9600 bd\n\r"};
const char eeprom_msg[] = {"\n\rWords   :%5d\n\rChecksum:%5.4X\n\r"};
const char _16s[] = {"%-16s"};
const char User_Menu[] = {"      User"};
const char Configuration_Msg[] = {" Configuration"};
const char rbs_fmt[] = {"%7s"};
const char Auto_Freq_fmt[] = {"Freq:%7.3f MHz"};
const char dsp_atten_fmt[] = {"%4dm "};
const char Release_PTT_msg[] = {"  Release PTT"};
const char Complete_msg[] = {" to complete..."};
const char Equalisation[] = {"  Equalisation"};
const char Completed[] = {"   Completed!"};
const char Aborted[] = {"    Aborted!"};
const char press_and_hold_msg[] = {" Press and hold"};
const char PTT_to_start_msg[] = {"PTT to start..."};
const char Automatic[] = {"  Automatic RF"};
const char OP_Equalisation[] ={"O/P Equalisation"};
const char Proceed[] = {"    Proceed?"};
const char PWR_Exits[] = {" PWR to exit..."};
const char Ref_Band_msg[] = {" <- Reference Band"};
const char CW_Practice_Msg[] = {"CW Practice Mode"};
const char Speed_Space_fmt[] = {"WPM:%2d  SPACE:%2d"};
const char Select_Type_fmt[] = {"Select:%9s"};
const char Number_Of_Groups_fmt[] = {"Groups:%9d"};
const char FILTER_Next_msg[] = {"Continue: FILTER"};
const char FILTER_Start_msg[] = {" FILTER = Start "};
const char f_fmt[] = {"%5.0f"};
const char CW_Practice_fmt[] = {"%s%20s\n\r%.29s%s"};
const char CW_Practice_msg[] = {"CW PRACTICE"};
const char line_space[] = {"%.29s%s"};

// User Configuration Prompts (Line 2)
const char dp_0_msg[] = {"AGC Speed:%6s"};			// Adjust AGC Speed - Fast/Slow
const char dp_1_msg[] = {"%3s LPF:%5li Hz"};		// Adjust Filter Bandwidths (Narrow/Wide/Tx)
const char dp_2_msg[] = {"Audio I/P:%6s"};			// Select Audio I/P - Mic/Line
const char dp_3_msg[] = {"Processor:%6s"};			// Adjust Speech Processor - On/Off
const char dp_4_msg[] = {"Keyer:%10s"};				// Select Keyer - Dot Priority/Iambic A/Iambic B/Vibroplex/Straight
const char dp_5_msg[] = {"Delay:%8imS"};			// CW Release Delay (Only in Straight Mode, skipped otherwise)
const char dp_6_msg[] = {"CW Pitch:%4i Hz"};		// Adjust CW Pitch
const char dp_7_msg[] = {"CW Pot:%9s"};				// Select CW Pot Mode, CW Speed/Squelch
const char dp_8_msg1[] = {"Locked:%6iwpm"};			// Default CW Speed Locked
const char dp_8_msg2[] = {"Unlocked:%4iwpm"};		// Default CW Speed Unlocked, adjust with RIT knob
const char dp_9_msg[] = {"CW/CWR Swap:%4s"};		// Adjust CW/CWR Swap On/Off
const char dp_10_msg[] = {"Backlight:%6i"};			// Adjust Backlight
const char dp_11_msg[] = {"Contrast:%7i"};			// Adjust Contrast
const char dp_12_msg1[] = {"%10s%4i S"};			// Adjust LCD Timer 1 - 3600 seconds
const char dp_12_msg2[] = {"%10s%6s"};				// Adjust LCD Timer Off
const char dp_13_msg[] = {"RS232:%10s"};			// Select RS232 Mode - Yaseu CAT/Kenwood CAT/Juma TRX2/Test Mode/Voice Memory
const char dp_14_msg[] = {"Baud Rate:%4i00"};		// Select Baud Rate 1200 - 115200 Baud
const char dp_15_msg1[] = {"%-11s(CAT)"};			// Display locked VFO mode, A/B-Split (CAT)
const char dp_15_msg2[] = {"VFO: 2%10s"};			// A/B-Split Mode
const char dp_15_msg3[] = {"VFO:%2i Memory:%2i"};	// Adjust number of VFOs - 3 - 26 VFOs
const char dp_17_msg[] = {"S-Meter:%8s"};			// Select S-Meter - Graphic/Numeric
const char dp_18_msg[] = {"Hold Time:%6.2f"};		// Adjust S-Meter Hold Time
const char dp_19_msg[] = {"TX Disable:%5s"};		// Adjust TX Disable - Off/On
const char dp_20_msg[] = {"Auto USB/LSB:%3s"};		// Adjust Auto USB/LSB - Off/On
const char dp_21_msg[] = {"Display:%8s"};			// Select Frequency Display - Original/New/Fixed-A/Fixed-B
const char dp_23_msg[] = {"Include RIT:%4s"};		// Adjust Include RIT On/Off
const char dp_24_msg[] = {"Tune Atten:%3idB"};		// Select Tune Attenuation - 0dB/1dB/2dB/3dB
const char dp_25_msg[] = {"VFO Adj:%8s"};			// Select VFO Adj Off/10Hz/100Hz-10Hz/All
const char dp_30_msg1[] = {"Select:%9s"};			// Select CW Annunciation Off
const char dp_30_msg2[] = {"%2dWPM Type:%5s"};		// Select CW Annunciation Full/Freq
const char dp_4s_11s_fmt[] = {"%4s:%11s"};			// Format descriptor used by display pages 16-22-26-27-28-29 and in service.c

// Common Prompts
const char _mode[] = {"Mode"};
const char _type[] = {"Type"};
const char _page[] = {"Page"};
const char _lcd_timer[] = {"LCD Timer:"};
const char _a_b_split[] = {"A/B-Split"};
const char Scroll_Msg[] = {"Scroll LCD:%5s"};

// Serial Messages
const char Settings_Saved_EEPROM[] = {"\n\rUser settings saved to EEPROM, Power OFF\n\r"};
const char RS232_Test_Exit[] = {"\n\rRS-232 Test\n\rPress PWR button to exit...\n\r"};
const char RS232_Test_Terminated[] = {"\n\rRS-232 Test Terminated\n\r"};
const char Press_Hold[] = {"Press and hold the PTT switch to start..."};
const char Equalising[] = {"\n\rEqualising...\n\r"};
const char Averaged_Pwr[] = {"Band:%4im Average Power:%5.1fW : %+4.1fdBm\n\r"};
const char New_Line[] = {"\n\r"};
const char Band_Atten[] = {"Band:%4im Rel Power:%+6.2fdB Attenuator:%3idB%s\n\r"};
const char Release_PTT[] = {"Release the PTT switch to complete...\n\r"};
const char Test_Msg[] = {"\n\r****************Extended Serial Test Suite***************\n\r"};

// Tuning steps: 0 = S (1Hz), 1 = M (10Hz), 2 = F (100Hz), 3 = V (1kHz), and 4 = X (10kHz) (Not Used)
// Avago Technologies HRPG-ASC-11R Optical Rotary Encoder - 120 counts/revolution.
const char tuning_step[] = {			// Indexed by: Tuning_Step
						'S',			// 0 - Slow, 1Hz (480Hz/turn)
						'M',			// 1 - Medium, (Default) 10Hz (4.8kHz/turn)
						'F',			// 2 - Fast, 100Hz (48kHz/turn)
						'V',			// 3 - Very Fast, 1kHz (480kHz/turn)
						'X'				// 4 - eXtra Fast, 10kHz (4.8MHz/turn)
						};
// Prompt Messages
const char *cw_annunciation_msg[] = {
						"Off",
						"Full",
						"Freq"
						};

const char *Message_Type[] = {			// Indexed by: type in CW Practice Mode
						"LETTERS",		// 0
						"NUMBERS",		// 1
						"MIXED"			// 2
						};

const char *s_meter_type[] = {			// Indexed by: eeprom.defval.S_Meter_Type
						"Graphic",		// 0
						"Numeric"		// 1
						};

const char *agc_speed_msg[] = {			// Indexed by: AGC_speed
						"Slow",			// 0
						"Fast"			// 1
						};

const char *audio_input[] = {			// Indexed by: AF_Input
						"Line",			// 0
						"Mic"			// 1
						};

const char *cw_spd_pot[] = {			// Indexed by: eeprom.defval.sq
						"CW Speed",		// 0
						"Squelch-A",	// 1
						"Squelch-B"		// 2
						};

const char *band_limits[] = {			// Indexed by: cal.calval.Band_Limits
						" IARU Region 1  ",	// 0
						" USA   (Extra)  ",	// 1
						" USA  (General) "	// 2
						};

const char *on_off[] = {
						"Off",			// 0
						"On"			// 1
						};

const char *mode_msg[] = {				// Indexed by: eeprom.defval.mode[vfo_idx], eeprom.defval.mode[Select_VFO], eeprom.defval.mode[src_vfo]
						"LSB ",			// 0
						"USB ",			// 1
						"CW  ",			// 2
						"CWR ",			// 3
						"Tune"			// 4
						};

const char *band_sw_msg[] = {			// Indexed by: RBS_Mode Do not make these variable length strings, lcd_putst() uses them.
						"Default",		// 0
						" Mode-A",		// 1
						" Mode-B",		// 2
						" Locked",		// 3
						" Mode-C"		// 4
						};

const char *filter_width[] = {			// Indexed by: RX_Bandwidth
						"[N]",			// 0
						"[W]",			// 1
						" Tx"			// 2
						};

const char *keyer_msg[] = {				// Indexed by: Keyer_Mode
						"Dot Pri.",		// 0
						"Iambic A",		// 1
						"Iambic B",		// 2
						"Vibroplex",	// 3
						"Straight"		// 4
						};

const char *rs232_mode[] = {			// Indexed by: eeprom.defval.serial_mode
						"Disabled",		// 0
						"Yaesu CAT",	// 1
						"KenwoodCAT",	// 2
						"JUMA TRX2",	// 3
						"Test Mode",	// 4
						"Voice Mem"		// 5
						};

const char *freq_disp[] = {				// Indexed by: eeprom.defval.Freq_Display
						"Original",		// 0
						"New",			// 1
						"Fixed-A",		// 2
						"Fixed-B"		// 3
						};

const char *vfo_adj[] = {				// Indexed by: eeprom.defval.VFO_Adjust
						"Off",			// 0
						"10Hz",			// 1
						"100/10Hz",		// 2
						"All"			// 3
						};

const char *power_msg[] = {				// Indexed by: eeprom.defval.nb (power_down_mode)
						"Immediate",	// 0
						"Prompted",		// 1
						"Save State"	// 2
						};

const char *save_settings_prompt[] = {	// Indexed by: flag in function: save_settings(), and in _VM_Command() in serial_ext_kb.c, and in CW Practice mode.
						" Save Settings?",	// 0
						" Reset Defaults?",	// 1
						"Erase Voice Mem?",	// 2
						"    Repeat?"		// 3
						};

const char *disp_type[] =	{			// Indexed by: Display_Scale
						"Original",		// 0
						"Large",		// 1
						"Small"			// 2
						};

const char *saved_restored[] = {		// Indexed by: local flag in function: save_settings(), as well as _VM_Command() in serial_ext_kb.c
						"   Cancelled!   ",	// 0
						"     Saved!     ",	// 1
						"     Erased!    "	// 2
						};

const char lock_symbol[] = {			// Indexed by: vfo_lock
						SPACE,			// Unlocked
						'\353'			// Locked (Octal 353)
						};

const char *cw_rls_speed[] = {			// Indexed by: eeprom.defval.sq
						"CW Speed",
						"Preset",		// Duplicating the entry rather than calculating an index saves 15 bytes! A.Ryan - 5B4AIY - 25/MAY/13
						"Preset"
						};

const char *Not_Installed[] = {
						"Not ",
						""
						};

const char *start_page_select[] = {		// Indexed by masked value of display_page
						"Mode/BW",		// 0
						"O/P Power",	// 1
						"SWR",			// 2
						"Voltage",		// 3
						"PA Current",	// 4
						"Last Page"		// 5
						};

const char *pwr_mtr_display[] = {		// Indexed by: eeprom.defval.Power_Meter
						"  --.-W",		// 0 - RX display for power in Watts
						"--.-dBm"		// 1 - RX or very low TX power display in dBm
						};

const char *pwr_mtr_msg[] = {			// Indexed by: eeprom.defval.Power_Meter
						"Watts",		// 0
						"dBm"			// 1
						};

const char *mv[] = {					// Indexed by either result of logic test (0/1) or constant
						"Mem",			// 0
						"VFO"			// 1
					};

const char *eeprom_err[] = {			// Indexed by return flag from read_defval() and read_calval()
						"OK",			// 0
						"Error!"		// 1
							};

const char *direction[] = {				// Indexed by scroll_direction in lcd-trx2.c
						"Left",			// 0
						"Right"			// 1
						};

const char *VFO_Eq_Mode[] = {			// Indexed by eeprom.defval.VFO_Equalisation
						"Off",			// 0	defined as: OFF
						"Split Only",	// 1	defined as: SPLIT_ONLY
						"Splt+Smplx"	// 2	defined as: SPLIT_PLUS_SIMPLEX
						};

const int status_beep[]	= {				// Used for all status/mode changes. Indexed by: Tuning_Step, RX_Bandwidth, eeprom.defval.mode[], beep_number
						HZ392_01,		// 0
						HZ466_85,		// 1
						HZ587_31,		// 2
						HZ698_45,		// 3
						HZ800			// 4
						};

/*
 Initially, the baud rate text was declared as a series of text strings, which used 6 bytes for the characters
 and an additional byte for the string terminator. By declaring the array as a character array and saving the
 1200 baud multiplier value (1, 2, 4, 8, 16, 32, 48, and 96), the array size could be reduced from 56 bytes to only
 8. To display the value, since either sprintf() or printf() was being used, the formatting descriptor was:
 %6li, and the actual value was then: 1200L * eeprom.defval.br[br_txt]. Unfortunately the multiplication added
 more code than the saving in memory! By saving instead the integer values of the speed, and then simply adding
 the two trailing zeros with a format descriptor of %4i00 the memory savings were considerably improved.
 A. Ryan 5B4AIY 11/DEC/2011
*/
const int br_txt[] = {					// Indexed by: Baud_Rate
						12,				// 0
						24,				// 1
						48,				// 2
						96,				// 3
						192,			// 4
						384,			// 5
						576,			// 6
						1152			// 7
					};

/*
 Band prompt digits used in the Rapid Band Switch feature, the first is blank and is never used, but provides
 a place-holder, as the index of valid frequencies is from 1 - 9. If the function returns 0, this is used to
 indicate an out-of-band frequency.
 */
const unsigned char band[] = {
							0,		// 0
							160,	// 1
							80,		// 2
							40,		// 3
							30,		// 4
							20,		// 5
							17,		// 6
							15,		// 7
							12,		// 8
							10		// 9
							};

const unsigned char prompt_index[] = {	// Indexed by page, local variable in display_settings()
							0,		// 0  - "Adjust"
							2,		// 1  - "Adjust Filter BW"
							1,		// 2  - "Select"
							11,		// 3  - "Speech"
							1,		// 4  - "Select"
							5,		// 5  - "CW Release"
							0,		// 6  - "Adjust"
							3,		// 7  - "Select Mode"
							4,		// 8  - "Default CW Speed"
							0,		// 9  - "Adjust"
							0,		// 10 - "Adjust"
							0,		// 11 - "Adjust"
							0,		// 12 - "Adjust"
							1,		// 13 - "Select"
							1,		// 14 - "Select"
							12,		// 15 - "Select VFO Mode"
							13,		// 16 - "VFO Equalisation"
							1,		// 17 - "Select"
							6,		// 18 - "Adjust S-Meter"
							0,		// 19 - "Adjust"
							0,		// 20 - "Adjust"
							7,		// 21 - "Select Frequency"
							14,		// 22 - "Fast Band Switch"
							0,		// 23 - "Adjust"
							1,		// 24 - "Select"
							1,		// 25 - "Select"
							8,		// 26 - "Meter Scale"
							9,		// 27 - "Power Down"
							15,		// 28 - "Power Meter"
							10,		// 29 - "Start-Up Display"
							16		// 30 - "CW Annunciation"
							};

// User Configuration Prompts (Line 1)
const char *user_cfg_prompts[] = {		// Indexed by: prompt_index[*page], local variable in function: display_settings()
							"Adjust",			// 0
							"Select",			// 1
							"Adjust Filter BW",	// 2
							"Select Mode",		// 3
							"Default CW Speed",	// 4
							"CW Release",		// 5
							"Adjust S-Meter",	// 6
							"Select Frequency",	// 7
							"Meter Scale",		// 8
							"Power Down",		// 9
							"Start-Up Display",	// 10
							"Speech",			// 11
							"Select VFO Mode",	// 12
							"VFO Equalisation",	// 13
							"Fast Band-Switch",	// 14
							"Power Meter",		// 15
							"CW Annunciation"	// 16
							};

// Amateur Band Limits for Fast Band Switch and TX Out-Of-Band Inhibit
long upper_limit[] = {
						_160M_UPPER,		// 0 - Place holder
						_160M_UPPER,		// 1
						_80M_UPPER_IARU,	// 2
						_40M_UPPER_IARU,	// 3
						_30M_UPPER,			// 4
						_20M_UPPER,			// 5
						_17M_UPPER,			// 6
						_15M_UPPER,			// 7
						_12M_UPPER,			// 8
						_10M_UPPER			// 9
						};

 long lower_limit[] = {
						_160M_LOWER,		// 0 - Place holder
						_160M_LOWER,		// 1
						_80M_LOWER,			// 2
						_40M_LOWER,			// 3
						_30M_LOWER,			// 4
						_20M_LOWER,			// 5
						_17M_LOWER,			// 6
						_15M_LOWER,			// 7
						_12M_LOWER,			// 8
						_10M_LOWER			// 9
						};

// Centre frequencies of the amateur bands from 160m - 10m. Used by the Fast Bandswitch feature and auto_equalise().
const unsigned long amateur_bands[] = {
									_160M_CENTRE,	// 0
									_80M_CENTRE,	// 1
									_40M_CENTRE,	// 2
									_30M_CENTRE,	// 3
									_20M_CENTRE,	// 4
									_17M_CENTRE,	// 5
									_15M_CENTRE,	// 6
									_12M_CENTRE,	// 7
									_10M_CENTRE		// 8
									};

// Frequency select points for Fast Bandswitch feature.
const unsigned long band_select_freq[] = {
									0L,				// 0 - Dummy value, never used.
									SELECT_160,		// 1
									SELECT_80,		// 2
									SELECT_40,		// 3
									SELECT_30,		// 4
									SELECT_20,		// 5
									SELECT_17,		// 6
									SELECT_15,		// 7
									SELECT_12		// 8
									};

// In order for an out-of-band indication, the upper frequency > lower segment limit and the lower frequency < upper segment limit
// See function: check_freq()
// US General Class lower segment limit
const unsigned long lower_segment_limit[] = {
									0UL,			// 0 - This index is always out-of-band
									30000000UL,		// 1 - 160m Dummy value, place holder
									3600000UL,		// 2 - 80m
									7125000UL,		// 3 - 40m
									30000000UL,		// 4 - 30m Dummy value, place holder
									14150000UL,		// 5 - 20m
									30000000UL,		// 6 - 17m Dummy value, place holder
									21200000UL,		// 7 - 15m
									30000000UL,		// 8 - 12m
									30000000UL		// 9 - 10m
									};

// US General Class upper segment limits
const unsigned long upper_segment_limit[] = {
									30000001UL,		// 0 - This index is always out-of-band
									0UL,			// 1 - 160m Dummy value, place holder
									3800000UL,		// 2 - 80m
									7175000UL,		// 3 - 40m
									0UL,			// 4 - 30m Dummy value, place holder
									14225000UL,		// 5 - 20m
									0UL,			// 6 - 17m Dummy value, place holder
									21275000UL,		// 7 - 15m
									0UL,			// 8 - 12m
									0UL				// 9 - 10m
									};

// SCAF filter tuning limits
const int scaf_min[] = {			// Upper Limit. Indexed by: RX_Bandwidth
						NAR_SCAF,	// 0 - Narrow	1,293Hz
						MID_SCAF,	// 1 - Wide		2,500Hz
						TX_UPPER	// 2 - Transmit	3,750Hz
						};

const int scaf_max[] = {			// Lower Limit. Indexed by: RX_Bandwidth
						MAX_SCAF,	// 0 - Narrow	500Hz
						NAR_SCAF,	// 1 - Wide		1,293Hz
						TX_LOWER	// 2 - Transmit	2,273Hz
						};
// ================================================================================================================
void (*RS_232_Mode)(void);		// RS-232 Mode, Yaesu CAT/Kenwood CAT/TRX-2/Voice Memory/Test
const char *user_band_prompt;	// Pointer to the characters for the User Band prompt messages

/*
 Global DDS Variables
 The freq_in_use variable always holds the DDS frequency. In receive it will hold the actual carrier frequency
 for USB and LSB. In the CW modes, (CW / CWR), the DDS frequency is offset by the amount of the CW shift. If
 the mode is CW, the transceiver is set to LSB, and the local oscillator is offset higher in frequency by the
 CW shift. Conversely, if the mode is CWR the transceiver is set to USB, and the local oscillator is offset
 lower in frequency by the amount of the CW shift. If RIT is turned on, then the frequency is further offset
 by the RIT shift.
 In transmit, it will hold the carrier frequency. It is also the frequency that is displayed in both transmit
 and receive. In the receive mode, if Include RIT is on, then this variable is displayed, otherwise it is the
 VFO frequency.
*/
long freq_in_use;				// Frequency currently in use, always used to load the DDS
long offset;					// Offset, for CW/CWR receive frequencies, plus RIT offset, if used.
int vfo_idx;					// VFO index, A = 0, B = 1, if (Split) then  RX = 0, TX = 1
int rit;						// RIT offset frequency (+/- 1kHz maximum.)
int tmp_sub_page0 = 0;			// Used to restore the sub-page when blinking the mode change
int mode_ctr = 0;				// Used as the Mode/Filter blink counter
int rf_filt_idx;				// Index to filter & attenuator bits table

// DDS & Clock Variables
long tx_filter_bw;				// Transmit filter bandwidth upper limit
int fcy;						// Clock / kHz

// Preset transceiver to RX mode. (Prevents initial spurious TX on switch-on.) A.Ryan - 5B4AIY - 21/AUG/2013
int PTT_IN = RECEIVE;			// Copy of PTT_IN_IO input / TX ON, 0 = Active
int dsp1_ctr = 0;				// Used for display blink feature
int dsp2_ctr = 0;
int band_in_use = OUT_OF_BAND;
int split_flag = FALSE;			// Indicates whether Split Frequency operation is active
int svc_flag = FALSE;			// Used to inhibit the drain current hold timer in the Service mode
int latch = FALSE;
unsigned int hc595 = 0;			// SPI bus latch bits

/*
 Alarm System Flag
 0 = No Alarm
 0x01 = Overcurrent
 0x02 = SWR
 0x04 = Overvoltage
 0x08 = Undervoltage
 0x10 = Undervoltage Pre-Limit
 0x2x Display Blank flag set
*/
int alarm_flag = FALSE;			// Alarm Flag, 0 = No Alarms
int loop_ctr = 0;				// Alarm Display Blink Counter 0 = Reset
int adj_attn = FALSE;			// Set when adjusting attenuator

#if MEASURE_CYCLE_TIME
int loop_ctr2 = 0;				// Debug Main Loop timing counter. Set MEASURE_CYCLE_TIME to TRUE to use.
#endif

// Keyer
int keyer_mode = MINUS_ONE;		// 0 = Dot priority, 1 = Iambic-A, 2 Iambic-B, 3 = Straight, -1 = Start-up inhibit (Jan Wieck WI1CK)

// Voice memory option
int isd_1700_installed = FALSE;	// Voice memory board 0 = Not Installed

// System Status Flags
long button_count = DEBOUNCE_COUNT;	// Used in button de-bounce macro (Defined in juma-trx2.h)
int tx_enable = ENABLE;			// 1 = Enable, 0 = Disable
int cw_active = OFF;			// Status flag for keyer module (timers_pwm.c)
int	lcd_mode = NORMAL_DISPLAY;	// LCD display mode
int sub_page0 = 0;				// LCD display sub page for lcd_mode0
int sub_page1 = 0;				// LCD display sub page for lcd_mode1 - AGC Speed
int vfo_lock = OFF;				// VFO knob tune lock
int mute = AUDIO_ON;			// Mute test flag, 1 = Mute, 0 = Audio on
int changed_flag = FALSE;		// Set if User Memory or VFO Memory is changed, cleared in save_defval().
int src_vfo;
int dst_vfo;
int copy_flag = FALSE;
int sense_flag = NORMAL;		// VFO Knob rotation sense - NORMAL - C/W to increase.
int tune_on = OFF;				// TUNE status flag
int beep_number = MINUS_ONE;	// Beep flag and tone index
int delay_time;
int RBS_Flag = OFF;				// Used by the Rapid Band-Switch feature.

unsigned char lcdpbuff[20];		// LCD print buffer, longest display is 16 characters, this is a safety margin.
unsigned char f_buff[6];		// Buffer for frequency characters for CW Annunciation, and CW Practice feature.

// ADC & Meter Variables
double batt_mean_val;			// Battery Voltage x 1,000,000
double power_bar_graph_const;	// Used in display_power_meter()
long fwd_pwr;					// Relative forward power
long rev_pwr;					// Relative reverse power
long out_pwr;					// Scaled output power = (fwd_pwr - rev_pwr) * scale
int batt_raw;					// Raw A-D converter output
int batt_scale_factor;			// Bar Graph Battery Voltage scale factor
int s_meter = 0;				// Scaled S-meter value 0 ... 48
int s_meter_timer;				// Hold time for numeric S-Meter
int s_meter_const;				// S-Meter constant, set in main()
int fwd_adval;					// Forward & Reverse power raw values, measured only when in TX mode
int rev_adval;
int id_raw_value;				// Drain current A-D value
int id_const;					// Bar Graph Drain Current scaling constant
int swr = 0;					// Calculated SWR * 100
int pwr_meter = 0;				// Scaled output power meter bar-graph value 0 ... 48, used in TRX-2 protocol
int cw_pot;						// CW speed potentiometer, also used for squelch
int sq_timer;					// Squelch open timer
int squelch_on;					// Squelch on flag, 0 = OFF, 1 = ON
int bl_timer;					// LCD back light timer(s), 0 = Not In Use
int low_voltage_warning = OFF;	// Pre-shutoff warning voltage, raw ADC value, = Low Voltage Alarm + 100mV

// Morse Code Practice
int dot_time, ics = 3;

// User power on values, EEPROM storage 
int fd_counter;					// Counts how many times factory defaults have reloaded - Changed to int - 5B4AIY
// ================================================================================================================
// User Configuration Settings
union
	{
	struct defval defval;
	unsigned int storage[sizeof(struct defval) / 2];
	} eeprom;

// System Calibration Values
union
	{
	struct calval calval;
	unsigned int ee[sizeof(struct calval) / 2];
	} cal;

// ================================================================================================================
/*
 CRC16 is a simple 16-bit cyclic redundancy checksum that provides a more robust method of checking data than many other methods.
 The routine returns a 16-bit CRC. Obviously, the largest block of data that can be checked is limited to 65536 bytes. For
 successive calls for larger blocks, the contents of the checksum can be left, and this partial CRC can continue to be used.

 The algorithm used is similar to that in many EPROM programmers and also disc drives. In the following notes, Bit 0 is the
 Least Significant Bit, Bit 7 is the Most Significant Bit.

 The routine calculates the CRC starting with Bit 0, then Bit 7, Bit 6, .... Bit 1.

 It relies on the following steps:

 1.	XOR the current data bit with Bit 1 of the current checksum,
 2.	XOR the result of Step 1 with Bit 3 of the checksum,
 3.	XOR the result of Step 2 with Bit 5 of the checksum,
 4.	XOR the result of Step 3 with Bit 14 of the checksum,
 5.	Multiply the checksum by 2, discarding any carry from the MSB,
 6.	Add the result of Step 4 to the result of Step 5.

 Steps 1 through 6 are repeated for all subsequent bits in the data byte. The entire process is repeated for all subsequent bytes.
 Thus, if the bit values in the CRC register are:

  15  14  13  12  11  10   9   8   7   6   5   4   3   2   1   0
   a   b   c   d   e   f   g   h   i   j   k   l   m   n   o   p

 and x is the current data bit value, y is the partial result, and ^ represents XOR, then the calculation for steps 1 through 4 is:

	y = ( ( ( ( x ^ o ) ^ m ) ^ k ) ^ b )

 After the left shift (multiply by 2) in Step 5, and the addition in step 6, the bits in the CRC register are:

  15  14  13  12  11  10   9   8   7   6   5   4   3   2   1   0
   b   c   d   e   f   g   h   i   j   k   l   m   n   o   p   y

 To give an example, suppose we wish to calculate the CRC for three bytes of data: C3, 55, AA. If we start with the CRC = 0, then
 the following steps will result (The HEX value is the result after the operation):

	DATA  BIT  VALUE RESULT         CHECKSUM         HEX
	========================================================
	C3     0     1     1      0000 0000 0000 0001    0001
           7     1     1      0000 0000 0000 0011    0003
           6     1     0      0000 0000 0000 0110    0006
           5     0     1      0000 0000 0000 1101    000D
           4     0     1      0000 0000 0001 1011    001B
           3     0     0      0000 0000 0011 0110    0036
           2     0     0      0000 0000 0110 1100    006C
           1     1     1      0000 0000 1101 1001    00D9

	55     0     1     0      0000 0001 1011 0010    01B2
           7     0     0      0000 0011 0110 0100    0364
           6     1     0      0000 0110 1100 1000    06C8
           5     0     1      0000 1101 1001 0001    0D91
           4     1     1      0001 1011 0010 0011    1B23
           3     0     0      0011 0110 0100 0110    3646
           2     1     0      0110 1100 1000 1100    6C8C
           1     0     0      1101 1001 0001 1000    D918

	AA     0     0     0      1011 0010 0011 0000    B230
           7     1     0      0110 0100 0110 0000    6460
           6     0     0      1100 1000 1100 0000    C8C0
           5     1     0      1001 0001 1000 0000    9180
           4     0     0      0010 0011 0000 0000    2300
           3     1     1      0100 0110 0000 0001    4601
           2     0     1      1000 1100 0000 0011    8C03
           1     1     0      0001 1000 0000 0110    1806

 Final Checksum = 0x1806
*/

unsigned int crc_1(unsigned char data, unsigned int csum)
	{
	data &= 0x01;							// Extract data bit
	data ^= (csum >> 1);					// Step 1
	data ^= (csum >> 3);					// Step 2
	data ^= (csum >> 5);					// Step 3
	data ^= (csum >> 14);					// Step 4
	csum <<= 1;								// Step 5
	return csum + (data & 0x0001);			// Step 6
	}

unsigned int crc_8(unsigned char data, unsigned int csum)
	{
	int i = 7;

	csum = crc_1(data, csum);						// Bit 0

	do {
		csum = crc_1((data >> i), csum);			// Bits 7 through 1
		} while(--i);

	return csum;
	}

unsigned int crc_16(unsigned int data, unsigned int csum)
	{
	csum = crc_8((unsigned char)data, csum);		// Low byte
	return crc_8((unsigned char)(data >> 8), csum);	// Low byte plus High byte
	}

// Save User Configuration Data
void save_defval(void)
	{
	int i;

	if((display_page & 0x07) == LAST_PAGE && lcd_mode == NORMAL_DISPLAY)
		display_page = LAST_PAGE + (sub_page0 << 4);	// Save the current display page

	eeprom.defval.d_csum = 0;

	for(i = 0; i < (sizeof(struct defval) / 2); i++)	// Size is returned in bytes, (316) but array eeprom.storage[] is in words.
		{
		if(i < ((sizeof(struct defval) / 2) - 1))
			eeprom.defval.d_csum = crc_16(eeprom.storage[i], eeprom.defval.d_csum);

 		EraseEE(EEPAGE, ((2 * i) + EEDEF), WORD);
		WriteEE((int *)&(eeprom.storage[i]), EEPAGE, ((2 * i) + EEDEF), WORD);	// EEPROM Address 8 high bits, address + physical EEPROM start 16 low bits - Added cast 5B4AIY
		}

	if(Serial_Mode == SERIAL_TEST) printf(eeprom_msg, i, eeprom.defval.d_csum);	// Only print in RS-232 Test Mode

	changed_flag = FALSE;
	}

// Read User Configuration Data
unsigned int read_defval(void)
	{
	int i;
	unsigned int checksum = 0;

	for(i = 0; i < (sizeof(struct defval) / 2); i++)	// Size is returned in bytes, (316) but array eeprom.storage[] is in words.
		{
		ReadEE(EEPAGE, ((2 * i) + EEDEF), (int *)&(eeprom.storage[i]), WORD);	// EEPROM Address 8 high bits, address + physical EEPROM start 16 low bits - Added cast 5B4AIY
		if(i < ((sizeof(struct defval) / 2) - 1)) checksum = crc_16(eeprom.storage[i], checksum);
		}

// Read factory defaults reset counter
	ReadEE(EEPAGE, EE_FD_LOC, &fd_counter, WORD);
	return (checksum != eeprom.defval.d_csum);
	}

// Save Calibration Values
void save_calval(int prt_flag)
	{
	int i;

	cal.calval.c_csum = 0;

	for(i = 0; i < (sizeof(struct calval) / 2); i++)							// Size is returned in bytes, (46) but array cal.ee[] is in words.
		{
		if(i < ((sizeof(struct calval) / 2) - 1))
			cal.calval.c_csum = crc_16(cal.ee[i], cal.calval.c_csum);

		EraseEE(EEPAGE, ((2 * i) + EECAL), WORD);
		WriteEE((int *)&(cal.ee[i]), EEPAGE, ((2 * i) + EECAL), WORD);			// EEPROM Address 8 high bits, address + physical EEPROM start 16 low bits - Added cast 5B4AIY
		}

	if(prt_flag && (Serial_Mode == SERIAL_TEST)) printf(eeprom_msg, i, cal.calval.c_csum);	// Only print in Test Mode
	}

// Read Calibration Values
unsigned int read_calval(void)
	{
	int i;
	unsigned int checksum = 0;

	for(i = 0; i < (sizeof(struct calval) / 2); i++)					// Size is returned in bytes, (46) but array cal.ee[] is in words.
		{
		ReadEE(EEPAGE, ((2 * i) + EECAL), (int *)&(cal.ee[i]), WORD);	// EEPROM Address 8 high bits, address + physical EEPROM start 16 low bits - Added cast 5B4AIY
		if(i < ((sizeof(struct calval) / 2) - 1)) checksum = crc_16(cal.ee[i], checksum);
		}

	return (checksum != cal.calval.c_csum);
	}

// Set factory defaults for EEPROM storage. (See trx2_eeprom.h for mapping details.)
void set_factory_defaults(void)
	{
	int i = 2, j = 0;
// User settings
	eeprom.defval.vfo[VFO_A] = DEFAULT_FREQ_A - 5000;	// 3.505MHz
	eeprom.defval.vfo[VFO_B] = DEFAULT_FREQ_A;			// 3.6MHz
	eeprom.defval.mode[VFO_A] = LSB;					// Lower Sideband
	eeprom.defval.mode[VFO_B] = LSB;					// Lower Sideband

// Fill the remaining VFO memories with the amateur band frequencies
	do	{
		if(i == 30) j = 0;							// Reset amateur_bands[] index for the RBS default frequencies

		eeprom.defval.vfo[i] = amateur_bands[j % 9];
		eeprom.defval.mode[i] = (eeprom.defval.vfo[i] < 10000000L)
							? LSB					// 160/80/40
							: USB;					// 30/20/17/15/12/10
		j++;
		} while (++i < 39);

	eeprom.defval.vfo[39] = 0;						// Spare Location (Not Used - 4 bytes)
	eeprom.defval.mode[39] = MODE_BW;				// Spare Location. Now used as the start-up display page. Default = Mode/BW
	eeprom.defval.step_idx = TEN_HZ;				// 10Hz tuning rate. (0 = 1Hz, 1 = 10Hz, 2 = 100Hz, 3 = 1kHz)
	eeprom.defval.vfo_sel = VFO_A;					// VFO-A
	eeprom.defval.max_vfo = SPLIT_MODE;				// A/B + Split
	eeprom.defval.VFO_Equalisation = SPLIT_ONLY;	// VFO Equalisation mode, only when SPLIT is active
	eeprom.defval.rit_on = OFF;						// RIT OFF
	eeprom.defval.agc_speed = SLOW;					// AGC Slow
	eeprom.defval.proc_on_off = OFF;				// Speech Processor OFF
	eeprom.defval.nb = PROMPTED;					// Data-point now used for Fast Power Off feature. 0 = Immediate, 1 = Prompted, 2  = Save State
	eeprom.defval.filter = WIDE;					// WID, for Matti
	eeprom.defval.contrast = DEFAULT_CONTRAST;		// 2000
	eeprom.defval.back_light = DEFAULT_BL;			// 350
	eeprom.defval.back_light_timer = OFF;
	eeprom.defval.scaf_filters[NARROW] = DEFAULT_NAR;	// Default narrow bandwidth, 1kHz
	eeprom.defval.scaf_filters[WIDE] = DEFAULT_WID;		// Default wide bandwidth, 2.5kHz
	eeprom.defval.scaf_filters[TX_FILTER] = DEFAULT_TX;	// Default transmit, 2.6kHz
	eeprom.defval.scaf_filters[SPARE] = NUL;		// Unused filter setting
	eeprom.defval.cw_shift = CW_SHIFT;				// 700Hz
	eeprom.defval.cw_sidetone = CW_SIDETONE;		// 700Hz
	eeprom.defval.keyer = IAMBIC_B;					// Iambic B
	eeprom.defval.serial_mode = SERIAL_TEST;		// Test Mode (4)
	eeprom.defval.af_input = MIC;
	eeprom.defval.sq = OFF;							// Squelch not in use
	eeprom.defval.br = DEFAULT_BAUD_RATE;			// Initial Baud rate = 9600
	eeprom.defval.S_Meter_Type = GRAPHIC;			// Graphic S-Meter - 5B4AIY
	eeprom.defval.OOB_Check = ENABLE;				// Out-Of-Band Check flag 0 = Disable, 1 = Enable
	eeprom.defval.Auto_SB = ENABLE;					// Auto Sideband Select 0 = Disable, 1 = Enable
	eeprom.defval.Freq_Display = FIXED_B;			// Frequency Display: 0 = Old, 1 = New, 2 = Fixed 1Hz, but no leading zeros, and decimal point in either Mhz or kHz, 3 = Fixed 10Hz, no leading zeros
	eeprom.defval.Band_SW = _DEFAULT;				// Band Switch Mode 0 = Default, 1 = Mode-A, 2 = Mode-B, 3 = Locked, 4 = Mode-C
	eeprom.defval.RIT_Include = NO;					// Include RIT shift in frequency display, 0 = NO, 1 = YES
	eeprom.defval.Tune_Attenuation = MAX_ATTEN;		// Set attenuation in TUNE mode to 3dB
	eeprom.defval.VFO_Adjust = OFF;					// Adjust VFO to nearest decade step. 0 = OFF, 1 = 10Hz, 2 = 10/100Hz, 3 = All
	eeprom.defval.Hold_Time = 2500;					// Numeric S-Meter peak hold time (Approx 2.5 seconds)
	eeprom.defval.CW_Speed = (2804 | LOCKED);		// 20wpm and Locked
	eeprom.defval.VFO_Lock = 0;						// All VFOs unlocked
	eeprom.defval.CW_CWR_Swap = OFF;				// Original operation, FILTER button does not swap CWR back to CW
	eeprom.defval.Display_Type = ORIGINAL_MARKERS;	// Graphic Scale Type 0 = Original, 1 = Large Markers, 2 Small Markers
	eeprom.defval.CW_Release = DEFAULT_CW_RELEASE;	// Default CW Release time, 500mS
	eeprom.defval.cw_annunciation = OFF;			// Default CW Annunciation mode
/*
 The VFO_Lock variable is an unsigned long integer. Each bit position holds the Lock/Unlock status of its
 corresponding VFO memory. In other words, bit 0 holds the lock status of VFO-A, bit 1, VFO-B etc. This
 allows for selective locking of individual VFO memories. It was tempting to use a bit in the mode array,
 but as the variable eeprom.defval.mode[] is referenced 23 times in the code, it would have meant a considerable
 amount of extra code to mask off the lock bit when it was not required, as well as OR and AND it when it was.
 Using this dedicated integer is far simpler, and less computationally intensive. - Adrian Ryan 20/NOV/2011
*/
// Calibration values
	cal.calval.ref_osc = REF_OSC;
	cal.calval.id_mult = ID_MULT;
	cal.calval.batt_mult = BATT_MULT;
	cal.calval.s_mtr_cal = S_METER_CAL;
	cal.calval.fwd_pwr_mult = FWD_PWR_MULT;
	cal.calval.beep_len = DEFAULT_BEEP_LEN;
	cal.calval.rf_atn_bits[0] = MAX_ATTEN;			// 300 kHz  Initial values for RF attenuator bits
	cal.calval.rf_atn_bits[1] = MAX_ATTEN;			// 600 kHz  Valid range 0 ... 3
	cal.calval.rf_atn_bits[2] = MAX_ATTEN;			// 1MHz
	i = 3;											// The size of array cal.calval.rf_atn_bits[] is 12 bytes.

	do	{											// Amateur Bands 160m - 10m
		cal.calval.rf_atn_bits[i] = 1;
		} while (++i < 12);

	cal.calval.splash = JUMA;						// Splash Screen display "Juma TRX2" + Firmware Version
	cal.calval.button_mode = HOLD;					// Page Latch/Hold. 0 = Hold, 1 = Latch
	cal.calval.swr_trip = SWR_ALARM;				// SWR = 3.00
	cal.calval.swr_delay = LONG_SWR_DLY;			// Default Long SWR Delay Time, 5 Seconds
	cal.calval.alarm_flags = 0x0F;					// Enable all alarms
	cal.calval.overvoltage_trip = OVERVOLTAGE_TRIP;	// Over-voltage trip (Nominally 2762 = 14.5V)
	cal.calval.overcurrent_trip = OVERCURRENT_TRIP;	// Over-current trip (Nominally 2463 = 2.5A)
	cal.calval.undervoltage_trip = UNDERVOLTAGE_TRIP;	// Under-voltage trip (Nominally 2095 = 11.0V)
	cal.calval.Band_Limits = IARU_1;				// 0 = IARU Region 1, 1 = USA Extra Class, 2 = USA General Class

// Increment factory default reset counter
	ReadEE(EEPAGE, EE_FD_LOC, &fd_counter, WORD);
	fd_counter++;

// Save factory defaults reset counter
	EraseEE(EEPAGE, EE_FD_LOC, WORD);
	WriteEE(&fd_counter, EEPAGE, EE_FD_LOC, WORD);
	save_calval(1);					// Save Calibration Settings
	save_defval();					// Save Configuration settings
	}

void increment_and_check(int *value, int limit)
	{
	(*value)++;
	*value %= limit;
	}

int set_mode_blink(void)
	{
	tmp_sub_page0 = sub_page0;		// Save the current page for later restoral.
	sub_page0 = NORMAL_DISPLAY;		// Set the sub page to zero to display the mode and filter settings
	mode_ctr = MODE_COUNTER;		// Reset the mode counter so that we get two blinks,
	return 1;						// and return the initial value for the blink counter.
	}

/*
 Separate CW Speed & Squelch feature
 By checking whether the pot value has changed since the last pass through the main loop, it is now possible
 to avoid having the CW Speed changed when altering the squelch level. When the CW Speed pot function is set
 to Squelch, the CW Speed defaults to the user settable preset speed. When the function is set to CW Speed,
 the pot directly controls the speed, except if it is rotated fully anti-clockwise, whereupon the default preset
 speed is selected. To ensure that all pots do this, there is a 10-count dead band. If the A-D converter O/P
 is less than 10, then it is in the dead band, and the default speed selected. Adrian Ryan 20/NOV/2011
 The speed, in WPM = 1200 / Time in mSec
 To set the CW speed to the default value, note the minimum pot value is 10. Use these constants:

 Speed Range		Division		Addition		Default
	 wpm			Constant		Constant
 ==============================================================
	10 - 30			208692				40			2053/20wpm
	 5 - 40			79501				30			2551/20wpm
	 5 - 30			83477				40			2804/20wpm
	 6 - 60			92752				20			2169/20wpm
	10 - 60			16695				20			1511/20wpm
 ==============================================================
*/
int cw_speed(int speed)
	{
	long time;

	time = (speed < 10)
		? (long)(4096 - (Keyer_Speed & UNLOCKED))
		: (long)(4096 - speed);
	time *= time;								// Make action non-linear, Min = 1, Max = 16,695,396 (Pot = 10)
	return (int)(40L + (time / 83477L));		// Addition Constant + time / Division Constant.
	}											// Addition Constant sets maximum speed, Division Constant sets speed range.

int select_nearest_band(long freq)				// Used in the Rapid Bandswitch routine to select the nearest band
	{											// Valid bands are 1 - 9
	int i = 1;

	do	{
		if(freq < band_select_freq[i]) break;
		} while(++i < HIGHEST_BAND);

	return i;
	}

void set_tx_filter_bw(void)
	{
	tx_filter_bw = (long)(SCAF_CLK / (long)eeprom.defval.scaf_filters[TX_FILTER]);
	}

void debounce(void)
	{
	ms_delay(BUTTON_DEBOUNCE);				// Release de-bounce
	reset_encoder();
	}

/*
 These button procedures were introduced because when checking the buttons there is a significant amount of
 machine code required. By collecting these multiple occurrences 219 bytes of code space was saved.
 A.Ryan - 5B4AIY - 21/FEB/2015
*/
void wait_PWR_MODE_rls(void)				// Wait for either PWR or MODE button to be released...
	{
	while(PWR_SW || _MODE);
	debounce();
	}

int wait_PWR_MODE(void)						// Wait for either the PWR or the MODE button to be pressed...
	{
	int flag = FALSE;

	while(SW5 && !PWR_SW);					// Wait for either the MODE or the PWR button to be pressed...

	if(_MODE) flag = TRUE;					// The MODE button was pressed.

	beep((flag) ? HZ587_31 : HZ466_85, cal.calval.beep_len);
	wait_PWR_MODE_rls();					// Wait for the button to be released.
	return flag;
	}

void wait_PTT_rls(void)						// Wait for PTT button to be released...
	{
	while(!PTT_IN_IO);
	}

void wait_PWR_rls(void)						// Wait for PWR button to be released...
	{
	while(PWR_SW);
	debounce();
	}

void wait_FAST_VFAST_rls(void)				// Wait for FAST/VFAST button to be released...
	{
	while(_VFAST);
	}

void wait_FILTER_rls(int beep_flag)
	{
	if(beep_flag) beep(HZ587_31, cal.calval.beep_len);
	while(_FILTER);
	}

/*
 Save Current Settings with prompt
 The prompt index displays the type of prompt, the mode takes the values: 1 = Save Calibration settings,
 2 = Save Configuration Settings, 4 = Restore & Save complete factory default calibration & configuration settings.
 Note: Values 1 and 2 may be combined to save both the calibration and the configuration settings.
*/
int save_settings(int prompt, int mode)
	{
	int flag = TRUE;

	display_screen(save_settings_prompt[prompt], PWR_No_MODE_Yes);
	wait_PWR_MODE_rls();					// Wait for PWR or MODE button to be released

	if(wait_PWR_MODE())						// If MODE button was pressed,
		{
		if(mode & 1) save_calval(1);		// Save new System Calibration settings,

		if(mode & 2) save_defval();			// Save new User Configuration Settings.

		if(mode & 4) set_factory_defaults();// Complete factory default restore and save
		}
	else
		{
		if(mode & 1) read_calval();			// Restore previous System Calibration Settings

		if(mode & 2) read_defval();			// Restore previous User Configuration Settings

		flag = FALSE;
		}

	set_tx_filter_bw();
	display_line(LINE2, saved_restored[flag]);
	ms_delay(1000);							// Display message
	set_chgen(Display_Scale);				// Load bar graph fonts. Do not move - otherwise LCD is cleared!
	return flag;
	}

void max_min(int *value, int max, int min)
	{
	if(*value > max) *value = max;
	if(*value < min) *value = min;
	}

long int_round(long dividend, long  divisor)
	{
	long q, r;

	q = dividend / divisor;
	r = dividend % divisor;

	if(r >= (divisor >> 1)) q++;

	return q;
	}

/*
 Calculate SWR
 VSWR is calculated from the forward and reverse voltages from the directional coupler. If fwd = Forward
 voltage, and rev = Reverse voltage, then:

	Ro = rev / fwd
	VSWR = 1 + Ro / 1 - Ro

 Since we are dealing with an integer quantity for the SWR display, in this case the calculation is
 carried out in floating point, and then cast to an integer for the disp_meter() in lcd-trx2.c
 The actual VSWR is multiplied by 100 to display correctly. Thus a 1:1 VSWR is 100, a 2:1 is 200.

 Added a check for the reflection coefficient to avoid the (remote) possibility of a math trap error
 caused by dividing by zero if Ro = 1. As the maximum SWR allowed without an alarm is 10:1, the chosen
 value of 0.818182 gives a SWR of 10:1 which will definitely raise the High SWR alarm. This value was chosen
 so that when using a manual transmatch and using the SWR delay option, you will be able to see the high
 SWR and observe it coming down as you tune. A.Ryan - 5B4AIY - 6/JAN/2015
*/
int calc_swr(int fwd, int rev)
	{
	double Ro;

	if(fwd < PWR_MTR_DEAD_BAND) return 0;	// Only calculate if we have some power

	Ro = (double)rev / (double)fwd;			// Reflection coefficient

	if(Ro > MAX_RO) Ro = MAX_RO;			// Avoids possibility of a divide by zero Math Trap error.

	return (int)(((1.0 + Ro) / (1.0 - Ro)) * 100.0);
	}

int check_freq(long upper)
	{
	int band = HIGHEST_BAND;
	long lower;

	lower = upper;

	if(eeprom.defval.mode[vfo_idx] == LSB) lower -= tx_filter_bw;

	if(eeprom.defval.mode[vfo_idx] == USB) upper += tx_filter_bw;

// CW/CWR/Tune modes do not need correcting, as the displayed frequency is the carrier frequency
	do	{
		if(upper <= upper_limit[band] && lower >= lower_limit[band]) break;	// band is 1 - 9 at this point
		} while(--band);		// If this limit is reached, band = O

	if(cal.calval.Band_Limits == USA_GENERAL)	// If General Class set, perform extra checks
		{
		if(upper > lower_segment_limit[band] && lower < upper_segment_limit[band]) band = OUT_OF_BAND;
		}

	return band;				// If out-of-band, 0, otherwise 1 - 9
	}

/*
 Calculate & display bar graph S-Meter
 For numeric S-Meter, we will need a flag. Power meter or S-meter taken care of in display_bar_meter()
 The Numeric/Graphic S-Meter flag will have to be set/cleared in the User Setup section, and the status
 saved to the EEPROM. The peak hold feature was added because the original reacted rather too fast to
 enable reliable readings. The peak hold feature allows the hold time to be set from zero to about
 2.5 seconds in 5mSec increments, and results in a much better presentation. Adrian Ryan 16/NOV/2011
*/
char set_scale(void)
	{
	static int peak_s_meter;			// Initialised to zero by default.

	if(!s_meter_timer)					// Hold timer has timed-out,
		peak_s_meter = 0;				// so reset peak S-meter,

	if(s_meter > peak_s_meter)
		{
		peak_s_meter = s_meter;						// Save new peak value
		s_meter_timer = eeprom.defval.Hold_Time;	// Reset hold timer
		}

	if (peak_s_meter > 54) return 40;	// S9+40dB
	if (peak_s_meter > 44) return 30;	// S9+30dB
	if (peak_s_meter > 36) return 20;	// S9+20dB
	if (peak_s_meter > 29) return 10;	// S9+10dB
	if (peak_s_meter > 24) return 9;	// S9
	if (peak_s_meter > 20) return 8;	// S8
	if (peak_s_meter > 18) return 7;	// S7
	if (peak_s_meter > 15) return 6;	// S6
	if (peak_s_meter > 12) return 5;	// S5
	if (peak_s_meter > 8) return 4;		// S4
	if (peak_s_meter > 3) return 3;		// S3

	return peak_s_meter;				// S2, S1, S0
	}

/*
 Calculate & display bar graph meter. This now indicates true output power.
 Power Bar Graph Constant
 The standard output voltage from the forward power detector is 2.05V at 10W. This gives an A-D output of 4096 * 2.05 / 5.0
 which is a count of 1679. This is squared to give a power value, and is 2,819,041. For the digital display, this value is
 multiplied by the calibration constant stored in cal.calval.fwd_pwr_mult, and whose default value is 3550. This then gives
 a value of: 10,004,045,550nW. This is displayed as 10.0W by using the sprintf() function and dividing the value by 10^9.
 The variable: pwr_meter is assigned its value in the function: get_pwr(), and is: out_pwr * power_bar_graph_const. The output
 power value is scaled to be between 0 - 48 by this scaling factor, which is calculated at boot time using the current power
 meter calibration constant. (For further notes, see comments in juma-trx2.h)
 
 Battery Voltage
 The display is effectively that of a suppressed-zero voltmeter. The minimum reading is the under-voltage trip limit,
 and the maximum is the over-voltage trip limit. The scale length is therefore: over-voltage - under-voltage
 The fractional length to display is thus: (actual voltage - undervoltage) / scale length
 and the number of bars is: 48 * fractional length
 The battery voltage is measured from a potential divider consisting of a 33K resistor in series with a 10K resistor.
 The fractional factor is therefore: 10 / (33 + 10) = 0.232558
 If we assume an under-voltage trip of 11V and an over-voltage trip of 15V, this gives a scale length of 4V, and as there
 are 8 divisions, this resolves to 0.5V/division. Using the default battery calibration multiplier of 5249, the
 under-voltage trip A-D value is therefore 2095, and the over-voltage A-D value is 2858.
 The scale length is therefore 2858 - 2095 = 763
 If the input voltage for example is 13V, this is an A-D value of 2477, batt_raw would therefore be 2477 * 5250 = 13004250
 Thus the first value is: v = (batt_raw - cal.calval.undervoltage_trip) * cal.calval.batt_mult / BATT_MULT
 The variable value would then be 48 * 2447 / 763 = 117456 / 763 = 153
 Taking account of the scale length, v = v /  (cal.calval.overvoltage_trip - cal.calval.undervoltage_trip)
 Since there are 6 divisions to each scale bar, this gives a fraction display of 153 / 6 = 25, or half scale.
 Note that there is a constant loop-invariant expression here: 48 * cal.calval.batt_mult / BATT_MULT,
 as well as: 48 / (cal.calval.overvoltage_trip - cal.calval.undervoltage_trip)
 It is pointless re-calculating this constant each time through the loop, so it is moved to the initialisation
 section where: batt_scale_factor = cal.calval.overvoltage_trip - cal.calval.undervoltage_trip

 Drain Current
 The standard drain current constant is 1.21V/Amp. The standard calibration constant is 2,019. The output of the A-D converter
 for a drain current of 1A is: 4096 * 1.21 / 5.0 = 991. The current calculation is therefore: 991 * 2,019 / 2,000,000 = 1.00A
 The over-current trip limit is the equivalent A-D converter value scaled and corrected by the calibration constant. Therefore,
 in order to represent the drain current as a fraction of the current trip limit the bar graph meter reading is calculated:
	48 * Raw ADC / Overcurrent Trip. Turning things around, the id_const = cal.calval.overcurrent_trip / 48.
 */
// Display bar graph meter, S-meter when RX, PWR when TX, or alternative displays.
int meter_value(void)
	{
	if(sub_page0 < 2) return pwr_meter;
	if(sub_page0 == 2)
		{
		if(swr < 100) return 0;
		return (int)int_round((long)(48 * (swr - 99)), (long)(cal.calval.swr_trip - 99));
		}
	if(sub_page0 == 3) return (int)int_round((long)48L * (long)(batt_raw - cal.calval.undervoltage_trip), (long)batt_scale_factor);
	return (int)int_round((long)id_raw_value, (long)id_const);
	}

void display_bar_meter(void)
	{
	char s;

	if(PTT_IN)									// RX
		{
		s_meter = (int)int_round((long)convert_adc12(S_METER), (long)cal.calval.s_mtr_cal);

		if(eeprom.defval.S_Meter_Type)			// 0 = Graphic, 1 = Numeric
			{									// New numeric S-Meter
			s = set_scale();
			sprintf(lcdpbuff, (s > 9) ? s9_plus_msg : s9_msg, s);
			lcd_putst(lcdpbuff);
			}
		else									// Original Graphic S-Meter
			draw_s_meter(s_meter);
		}
	else										// TX
		draw_s_meter(meter_value());
	}

void display_rf_pwr(double rf_pwr)
	{
	if(eeprom.defval.Power_Meter)				// If dBm display mode is selected,
		{
		if(rf_pwr > 2.0)						// and output power is sufficient,
			disp_meter((log10(rf_pwr)), DBM);	// Display Scaling, P / 0.1 (PdBm = 10 * log10(pwr), the factor of 10 is included in scaling factor.)
		else
			lcd_putst(pwr_mtr_display[1]);		// otherwise blank display.
		}
	else disp_meter(rf_pwr, WATTS);				// Display Scaling, P / 1000
	}

// Measure & display Watt meter
void disp_fwd_pwr(void)
	{
	static long peak_pwr;

	if(PTT_IN)	// RX
		{
/*
 Note: Do not reset the decay_counter! In the Calibration & Setup mode, if the Latched Fast Page Select
 mode is in effect, it will cause the warning beep to be terminated resulting in a nasty buzzing noise
 when the Power page is displayed! A.Ryan - 5B4AIY - 23/APR/2014
*/
		lcd_putst(pwr_mtr_display[eeprom.defval.Power_Meter]);
		peak_pwr = 0L;
		}
	else		// TX
		{
		if(out_pwr > peak_pwr)					// Fast attack (out_pwr has already been set in get_pwr())
			{
			peak_pwr = out_pwr;					// Fast attack
			decay_counter = PEAK_SHOW_TIME;		// Reload decay timer (1,000mS)
			}
		else if(!decay_counter) peak_pwr = 0L;

		display_rf_pwr(((double)(peak_pwr) * (double)cal.calval.fwd_pwr_mult) / 1000000.0);
		}
	}

// Measure & display Drain current meter
void disp_id(void)
	{
	static double drain_current;				// Initialised to zero by default.
	static int hold_time;
	double id;

	if(PTT_IN)									// TX ON ?
		{
		lcd_putst(Display_Amps);				// No, so display blank drain current
		drain_current = 0.0;
		id_raw_value = 0;
		}
	else										// Yes, so display drain current
		{
		id = (double)(id_raw_value) * (double)(cal.calval.id_mult);

		if(id > drain_current)
			{
			drain_current = id;
			hold_time = 125;
			}
		else
			{
			if(hold_time--); else drain_current = 0.0;
			}

		disp_meter((svc_flag) ? id : drain_current, AMPS);
		}
	}

int check_bit(int index)
	{
	unsigned long mask = 1;

	mask <<= index;
	return (eeprom.defval.VFO_Lock & mask) ? TRUE : FALSE;
	}

void bottom_line(int vfo)
	{
/*
 Setting the vfo_lock here fixes bug whereby when returning to a memory lock in the SPLIT mode required two
 presses of the PWR button to unlock the same memory. A.Ryan - 15/OCT/2015
*/
	vfo_lock = check_bit(vfo);
	disp_freq(eeprom.defval.vfo[vfo]);				// Display new frequency on second line.
	lcdoutch(SPACE);
	lcd_putst(mv[(vfo < maximum_VFO)]);				// Display "Mem" or "VFO",
	lcdoutch(vfo + 'A');							// and the memory or VFO letter,
	lcdoutch(lock_symbol[vfo_lock]);				// and either a space or the lock symbol.
	}

/*
 Build main board & RF filter board (Only all band version) 74HC595 I/O latch data & send it
 D14 - D15 RF Attenuator selection
 Attenuation	D15		D14
		0		0		0		0dB
		1		0		1		1dB
		2		1		0		2dB
		3		1		1		3dB
 D11 - D13 Unused
 D8, D9, D10 RF filter select bits
     Filter		D10		D9		D8
		0		0		0		0	Band 0 - 300kHz
		1		0		0		1	Band 1 - 600kHz
		2		0		1		0	Band 2 - 1MHz
		3		0		1		1	Band 3 - 2MHz
		4		1		0		0	Band 4 - 4MHz
		5		1		0		1	Band 5 - 8MHz
		6		1		1		0	Band 6 & 7 - 12MHz
		7		1		1		1	Band 8,9,10,11 - 30MHz

 D7 - 3.5MHz/7.0MHz Filter Select bit (2-Band PA)
 D6 - Mic/Line I/P Select
 D5 - Noise Blanker On/Off (Not Used, always 0)
 D4 - Speech Processor On/Off
 D3 - AGC Speed, Fast/Slow
 D2 - Narrow SSB/CW Filter Select
 D1 - USB/LSB Sideband Select
 D0 - SSB/CW Mode Select
*/
void send_packet_to_74hc595(void)
	{
	static unsigned int old_hc595;			// Initialised to zero by default.
	static unsigned int old_band;

	rf_filt_idx = 0;

	do	{
		if(freq_in_use < rf_filt_attn[rf_filt_idx]) break;			// Scan filter & attenuator switch point table
		} while (++rf_filt_idx < RF_FILT_TABLE_LEN);

	hc595 = ((eeprom.defval.mode[vfo_idx] == TUNE) && !adj_attn)	// Check for TUNE mode
			? eeprom.defval.Tune_Attenuation						// and use TUNE attenuation,
			: (unsigned int)cal.calval.rf_atn_bits[rf_filt_idx];	// otherwise, preset band attenuation.

	hc595 <<= 14;							// Shift attenuation setting up to bits 14 and 15, and clear low order bits,
	hc595 |= rf_filter_bits[rf_filt_idx];	// and OR in the filter select bits. (D10 - D9 - D8)

	if(freq_in_use > M7_FILT)
		hc595 |= MHZ7;						// D7 - 3.5 / 7 MHZ filter select(for dual-band PA only)

	if(AF_Input == MIC)
		hc595 |= AF_INPUT;					// D6 - Microphone/Line input selection 0 = Line, 1 = Mic

//	if(eeprom.defval.nb != 0)
//			hc595 |= NB;					// D5 - Noise Blanker - No longer used - 5B4AIY

	if(Speech_Processor == ON && AF_Input == MIC)
		hc595 |= PROC_ON;					// D4 - Speech processor On = 1, Off = 0

	if(AGC_speed == FAST)
		hc595 |= FAST_AGC;					// D3 - AGC speed, Fast = 1, Slow = 0

	if(RX_Bandwidth == NARROW)
		hc595 |= NAR;						// D2 - Narrow SSB/CW active band pass filter select
/*
 Mode: 0 = LSB, 1 = USB, 2 = CW (Normal), 3 = CWR (Reverse), 4 = Tune
 Truth Table for bits 0 and 1.
 Bit 0 = SSB/!CW Select, 1 = SSB, 0 = CW/Tune
 Bit 1 = USB/LSB Select 1 = LSB, 0 = USB

 Mode   SB    SSB/!CW
 ======================
       Bit 1    Bit 0
  LSB    1        1
  USB    0        1
  CW     0        0
  CWR    1        0
  Tune   1        0
 ======================
*/
	if(eeprom.defval.mode[vfo_idx] != USB && eeprom.defval.mode[vfo_idx] != CWR)
		hc595 |= SB_SELECT;					// D1 - Sideband Select LSB = 1, USB = 0

	if(eeprom.defval.mode[vfo_idx] < 2)		// 0 = LSB, 1 = USB
		hc595 |= SSB_CW;					// D0 - SSB / !CW Select, USB/LSB = 1, CW/CWR/Tune = 0

	if((old_hc595 != hc595) || (old_band != rf_filt_idx))	// Only update hardware if there has been a change.
		{
		old_hc595 = hc595;					// Save new configuration
		old_band = rf_filt_idx;				// This check suppresses band change glitches when changing bands from 17m through 10m
		T2CONbits.TON = OFF;				// Stop TMR2 - Audio OFF
		exchg_data_spi1(hc595);				// Start transmission to main board latch
		ms_delay(GLITCH_TIME);				// Wait for click to dissipate.
		T2CONbits.TON = ON;					// Start TMR2 - Audio ON
		}
	}

int get_pwr(void)							// Called in main loop in TX mode, as well as by adjust_rf_attenuator() and get_average_pwr()
	{										// and by auto_equalise()
	fwd_adval = convert_adc12(FWD_PWR);
	rev_adval = convert_adc12(REV_PWR);
	fwd_pwr = (long)fwd_adval * (long)fwd_adval;	// Calculate relative power levels (V^2)
	rev_pwr = (long)rev_adval * (long)rev_adval;
	out_pwr = fwd_pwr - rev_pwr;					// Output power = forward - reverse.
	pwr_meter = (int)((double)out_pwr * power_bar_graph_const);	// Used in TRX-2 protocol for TRX-Manager (serial_trx2.c), and meter_value()
	return calc_swr(fwd_adval, rev_adval);
	}

void get_value(int *value, int speed, int min, int max)
	{
	if(no_adj == FALSE)
		{
		if(sense_flag == REVERSE) *value -= encoder_get_coarse(speed);	// Reverse sense only used in filter bandwidth adjustment
		else *value += encoder_get_coarse(speed);
		}

	max_min(value, max, min);
	}

void warning_beep(void)
	{
	if(!decay_counter)
		{
		beep(HZ1000, 25);
		decay_counter = 500;
		}
	}

void check_alarm(void)								// Executed each time through the main loop
	{
	static unsigned long avg_current;				// Initialised to zero by default.
	static int avg_ctr;								// Initialised to zero by default.

	if(avg_ctr)										// Get the next sample to average
		{
		id_raw_value = convert_adc12(ID_CUR);		// Save in global for use by other functions.
		avg_current += id_raw_value;
		avg_ctr--;									// Decrement the counter
		}
	else											// We have all the samples
		{
		avg_current /= OVERCURRENT_AVERAGE;			// Calculate the average current (64 samples)

		if(avg_current > cal.calval.overcurrent_trip)
			{
			alarm_flag |= OC_AL_ON;					// Set the alarm flag
			}

		avg_current = 0;							// Reset average current
		avg_ctr = OVERCURRENT_AVERAGE;				// Reset average counter
		}

	batt_raw = convert_adc12(BATT_CH);				// Get battery voltage, and save in global for other functions.

	if(batt_raw > cal.calval.overvoltage_trip)
		{											// The voltage is over the limit,
		alarm_flag |= HI_V_AL_ON;					// set the alarm flag
		}

	if(batt_raw < low_voltage_warning)
		{
		alarm_flag |= BATT_LO;						// The voltage is lower than the pre-limit,
		low_voltage_warning = OFF;					// so set the alarm flag, and cancel the warning.
		}

	if(batt_raw < cal.calval.undervoltage_trip)
		{											// The voltage is lower than the final limit,
		alarm_flag |= LO_V_AL_ON;					// so set the alarm flag.
		}

	alarm_flag &= (cal.calval.alarm_flags | BATT_LO);	// Mask disabled alarms, but leave the Low Battery flag.

	if(alarm_flag)
		{
		lcd_mode = ALARM_DISPLAY;					// Force alarms to be displayed. Reset in display_alarm()
		mute = AUDIO_ON;							// Turn audio on
		}
	}

// Function for Multi-band PA input RF attenuator adjust
void adjust_rf_attenuator(void)
	{
	int temp_sub_page, atten;

	adj_attn = TRUE;								// This forces the use of the true attenuator setting
	temp_sub_page = sub_page0;						// Save the current display page,
	sub_page0 = 1;									// and switch to the RF output power display.

	do	{
		check_alarm();
		get_pwr();
		lcd_cmd(LINE1);
		display_bar_meter();						// Display PWR meter bar graph, and digital power meter.
		display_rf_pwr(((double)out_pwr * (double)cal.calval.fwd_pwr_mult) / 1000000.0);
		sprintf(lcdpbuff, Display_Attenuator, -cal.calval.rf_atn_bits[rf_filt_idx]);
		display_line(LINE2, lcdpbuff);				// Display the current attenuator setting
// If you attempt to use: &cal.calval.rf_atn_bits[rf_filt_idx] you will provoke a compiler 'Incompatible pointer type'
// error message because cal.calval.rf_atn_bits[] is an array of characters, not integers. Thus, to avoid this error
// the value is equated to an integer, the range is checked, and the result returned to the array. A.Ryan - 30/JAN/2014
		atten = cal.calval.rf_atn_bits[rf_filt_idx];
		get_value(&atten, ENCODER_SLOW, MIN_ATTEN, MAX_ATTEN);
		cal.calval.rf_atn_bits[rf_filt_idx] = atten;
		send_packet_to_74hc595();
		warning_beep();
		} while(!PTT_IN_IO && !alarm_flag);			// Stay here while PTT switch is pressed, and there are no alarms.

// Prepare for exit
	if(alarm_flag) clear_lcd();
	else save_calval(1);							// Save calibration values on exit, if no alarms.

	reset_encoder();								// Clear the encoder,
	sub_page0 = temp_sub_page;						// and restore previous display page.
	adj_attn = FALSE;								// This forces the use of the preset attenuator setting
	}

// LCD back light functions
void bl_on(void)
	{
	set_pwm4_dac(eeprom.defval.contrast);			// Set contrast
	set_pwm3_dac(eeprom.defval.back_light);			// Turn backlight ON
	bl_timer = eeprom.defval.back_light_timer * 5;	// Load timer. 0 = Timer OFF
	}

void set_bit(int index)
	{
	unsigned long mask = 1;

	eeprom.defval.VFO_Lock |= (mask << index);
	}

void clr_bit(int index)
	{
	unsigned long mask = 1;

	eeprom.defval.VFO_Lock &= ~(mask << index);
	}

void toggle_lock(int vfo)
	{
	vfo_lock ^= 1;									// VFO lock flip-flop
	(vfo_lock) ? set_bit(vfo) : clr_bit(vfo);
	beep_number = vfo_lock;
	changed_flag = TRUE;
	}

void Switch_Off(void)
	{
	stop_scaf_clock();								// Block audio path, reduce power off noise.
	wait_PWR_rls();									// Wait while power switch is still pressed
	bl_off();										// Turn display off
	PWR_ON = OFF;									// Release the power latch
	while(TRUE);									// Final wait
	}

// Handle PWR button. VFO lock, Shut down the system or RF attenuator adjust if TX && TUNE, improved sequence 03,07.2008
void power_off(void)
	{
	int print_flag = FALSE;

	button_debounce(PWR_SW);

	if(alarm_flag)
		{
		beep(HZ698_45, DEFAULT_BEEP_LEN);			// Always beep for alarm acknowledge
		loop_ctr = 0;								// Reset the alarm blink counter

		if(button_count)		// ******* PRIMARY Function *******
			{
			if(alarm_flag & OC_AL_ON)				// Is it Over-current?
				{
				alarm_flag &= CLR_OC_AL;			// Try to clear over-current alarm
				return;
				}

			if(alarm_flag & SWR_AL)					// Is it High SWR?
				{
				alarm_flag &= CLR_SWR_AL;
				return;
				}

			if(alarm_flag & HI_V_AL_ON)				// Is it Over-Voltage?
				{
				alarm_flag &= CLR_HI_V_AL;
				return;
				}

			if(alarm_flag & BATT_LO)				// Is it Under-Voltage warning?
				{
				alarm_flag &= CLR_BATT_LO;
				low_voltage_warning = OFF;			// Reset trigger - one-time alarm!
				return;
				}

			if(alarm_flag & LO_V_AL_ON)				// Is it Under-Voltage?
				{
				alarm_flag &= CLR_LO_V_AL;
				return;
				}
			}
		else					// ****** SECONDARY Function ******
			{
			display_screen(Emergency, Shutdown);
			Switch_Off();							// No return from this function.
			}
		}

	if(button_count)			// ******* PRIMARY Function *******
		{
		if(tune_on)									// PWR switch in TUNE mode takes us to
			adjust_rf_attenuator();					// PA RF attenuator (Power Level) adjustment.
		else
			if(lcd_mode == NORMAL_DISPLAY) toggle_lock(vfo_idx);
		}
	else						// ****** SECONDARY Function ******
		{
		beep(HZ392_01, cal.calval.beep_len * 2);	// Play low sound when ready for power down

		while(tone_counter);						// Let the tone finish

		switch(power_down_mode)
			{
			case IMMEDIATE: default:
				if(changed_flag) save_defval();		// Save any pending Rapid Bandswitch User or VFO memory/lock changes.
			break;

			case PROMPTED:
				print_flag = save_settings(0, 2);	// Prompt to save current configuration settings
			break;

			case SAVE_STATE:
				save_defval();
				display_screen(Configuration_Msg, saved_restored[1]);
				print_flag = TRUE;
				ms_delay(850);
			break;
			}

		if((Serial_Mode == SERIAL_TEST) && print_flag)
			{
			printf(Settings_Saved_EEPROM);
			ms_delay(5);							// Let the printout finish
			}

		Switch_Off();								// No return from this function.
		}
	}

// RS-232 loop back test - Press and hold DISPLAY and then power on until prompt is displayed
void rs232_test(void)
	{
	unsigned char c;

	display_screen(Loop_Back_Test, Awaiting_Data);
	printf(RS232_Test_Exit);
	ms_delay(400);							// Ensure message has been sent
	ClearUSART1queue();

	do	{
		if(kbhit())
			{
			c = getch();
			beep(HZ698_45, SHORT_BEEP);		// Give beep tone
			putch(c);						// Echo character to terminal
			sprintf(lcdpbuff, Display_RX_Data, c, c);
			display_line(LINE2, lcdpbuff);	// Display the character code as ASCII and HEX
			}
		} while(!PWR_SW);

	printf(RS232_Test_Terminated);
	wait_PWR_rls();							// Wait for switch to be released, this avoids spurious power down
	}

void display_alarm(void)
	{
	static int display_message;				// Initialised to zero.

	if(alarm_flag)							// If there are any alarms,
		{
		bl_on();							// force backlight on
		lcd_cmd(LINE1);						// and start at Line 1.

		if(!loop_ctr)						// If blink counter has timed-out,
			{
			loop_ctr = LOOP_COUNT;			// reset the blink counter,
			display_message ^= 1;			// and toggle the message flag.
			beep(4700, SHORT_BEEP);
			}

		if(display_message)
			{
			if(alarm_flag & OC_AL_ON)
				{
				lcd_putst(Overcurrent_Alm);
				return;
				}

			if(alarm_flag & SWR_AL)
				{
				lcd_putst(High_SWR_Alm);
				return;
				}

			if(alarm_flag & HI_V_AL_ON)
				{
				lcd_putst(Over_Voltage_Alm);
				return;
				}

			if(alarm_flag & BATT_LO)
				{
				lcd_putst(Low_Battery_Alm);
				return;
				}

			if(alarm_flag & LO_V_AL_ON)
				{
				lcd_putst(Under_Voltage_Alm);
				return;
				}
			}
		else lcd_spc(16);					// Display blanks
		}
	else									// If there are no alarms,
		{
		lcd_mode = NORMAL_DISPLAY;			// restore normal display,
		display_message = FALSE;			// and reset the message flag.
		}
	}

long get_average_pwr(void)
	{
	double rf_power;
	long favg_pwr = 0, ravg_pwr = 0;
	int swr, i = 100;

	do	{
		swr = get_pwr();
		favg_pwr += fwd_adval;
		ravg_pwr += rev_adval;
		rf_power = ((double)fwd_pwr * (double)cal.calval.fwd_pwr_mult) / 1000000.0;	// Scaling, P = ((ADC * ADC) * Calibration Factor / 10^6 = mW

		if(rf_power < MIN_POWER) return 0;

		lcd_cmd(LINE1);						// Move cursor to line 1, and
		draw_s_meter(pwr_meter);			// display graphic power meter,
		display_rf_pwr(rf_power);			// and digital power meter.
		check_alarm();

		if(swr > cal.calval.swr_trip) alarm_flag |= SWR_AL;
		} while (--i);

	favg_pwr /= 100L;
	ravg_pwr /= 100L;
	favg_pwr *= favg_pwr;
	ravg_pwr *= ravg_pwr;
	return (favg_pwr - ravg_pwr);
	}

int get_atten(double ratio)
	{
/*
  The actual attenuation values taking into account nominal resistor values are:
  -1dB attenuator: -0.936dB R1/R3 = 820R, R2 = 4R7 
  -2dB attenuator: -1.960dB R1/R3 = 470R, R2 = 12R
  -3dB attenuator: -2.982dB R1/R3 = 270R, R2 = 16R
*/
	if(ratio >= 2.6) return 3;

	if(ratio >= 1.6) return 2;

	if(ratio >= 0.6) return 1;

	return 0;
	}
/*
 The attenuator settings display for the local mode invocation attempts to convey the maximum information
 in as compact a form as possible, bearing in mind the very limited LCD capabilities. The display is of
 the form:

 '  15m 000110110 '

 where the first field indicates the reference band, and the 9-digit number indicates the attenuator settings
 for the amateur bands in the order: 10m, 12m, 15m, 17m, 20m, 30m, 40m, 80m, and 160m.

 To further emphasise the reference band, its digit will blink. In this example, the 10m attenuator setting
 is 0dB, the 12m setting is 0dB, the 15m settings 0dB, and its digit will be blinking, the 17m setting is -1dB,
 the 20m setting is -1dB, the 30m settings is 0dB, the 40m setting is -1dB, the 80m setting is -1dB, and finally
 the 160m setting is 0dB.

 The function is called with the reference in the upper byte, and returns with the attenuation display in
 lcdpbuff ready for displaying on the chosen line of the LCD.
*/
void display_atten(int reference)
	{
	int i, j;

	reference >>= 8;					// Recover reference band from upper byte
	sprintf(lcdpbuff, dsp_atten_fmt, band[reference + 1]);	// Insert the reference band number (band[1] = 160, band[9] = 10)
	reference += 3;						// Correct the reference band number for this function.

	for(i = 11, j = 6; i > 2; i--, j++)
		{								// Construct the attenuation setting string
		lcdpbuff[j] = ((i == reference) && (ms_counter > 499))
					? SPACE
					: cal.calval.rf_atn_bits[i] + ZERO;
		}

	lcdpbuff[15] = SPACE;				// Add trailing space,
	lcdpbuff[16] = 0;					// and finally terminate the buffer.
	}
/*
 The auto_equalise() function is intended to ensure that the output power of the transceiver is essentially
 constant across the 160m to 10m amateur bands. The function can be invoked either remotely from the Serial
 Test Suite using the 'N' command, or locally from the front panel.

 To invoke locally, from the power off state, press and hold the FAST/VFAST button and power up the
 transceiver. Allow the system to boot, and release the button when the 'Auto Equalisation' message appears.
 Respond to the prompt that will then be displayed. You will then be prompted to press and hold the PTT
 switch. Whilst the switch is pressed the transceiver will be automatically tuned to frequencies from 10m
 down to 160m and the output power measured. At the conclusion a calculation will be performed to optimise
 the attenuation settings across the various bands so as to achieve essentially a constant output power.

 The following arrays and their indices are used:
 
 amateur_bands[]
 This array holds the amateur band frequencies. amateur_bands[0] = 160m, amateur_bands[8] = 10m

 band[]
 This array holds the band prompt digits. band[0] = Invalid Band, band[1] = '160', band[9] = '10'.

 cal.calval.rf_atn_bits[]
 This array holds the attenuation settings for all the bands. cal.calval.rf_atn_bits[3] = 160m attenuation,
 cal.calval.rf_atn_bits[11] = 10m attenuation.

 save_atten[]
 This holds the saved attenuation values. save_atten[0] = 160m attenuation, save_atten[8] = 10m attenuation.

 new_atten[]
 This holds the calculated new attenuation values. new_atten[0] = 160m attenuation, new_atten[8] = 10m attenuation.

 measured_power[]
 This holds the measured average power. measured_power[0] is not used, place holder, measured_power[1] = 160m average power,
 measured_power[9] = 10m average power.
*/
int auto_equalise(int prt_flag)
	{
	double rf_power;
	long measured_power[10], reference_pwr = 20000000L;
	int save_atten[9], new_atten[9], save_tune_atten, save_mode, ref_band, i = 0, err_flag = NORMAL_EXIT;

	save_tune_atten = eeprom.defval.Tune_Attenuation;	// Save current Tune Attenuation setting
	eeprom.defval.Tune_Attenuation = 3;					// Set attenuator to -3dB
	save_mode = eeprom.defval.mode[vfo_idx];			// Save current VFO's mode
	eeprom.defval.mode[vfo_idx] = TUNE;					// Select TUNE mode

	do	{
		save_atten[i] = cal.calval.rf_atn_bits[i + 3];	// Save current amplifier equalisation settings,
		cal.calval.rf_atn_bits[i + 3] = 0;				// and reset to 0dB.
		} while (++i < 9);

	(prt_flag) ? printf(Press_Hold) : display_screen(press_and_hold_msg, PTT_to_start_msg);

	while(PTT_IN_IO);									// Wait for PTT switch closure,

	if(prt_flag) printf(Equalising);

	i = 9;
	KEY = OFF;											// and initially turn the RF OFF.

	do	{
		freq_in_use = amateur_bands[i - 1];				// Select the next frequency,
		sprintf(lcdpbuff, Auto_Freq_fmt, (double)freq_in_use / 1000000.0);
		display_line(LINE2, lcdpbuff);					// and display it,
		dds_load(freq_in_use);							// and load the synthesiser,
		send_packet_to_74hc595();						// and select the new RF filter,
		ms_delay(100);									// then allow time for the relays to settle,
		KEY = ON;										// and turn the RF ON,
		ms_delay(100);									// allow KEY line to settle, and increase display time,
		measured_power[i] = get_average_pwr();			// and display and save the measured power.
		KEY = OFF;										// Turn the RF OFF.

		if(measured_power[i] == 0)						// Check for abnormally low output power.
			{
			err_flag = PWR_MEASUREMENT_ERR;
			goto Abort;									// In which case, abort.
			}

		if(measured_power[i] < reference_pwr)			// Find the lowest power.
			{
			reference_pwr = measured_power[i];
			ref_band = i - 1;
			}

		if(prt_flag)									// If this is a remote invocation...
			{
			rf_power = ((double)measured_power[i] * (double)cal.calval.fwd_pwr_mult) / 1000000.0;	// Power in mW
			printf(Averaged_Pwr, band[i], rf_power / 1000.0, (double)(10.0 * log10(rf_power)));
			}

		if(PTT_IN_IO) err_flag = USER_ABORT;			// Check PTT switch
		if(alarm_flag) err_flag = ALARM_ERR;			// Check alarms
		if(err_flag) goto Abort;						// If PTT switch is released, or there is an alarm, abort.
		} while (--i);

	lcd_cmd(LINE1);
	draw_s_meter(0);
	display_rf_pwr(0.0);

	if(prt_flag) printf(New_Line);

	i = 8;			// Start at the 10m band, so that display corresponds to initial measurements.

	do	{												// Now calculate the attenuator settings
		rf_power = 10.0 * log10((double)measured_power[i + 1] / (double)reference_pwr);
		new_atten[i] = get_atten(rf_power);

		if(prt_flag) printf(Band_Atten, band[i + 1], rf_power, -new_atten[i], (i == ref_band) ? Ref_Band_msg : "");

		} while (i--);

	(prt_flag) ? printf(Release_PTT) : display_screen(Release_PTT_msg, Complete_msg);
	wait_PTT_rls();			// Wait for PTT switch release
	Abort:					// I'm not dogmatic about not using GOTO if it's sensible, as here.
	KEY = OFF;				// Turn RF OFF

	if(prt_flag) printf(New_Line);

	i = 0;

	do	{
		cal.calval.rf_atn_bits[i + 3] = (err_flag) ? save_atten[i] : new_atten[i];
		} while (++i < 9);

	if(!err_flag) save_calval(0);						// If there were no errors, save the new settings.

	eeprom.defval.Tune_Attenuation = save_tune_atten;	// Restore original Tune Attenuation setting,
	eeprom.defval.mode[vfo_idx] = save_mode;			// and original VFO's mode.
	ref_band <<= 8;										// Shift data to upper byte
	return err_flag | ref_band;							// Include the reference band data
	}

// Adjust VFO frequency to the nearest decade for the frequency step in use
void snap_to_step(void)
	{
/*
 Although all the calculations could be done here with only a single variable, r, because there are so many address
 resolution calculations to perform for eeprom.defval.vfo[vfo_idx] and f_steps[eeprom.defval.step_idx], it actually
 saves 51 bytes to use these temporary variables. A.Ryan, 15/OCT/2015
*/
	long f;
	int r, step;

	if(eeprom.defval.VFO_Adjust >= Tuning_Step)			// If VFO Adjust >= Current Adjustment Setting
		{
		f = eeprom.defval.vfo[vfo_idx];
		step = f_steps[Tuning_Step];
		r = (int)(f % (long)step);
		f -= (long)r;									// First round down.

		if(r > (step >> 1)) f += (long)step;			// If the remainder is greater than half the step value, round up one step.

		eeprom.defval.vfo[vfo_idx] = f;
		}
	}

int RIT_freq(int adc)
	{
	if(adc >= (2048 + RIT_DEAD_ZONE))	// Blank dead zone (RIT_DEAD_ZONE = 47, defined in juma-trx2.h)
		adc -=(2048 + RIT_DEAD_ZONE);	// Positive side
	else
		{
		if(adc <= (2048 - RIT_DEAD_ZONE))// Negative side
			adc -=(2048 - RIT_DEAD_ZONE);
		else
			adc = 0;					// Dead zone
		}

	return adc / 2;						// In decimal frequency system, the result is divided by 2.
	}

long get_rit(void)
	{
	static int old_ADC;
	int i;

	i = convert_adc12(RIT_POT);			// Get RIT pot value

	if(abs(old_ADC - i) > 1) old_ADC = i;
	else i = old_ADC;					// This eliminates the +/-1 Hz jitter.

	return RIT_freq(i);
	}

void display_hdr(void)
	{
	printf(firmware, Display_JUMA_TRX2, VERSION, BUILD, BUILD_DATE);
	printf(copyright);
	printf(added_features);
#if INCLUDE_TEST_CODE
	printf(Test_Msg);
#endif
	}

void get_one_zero(int *value)
	{
	get_value(value, ENCODER_SLOW, 0, 1);
	}

void set_decade_value(int *value, int min, int max)
	{
	if(no_adj == FALSE) *value += encoder_get_coarse(ENCODER_MEDIUM) * 10;

	max_min(value, max, min);
	}

void rs232_2(void)
	{
	serial_trx2(!PTT_OUT & PTT_IN);		// Flag indicates a frequency change is permissible. PTT_OUT 1 = TX, 0 = RX, PTT_IN 0 = TX, 1 = RX
	}

void (*port_mode[])(void) = {				// Indexed by: Serial_Mode
						ClearUSART1queue,	// 0 - RS-232 port disabled
						serial_yaesu,		// 1 - Yaesu CAT
						serial_kenwood,		// 2 - Kenwood CAT
						rs232_2,			// 3 - TRX-2 protocol
						serial_test,		// 4 - Test mode
						serial_ext_kb		// 5 - Voice Memory
						};
/*
 One of the features of elegant well-structured code is the concept of burying the complexity or details.
 The original code used several very long and complex switch/case constructs to deal with setting the user
 configuration and calibration setup. Whilst there is nothing inherently 'wrong' with this approach, it did
 lead to a very complex source code layout where one could easily get lost amongst the multitude of nested
 loops and braces. Changes were difficult to accomplish, and it was very easy to place a containing brace in
 the wrong position, so that although the code would compile and link without any apparent error, there could
 be really serious or subtle bugs in the executable code. To avoid this and to simplify the high-level source
 code I decided to restructure these long switch/case constructs into a simpler form. The following sections
 of code accomplish this by placing the various display pages etc. into small functions, and then collecting the
 functions into an array and finally executing the desired function using a simple index that was the original
 code's switch variable. Although this has increased the size of the executable code module the overall
 simplification was well worth the effort. The increase in code size is largely as a result of this processor's
 lack of a complex indexed call instruction which is common amongst CISC processors. As a consequence it takes
 a few more machine cycles to actually calculate the desired execution address. - Adrian Ryan - 5B4AIY - 22/MAY/2012
*/
// AGC speed - Fast/Slow
void sp_0(void)
	{
	get_one_zero(&AGC_speed);
	sprintf((char *)lcdpbuff, dp_0_msg, agc_speed_msg[AGC_speed]);
	}

// Adjust selected filter
/*
 The filter bandwidth adjustment actually alters the period of the SCAF clock, and thus a reduction in the period increases the
 filter cut-off frequency. In order to preserve the 'sense' of the adjustment, i.e, a clockwise rotation of the VFO knob
 causing an increase in frequency, the encoder value has to be subtracted. This is achieved by means of the sense_flag.
*/
void sp_1(void)
	{
	sense_flag = REVERSE;
	get_value(&eeprom.defval.scaf_filters[RX_Bandwidth], ENCODER_MEDIUM, scaf_min[RX_Bandwidth], scaf_max[RX_Bandwidth]);
	sense_flag = NORMAL;
	sprintf((char *)lcdpbuff, dp_1_msg, filter_width[RX_Bandwidth], (long)(SCAF_CLK / (long)eeprom.defval.scaf_filters[RX_Bandwidth]));	// Calculate & display corner frequency
	}

// AF Input Source - Mic/Line
void sp_2(void)
	{
	get_one_zero(&AF_Input);
	sprintf((char *)lcdpbuff, dp_2_msg, audio_input[AF_Input]);
	}

// Speech Processor On / Off (This page is skipped if the AF I/P Source is LINE)
void sp_3(void)
	{
	if(AF_Input == MIC)
		{
		get_one_zero(&Speech_Processor);
		sprintf((char *)lcdpbuff, dp_3_msg, on_off[Speech_Processor]);
		}
	else sub_page1++;
	}

// Keyer operating mode - Dot Priority, Iambic A, Iambic B, Vibroplex, or Straight
void sp_4(void)
	{
	get_value(&Keyer_Mode, ENCODER_SLOW, DOT_PRIORITY, STRAIGHT_KEY);
	sprintf((char *)lcdpbuff, dp_4_msg, keyer_msg[Keyer_Mode]);
	}

// Straight Key CW Release Time Minimum = 200mS, Maximum = 1.5 Seconds (This page is skipped if Keyer Mode is not Straight)
void sp_5(void)
	{
	if(Keyer_Mode == STRAIGHT_KEY)
		{
		set_decade_value(&eeprom.defval.CW_Release, MIN_CW_RELEASE, MAX_CW_RELEASE);

		if(eeprom.defval.CW_Release > MIN_CW_RELEASE)						// If release time is set,
			sprintf((char *)lcdpbuff, dp_5_msg, eeprom.defval.CW_Release);	// display set release time,
		else
			sprintf((char *)lcdpbuff, CW_rls_prompt, cw_rls_speed[eeprom.defval.sq]);
		}
	else sub_page1++;
	}

// Set CW Shift & Side Tone Frequency, Minimum = 300 Hz, Maximum = 1 kHz
void sp_6(void)
	{
	get_value(&eeprom.defval.cw_shift, ENCODER_SLOW, MIN_CW_SHIFT, MAX_CW_SHIFT);
	eeprom.defval.cw_sidetone = FCY / (2 * eeprom.defval.cw_shift);
	sprintf((char *)lcdpbuff, dp_6_msg, eeprom.defval.cw_shift);	// Display CW shift (Hz)
	}

// CW speed pot = CW speed / Squelch-A / Squelch-B
void sp_7(void)
	{
	get_value(&eeprom.defval.sq, ENCODER_SLOW, 0, 2);
	sprintf((char *)lcdpbuff, dp_7_msg, cw_spd_pot[eeprom.defval.sq]);
	}

// CW Keyer Speed Preset
void sp_8(void)
	{
	int x = 0;

	if(no_adj == FALSE) x = encoder_get_coarse(ENCODER_MEDIUM);

	if(x > 0) Keyer_Speed |= LOCKED;	// Preset speed locked

	if(x < 0) Keyer_Speed &= UNLOCKED;	// Preset speed unlocked

	if(Keyer_Speed & LOCKED)
		sprintf((char *)lcdpbuff, dp_8_msg1, 1200 / cw_speed(Keyer_Speed & UNLOCKED));
	else
		{
		Keyer_Speed = (cw_pot < 10) ? 10 : cw_pot;
		cw_period = cw_speed(Keyer_Speed);
		sprintf((char *)lcdpbuff, dp_8_msg2, 1200 / cw_period);
		}
	}

// CW/CWR Swap Enable/Disable
void sp_9(void)
	{
	get_one_zero(&eeprom.defval.CW_CWR_Swap);
	sprintf((char *)lcdpbuff, dp_9_msg, on_off[eeprom.defval.CW_CWR_Swap]);
	}

// LCD back light intensity
void sp_10(void)
	{
	set_decade_value(&eeprom.defval.back_light, MIN_BL, MAX_BL);
	set_pwm3_dac(eeprom.defval.back_light);
	sprintf((char *)lcdpbuff, dp_10_msg, eeprom.defval.back_light);
	}

// LCD Contrast
void sp_11(void)
	{
	set_decade_value(&eeprom.defval.contrast, MIN_CONTRAST, MAX_CONTRAST);
	set_pwm4_dac(eeprom.defval.contrast);
	sprintf((char *)lcdpbuff, dp_11_msg, eeprom.defval.contrast);
	}

// LCD back light timer
void sp_12(void)
	{
	get_value(&eeprom.defval.back_light_timer, ENCODER_SLOW, 0, MAX_BLT);

	if(eeprom.defval.back_light_timer)
		sprintf((char *)lcdpbuff, dp_12_msg1, _lcd_timer, eeprom.defval.back_light_timer * 5);
	else
		sprintf((char *)lcdpbuff, dp_12_msg2, _lcd_timer, on_off[0]);
	}

// Serial I/O mode/protocol select.
// Voice Memory mode only selectable if the module is present. A.Ryan - 5B4AIY - 17/AUG/2013
void sp_13(void)
	{
	ClearUSART1queue();
	ClearUSART2queue();						// This will hopefully eliminate the spurious VM Erase bug. A.Ryan - 01/MAR/2014
	clear_buffer();							// Flush the TRX-2/Yaesu/Kenwood command buffer & reset buffer index.
	get_value(&Serial_Mode, ENCODER_SLOW, 0, 4 + isd_1700_installed);

	if(Serial_Mode == SERIAL_YAESU || Serial_Mode == SERIAL_KENWOOD)// If either CAT mode is selected
		{
		maximum_VFO = SPLIT_MODE;			// Force VFO mode to A/B + Split
		Select_VFO = VFO_A;					// Force active VFO as VFO-A
		}

	RS_232_Mode = port_mode[Serial_Mode];
	sprintf((char *)lcdpbuff, dp_13_msg, rs232_mode[Serial_Mode]);
	}

// Select user UART1 Baud rate
void sp_14(void)
	{
	get_value(&Baud_Rate, ENCODER_SLOW, 0, 7);
	SetUSART1baud(Baud_Rate);		// Set new Baud rate
	sprintf((char *)lcdpbuff, dp_14_msg, br_txt[Baud_Rate]);		// Display current selection
	}

// Select VFO mode / Number of memories in use
void sp_15(void)
	{
	if(Serial_Mode == SERIAL_YAESU || Serial_Mode == SERIAL_KENWOOD)// If either CAT mode is selected
		sprintf((char *)lcdpbuff, dp_15_msg1, _a_b_split);
	else
		{
		get_value(&maximum_VFO, ENCODER_SLOW, SPLIT_MODE, 26);

		if(maximum_VFO == SPLIT_MODE)								// A + B / Split
			sprintf((char *)lcdpbuff, dp_15_msg2, _a_b_split);
		else
			sprintf((char *)lcdpbuff, dp_15_msg3, maximum_VFO, 26 - maximum_VFO);	// Other VFOs
		}

	Select_VFO = VFO_A;		// Reset to VFO-A
	}

// If SPLIT mode is in effect, select the type of VFO Equalisation. (This page is skipped if VFO Mode is not A/B Split.)
void sp_16(void)
	{
	if(maximum_VFO == SPLIT_MODE)
		{
		get_value(&Equalisation_Mode, ENCODER_SLOW, OFF, SPLIT_PLUS_SIMPLEX);
		sprintf((char *)lcdpbuff, dp_4s_11s_fmt, _mode, VFO_Eq_Mode[Equalisation_Mode]);
		}
	else sub_page1++;
	}

// Select type of S-Meter display, graphic (original) or numeric
void sp_17(void)
	{
	get_one_zero(&eeprom.defval.S_Meter_Type);
	sprintf((char *)lcdpbuff, dp_17_msg, s_meter_type[eeprom.defval.S_Meter_Type]);
	}

// Numeric S-Meter Peak Hold Time Minimum = 250mS, Maximum = 5 Secs.
void sp_18(void)
	{
	set_decade_value(&eeprom.defval.Hold_Time, MIN_S_METER_HOLD, MAX_S_METER_HOLD);
	sprintf((char *)lcdpbuff, dp_18_msg, ((double)eeprom.defval.Hold_Time) / 1000.0);
	}

// Enable / Disable out-of-band checks for transmitter inhibit
void sp_19(void)
	{
	get_one_zero(&eeprom.defval.OOB_Check);
	sprintf((char *)lcdpbuff, dp_19_msg, on_off[eeprom.defval.OOB_Check]);
	}

// Auto Sideband Select Enable/Disable
void sp_20(void)
	{
	get_one_zero(&eeprom.defval.Auto_SB);
	sprintf((char *)lcdpbuff, dp_20_msg, on_off[eeprom.defval.Auto_SB]);
	}

// Frequency Display Old/New select
void sp_21(void)
	{
	get_value(&eeprom.defval.Freq_Display, ENCODER_SLOW, 0, 3);
	sprintf((char *)lcdpbuff, dp_21_msg, freq_disp[eeprom.defval.Freq_Display]);
	}

// Band Switch Mode Select 0 = Default, 1 = User Frequencies, 2 = Current Frequency, 3 = User Frequencies (Locked)
void sp_22(void)
	{
	get_value(&RBS_Mode, ENCODER_SLOW, _DEFAULT, _LOCKED);

	if((RBS_Mode != _MODE_B) && RBS_Flag) RBS_Flag = OFF;	// If you change the RBS Mode from Mode-B, then clear the RBS_Flag

	sprintf((char *)lcdpbuff, dp_4s_11s_fmt, _mode, band_sw_msg[RBS_Mode]);
	}

// Choose whether to include the RIT frequency with the displayed frequency
void sp_23(void)
	{
	get_one_zero(&eeprom.defval.RIT_Include);
	sprintf((char *)lcdpbuff, dp_23_msg, on_off[eeprom.defval.RIT_Include]);
	}

// Select attenuation in TUNE mode
void sp_24(void)
	{
	get_value(&eeprom.defval.Tune_Attenuation, ENCODER_SLOW, 0, 3);
	sprintf((char *)lcdpbuff, dp_24_msg, -eeprom.defval.Tune_Attenuation);
	}

// Select VFO decade adjustment
void sp_25(void)
	{
	get_value(&eeprom.defval.VFO_Adjust, ENCODER_SLOW, 0, 3);
	sprintf((char *)lcdpbuff, dp_25_msg, vfo_adj[eeprom.defval.VFO_Adjust]);
	}

// Graphic Scale Display select, Original, Large Markers, Small Markers
void sp_26(void)
	{
	get_value(&Display_Scale, ENCODER_SLOW, ORIGINAL_MARKERS, SMALL_MARKERS);
	sprintf((char *)lcdpbuff, dp_4s_11s_fmt, _type, disp_type[Display_Scale]);
	}

// Noise blanker datapoint now used for Fast Power OFF flag
void sp_27(void)
	{
	get_value(&eeprom.defval.nb, ENCODER_SLOW, IMMEDIATE, SAVE_STATE);

	if(power_down_mode == IMMEDIATE && display_page == LAST_PAGE) display_page = MODE_BW;
	sprintf((char *)lcdpbuff, dp_4s_11s_fmt, _mode, power_msg[power_down_mode]);
	}

// RF O/P Power meter type
void sp_28(void)
	{
	get_one_zero(&eeprom.defval.Power_Meter);
	sprintf((char *)lcdpbuff, dp_4s_11s_fmt, _type, pwr_mtr_msg[eeprom.defval.Power_Meter]);
	}

// Start-Up Page Selection
void sp_29(void)
	{
	get_value(&display_page, ENCODER_SLOW, MODE_BW, (power_down_mode == IMMEDIATE) ? PA_CURRENT : LAST_PAGE);
	sprintf((char *)lcdpbuff, dp_4s_11s_fmt, _page, start_page_select[display_page & 0x07]);
	}

// CW Annunciation Selection
void sp_30(void)
	{
	unsigned int cw_annunciation, speed;

	cw_annunciation = eeprom.defval.cw_annunciation & 0x00FF;
	get_value(&cw_annunciation, ENCODER_SLOW, 0, 2);

	if(cw_annunciation)
		{
		speed = cw_speed(convert_adc12(CW_POT));	// Get new speed
		sprintf((char *)lcdpbuff, dp_30_msg2, 1200 / speed, cw_annunciation_msg[cw_annunciation]);
		}
	else
		{
		sprintf((char *)lcdpbuff, dp_30_msg1, cw_annunciation_msg[cw_annunciation]);
		speed = 0;
		}
	eeprom.defval.cw_annunciation = (speed << 8) + cw_annunciation;
	dot_time = speed;
	}

void (*set_cfg[])(void) = {
							sp_0,		// AGC speed - Fast/Slow
							sp_1,		// Adjust selected filter bandwidth
							sp_2,		// AF Input Source - Mic/Line
							sp_3,		// PROC On / Off
							sp_4,		// Keyer operating mode - Dot Priority, Iambic A, Iambic B, Vibroplex, or Straight
							sp_5,		// Straight Key CW Release Time Minimum = 200mS, Maximum = 1.5 Seconds
							sp_6,		// Set CW Shift & Side Tone Frequency, Minimum = 300 Hz, Maximum = 1 kHz
							sp_7,		// CW speed pot = CW speed / Squelch-A / Squelch-B
							sp_8,		// CW Keyer Speed Preset
							sp_9,		// CW/CWR Swap Enable/Disable
							sp_10,		// LCD back light intensity
							sp_11,		// LCD Contrast
							sp_12,		// LCD back light timer
							sp_13,		// Serial I/O mode/protocol select.
							sp_14,		// Select user UART1 Baud rate
							sp_15,		// Select VFO mode / Number of memories in use
							sp_16,		// Select VFO Equalisation mode
							sp_17,		// Select type of S-Meter display, Graphic (original) or Numeric
							sp_18,		// Numeric S-Meter Peak Hold Time Minimum = 250mS, Maximum = 5 Seconds.
							sp_19,		// Enable / Disable out-of-band checks for transmitter inhibit
							sp_20,		// Auto Sideband Select Enable/Disable
							sp_21,		// Frequency Display Old/New select
							sp_22,		// Band Switch Mode Select 0 = Default, 1 = User Frequencies, 2 = Current Frequency, 3 = User Frequencies (Locked)
							sp_23,		// Choose whether to include the RIT frequency with the displayed frequency
							sp_24,		// Select attenuation in TUNE mode
							sp_25,		// Select VFO decade adjustment
							sp_26,		// Graphic Scale Display select, Original, Large Markers, Small Markers
							sp_27,		// Noise blanker data-point now used for Fast Power OFF flag
							sp_28,		// RF O/P Power meter type
							sp_29,		// Start-Up Page Selection
							sp_30		// CW Annunciation On/Off, Type Select
							};

void display_cfg_page(void)
	{
	bl_on();
	sprintf(lcdpbuff, _16s, user_cfg_prompts[prompt_index[sub_page1]]);	// Select appropriate prompt message,
	display_line(LINE1, lcdpbuff);			// and display it.
	set_cfg[sub_page1]();					// Select the appropriate adjustment page,
	display_line(LINE2, lcdpbuff);			// and display the returned value.
	}

void fast_cfg_page(void)
	{
	int page;

	page = sub_page1;

	page += encoder_get_coarse(ENCODER_MEDIUM);
	max_min(&page, MAX_SUB_PAGE1, 0);

	if((page == 3) && (AF_Input == LINE))
		skip_page(sub_page1, &page);		// Skip Speech Processor setting if input is LINE

	if((page == 5) && (Keyer_Mode != STRAIGHT_KEY))
		skip_page(sub_page1, &page);		// Skip Straight Key Release Time adjustment if keyer is not in STRAIGHT mode

	if((page == 14) && (Serial_Mode == DISABLED))
		skip_page(sub_page1, &page);		// Skip RS-232 port Baud rate adjust if port is disabled

	if((page == 16) && (maximum_VFO != SPLIT_MODE))
		skip_page(sub_page1, &page);		// Skip VFO Equalisation setting if SPLIT MODE is not selected

	sub_page1 = page;
	no_adj = TRUE;							// Ensure that all parameter setting adjustments are inhibited,
	display_cfg_page();						// and display the current configuration page,
	no_adj = FALSE;							// now restore normal parameter adjustments.
	}

void dm_0(void)
	{
// Display the current mode or blank
	(dsp2_ctr & 0x01) ? lcd_spc(4) : lcd_putst(mode_msg[eeprom.defval.mode[vfo_idx]]);
// Display the current filter or blank
	if(PTT_IN)								// Are we in RX mode?
		(dsp1_ctr & 0x01) ? lcd_spc(3) : lcd_putst(filter_width[RX_Bandwidth]);
	else
		lcd_putst(Display_TX);				// No, so display TX message instead.
	}

void dm_2(void)
	{
	(!swr) ? lcd_putst(Display_SWR) : disp_meter((double)swr, SWR);
	}

void dm_3(void)
	{
	double v;

	v = (double)batt_raw * (double)(cal.calval.batt_mult);
	batt_mean_val = (batt_mean_val * 0.9) + (v * 0.1);		// 10-sample running average.
	disp_meter(batt_mean_val, VOLTS);						// New version - 5B4AIY
	}

void (*dsp_mode[])(void) = {			// Indexed by sub_page0
						dm_0,			// 0 - Normal Display S-Meter(Rx)/Analog Power Meter(Tx), Mode, Filter
						disp_fwd_pwr,	// 1 - S-Meter(Rx)/Analog Power Meter(Tx), Digital Watt-meter
						dm_2,			// 2 - S-Meter(Rx)/Analog SWR(Tx), Digital SWR (disp_meter())
						dm_3,			// 3 - S-Meter(Rx)/Analog Voltmeter(Tx), Digital Voltmeter (disp_meter())
						disp_id			// 4 - S-Meter(Rx)/Analog Ammeter(Tx), Digital Ammeter
						};

void lcd_0(void)							// Normal display mode, cursor is already at the start of Line 1
	{
	display_bar_meter();					// Display S-meter or PWR meter bar graph
	dsp_mode[sub_page0]();					// Display sub page (Normal/Power/SWR/Voltage/Current)
	disp_freq((RIT_On_Off && eeprom.defval.RIT_Include && PTT_IN) ? freq_in_use + (long)rit : freq_in_use);
	lcdoutch(SPACE);
// Check if special RIT format is required
	if(RIT_On_Off && PTT_IN)				// RIT ON and RX
		{
		disp_rit(rit);
		}
	else									// RX/TX RIT OFF
		{
// Normal VFO display
		if(split_flag)
			lcd_putst(Display_Splt);
		else
			{
			lcd_putst(mv[1]);				// Display "VFO",
			lcdoutch(Select_VFO + 'A');		// and VFO letter.
			}
// Display lock symbol and tuning step
		lcdoutch(lock_symbol[vfo_lock]);
		lcdoutch(tuning_step[Tuning_Step]);
		}
	}

void (*lcd_dsp[])(void) = {					// Indexed by lcd_mode
						lcd_0,				// 0 - Normal Display
						display_cfg_page,	// 1 - User Configuration Display
						display_alarm		// 2 - Alarm Display
						};

void vfo_memory_copy(int reset)
	{
	static int vfo;

	if(reset)
		{
		vfo = 0;
		return;
		}

	vfo += encoder_get_coarse(ENCODER_MEDIUM);
	max_min(&vfo, 25, -26);

	if(vfo < 0)			// Copy memory to Active VFO
		{
		copy_flag = LEFT_ARROW;				// Left direction arrow
		src_vfo = -(vfo + 1);
		dst_vfo = (split_flag)
				? VFO_A
				: Select_VFO;	// If SPLIT mode is active, then VFO-A is the destination VFO.
		sprintf(lcdpbuff, copy_vfo, (char)(dst_vfo + 'A'), (char)copy_flag, mv[(src_vfo < maximum_VFO)], (char)(src_vfo + 'A'));
		}
	else				// Copy Active VFO to memory
		{
		copy_flag = RIGHT_ARROW;			// Right direction arrow
		src_vfo = (split_flag)
				? VFO_A
				: Select_VFO;	// If SPLIT mode is active, then VFO-A is the source VFO.
		dst_vfo = vfo;
		sprintf(lcdpbuff, copy_vfo, (char)(src_vfo + 'A'), (char)copy_flag, mv[(dst_vfo < maximum_VFO)], (char)(dst_vfo + 'A'));
		}

	display_line(LINE1, lcdpbuff);			// Display the copy message
	disp_freq(eeprom.defval.vfo[src_vfo]);	// Display the source VFO frequency

	if(check_bit(dst_vfo))
		{
		lcd_putst(band_sw_msg[_LOCKED]);	// Message is 'Locked'
		copy_flag = FALSE;					// Clear copy flag
		}
	else
		{
		lcd_spc(3);
		lcd_putst(mode_msg[eeprom.defval.mode[src_vfo]]);
		}
	}

void mode_function(void)
	{
	if(lcd_mode == CONFIG_DISPLAY) fast_cfg_page();
	else vfo_memory_copy(FALSE);
	}

void synch_beep(void)
	{
	int time;

	time = decay_counter;

	if(time < BUTTON_DEBOUNCE)
		{
		decay_counter = 0;					// Belt & Braces code!
		ms_delay(time);
		warning_beep();
		ms_delay(BUTTON_DEBOUNCE - time);
		}
	else ms_delay(BUTTON_DEBOUNCE);
// Prevents spurious page/band/memory change if VFO knob rotated whilst holding the button.
	reset_encoder();
	}

void Lock_VFO(int vfo)
	{
	display_line(LINE1, VFO_Lock_msg);		// Display the current VFO's lock status

	if(PWR_SW)								// If PWR switch is pressed,
		{
		toggle_lock(vfo);					// toggle current VFO's lock status

		while(PWR_SW)						// Wait until PWR button is released
			{
			if(hold_latch == LATCH)			// This is necessary so that the warning beeps
				{							// continue even if the PWR button is held when
				warning_beep();				// in SPLIT mode toggling the VFO/Memory Lock.
				synch_beep();
				}
			else ms_delay(BUTTON_DEBOUNCE);	// Make de-bounce for Press & Hold mode
			}
		}
	}

void VFO_Select(int enable)
	{
	if(enable)
		{
		vfo_idx += encoder_get_coarse(ENCODER_MEDIUM);	// Read encoder, 26 memories = about 1 turn
		max_min(&vfo_idx, VFO_Z, VFO_A);
		}

	if(vfo_idx >= maximum_VFO)
		Lock_VFO(vfo_idx);
	else
		{
		display_line(LINE1, Select_VFO_msg);
		Select_VFO = vfo_idx;
		}

	bottom_line(vfo_idx);
	}

void Toggle_VFO_Lock(int enable)
	{
	static int vfo;

	if(enable)
		{
		vfo += encoder_get_coarse(ENCODER_MEDIUM);	// Select VFO
		max_min(&vfo, VFO_Z, VFO_A);		// and keep within range
		}

	Lock_VFO(vfo);
	bottom_line(vfo);						// Display VFO frequency and lock status.
	}

void equalise_VFO(int source)
	{
	int destination;

	destination = source ^ 0x0001;

	if(check_bit(destination)) sprintf(lcdpbuff, vfo_locked, ('A' + (char)destination));	// VFO Locked
	else
		{						// Equalise the VFO frequencies and modes.
		eeprom.defval.vfo[destination] = eeprom.defval.vfo[source];
		eeprom.defval.mode[destination] = eeprom.defval.mode[source];
		A_equals_B_flag = 2;	// Inserted to fix the Auto-Update for TRX-Manager
		}
	}

void rapid_band_switch(int adj)
	{
	if(vfo_lock) sprintf(lcdpbuff, vfo_locked, vfo_idx + 'A');	// If the 'active' VFO is locked, then display the message and abort.
	else
		{
		band_in_use = select_nearest_band(eeprom.defval.vfo[vfo_idx]);
		sprintf(lcdpbuff, selected_band, band[band_in_use]);

		if(adj)									// If the adjust flag is enabled,
			{
			int step = encoder_get_coarse(ENCODER_MEDIUM);

			if(step) RBS_Flag = OFF;

			band_in_use += step;
			max_min(&band_in_use, HIGHEST_BAND, LOWEST_BAND);
			}
		else reset_encoder();

		if(RBS_Mode == _DEFAULT)				// If RBS is in the DEFAULT mode, then use the Default frequencies,
			{
			eeprom.defval.vfo[vfo_idx] = amateur_bands[band_in_use - 1];

			if(eeprom.defval.Auto_SB) eeprom.defval.mode[vfo_idx] = (band_in_use > 3) ? USB : LSB; 
			}
		else									// Otherwise, if RBS is in MODE-A or MODE-B, use the User Mode frequencies,
			{
			eeprom.defval.vfo[vfo_idx] = eeprom.defval.vfo[band_in_use + 29];
			eeprom.defval.mode[vfo_idx] = eeprom.defval.mode[band_in_use + 29];
			}

// If VFO Equalisation is enabled, and VFO mode is A/B + Split...
		if(Equalisation_Mode && maximum_VFO == SPLIT_MODE)
			{									// Prevent cross-band split frequency operation
			if(Select_VFO == SPLIT_MODE || Equalisation_Mode == SPLIT_PLUS_SIMPLEX)
				{								// Check to see if VFO-A and VFO-B are using the same band.
				if(check_freq(eeprom.defval.vfo[VFO_A]) != check_freq(eeprom.defval.vfo[VFO_B]))
					{							// The VFOs are tuned to different bands, so,
					equalise_VFO(vfo_idx);		// equalise their frequency and mode.
					}
				}
			}
		}

	display_line(LINE1, lcdpbuff);				// Display the selected amateur band
	disp_freq(eeprom.defval.vfo[vfo_idx]);		// and the frequency.
	lcd_putst(band_sw_msg[RBS_Mode + RBS_Flag]);// DEFAULT - MODE-A - MODE-B - LOCKED - MODE-C
	}

void send(int element)
	{
	int time = 1;

	time += (element << 1);
	beep(eeprom.defval.cw_sidetone, dot_time * time);

	while(tone_counter);		// Wait while tone generator is busy

	ms_delay(dot_time);			// Inter-element time
	}

void send_char(unsigned char symbol)
	{
	unsigned int length;

	length = symbol >> 5;		// Extract the symbol length, 1 - 5 elements.
// Note: When sending dual symbols in status for MODE, length is zero for second symbol!
	while (length--)
		{
		send(symbol & 0x01);	// Send the element, 0 = Dot, 1 = Dash,
		symbol >>= 1;			// select the next element.
		}

	ms_delay(ics * dot_time);	// Inter-Character time
	}

void select_symbol(int type)	// type = 0 Letters, 1 Figures, 2 Mixed
	{
	static int previous_character;
	int limit = 26, offset = 10;		// Start with LETTERS
	unsigned char c;

	if(type == 2) type = rand() & 1;	// Randomly select either Letters or Numbers

	if(type)					// Numbers
		{
		limit = 10;
		offset = 0;
		}

	do {						// This prevents two identical sequential characters
		c = offset + (rand() % limit);
		} while(c == previous_character);

	previous_character = c;
	send_char(morse_symbols[c]);// Send the current Morse character
	c += (c < 10) ? ZERO : 55;	// Convert index to ASCII character,
	scroll_LCD(LINE2, c);		// and add it to the LCD and scroll display.

	if(Serial_Mode == SERIAL_TEST) printf("%c", c);
	}

int send_status(int select_flag)
	{
	unsigned int i, ws = 0;		// ws = Word Space dot time counter
	unsigned char c;

	if(select_flag & SKIP_CYCLE) return select_flag & 0x000F;	// Skip 1 loop cycle to ensure frequency has updated when changing VFOs.

	if(select_flag == 0x000F) ws = 4;

	if(select_flag & 0x0001)	// Announce current mode
		{
		i = morse_mode[eeprom.defval.mode[vfo_idx]];
		send_char((unsigned char)(i & 0x00FF));					// Send first letter of current mode (L, U, C, C, T)
		send_char((unsigned char)(i >> 8));						// Send second letter or nul and, if this is the FULL mode,
		ms_delay(dot_time * ws);								// delay a word space. (We have already sent 3 dot-times for a character space)
		}

	if(select_flag & 0x0002)	// Announce current filter
		{
		send_char(morse_filter[RX_Bandwidth]);					// Send current filter (N, W), and, if this is the FULL mode,
		ms_delay(dot_time * ws);								// delay a word space. (We have already sent 3 dot-times for a character space)
		}

	if(select_flag & 0x0004)	// Announce current VFO
		{
		(split_flag) ? send_char(LTR_S) : send_char(LTR_V);		// Check for Split Mode
		send_char(morse_symbols[vfo_idx + 10]);					// Send current VFO letter (A - Z), and, if this is the FULL mode,
		ms_delay(dot_time * ws);								// delay a word space. (We have already sent 3 dot-times for a character space)
		}

	if(select_flag & 0x0008)	// Announce current frequency, kHz resolution
		{
		sprintf(f_buff, f_fmt, (double)(freq_in_use / 1000.0));	// Convert current VFO frequency to ASCII string
		send_char(LTR_F);										// Send the leading 'F' character, followed by
		i = 0;

		do	{													// the frequency digits rounded to kHz.
			c = f_buff[i++];									// Get the next frequency digit,

			if(isdigit(c)) send_char(morse_symbols[c - ZERO]);	// ignore leading spaces, convert to index, and send number
			} while(i < 5);
		}
	return OFF;													// Clear the cw_status word.
	}

// main __________________________________________________________________________________

int main(void)
	{
	int cw_status = 0, old_cw_pot = 0;
	unsigned int y, w;
//	Note:	y and w used when checking EEPROM. y is also used to restore the FILTER setting when returning from User Configuration.
// Set general I/O
	TRISA = INIT_TRISA;						// Switches, PTT
	PORTA = INIT_PORTA;

	TRISB = INIT_TRISB;						// ADC inputs, TXEN, RXEN, General I/O
	PORTB = INIT_PORTB;

	TRISC = INIT_TRISC;						// Sideband select & switches
	PORTC = INIT_PORTC;

	TRISD = INIT_TRISD;						// LEDs & LCD pins = output
	PORTD = INIT_PORTD;

	TRISF = INIT_TRISF;						// DDS controls
	PORTF = INIT_PORTF;

	TRISG = INIT_TRISG;						// DDS controls, EEPROM, DScard signals
	PORTG = INIT_PORTG;

// Power switch
	PWR_ON = ON;							// Secure power ON

// Start LCD
	initlcd();								// Initialise the LCD, and use default brightness and contrast values.

// Start PWM system
	IPC0 = 0x5444;							// Set tone generator (TMR1) priority higher than others
	init_timers_pwm();						// Setup PWM & Tone Generators

// Start DDS
	dds_init();								// Initialise the AD9851 synthesiser

// CW
	cw_period = 50;							// Set something before IRQ system starts
	fcy = FCY / 1000;						// Clock frequency (kHz)

// Initialise Main Board SPI traffic
	init_spi1();
	send_packet_to_74hc595();

// Start UART & print hello messages
	InitUSART1();							// Wake up serial interface, and initialise the buffer pointers.
	InitUSART2();							// Wake up secondary serial interface, and initialise its buffer pointers.

// Initialise the A-D converter
	init_adc12();							// Setup A/D converter, must be done before Keyer is started, RB I/O bits

// Read Calibration & User Configuration values from EEPROM
	y = read_calval();
	w = read_defval();

	if(y || w)								// If either checksum is non-zero, then checksum error.
		{
		display_screen(Display_ChkSumErr, Display_Load_Defaults);
		set_factory_defaults();				// EEPROM empty or corrupted, set factory defaults
		ms_delay(1000);
		}

	if(cal.calval.splash)
		{
		sprintf(lcdpbuff, Hello, Display_JUMA_TRX2, VERSION);
		display_screen(lcdpbuff, Display_OH2NLT_OH7SV);
		ms_delay(1000);
		}

// Init ISD1700 voice memory if present.
// If not checked here, then the audio channels are not set, and the Service Mode beep is inaudible.
	init_isd1700();

// Start encoder
	encoder_init();							// Initialise encoder, enable INT4

// Open audio channel and give start up notification 
	init_scaf_clock();						// Open audio channel, start SCAF clocking
	ms_delay(50);

// Check for Service Mode
	delay_time = 500;

	if(PWR_SW)
		{
		button_debounce(PWR_SW);

		if(!button_count)
			{
			beep(HZ698_45, SHORT_BEEP * 4);	// Give service beep
			sprintf((char *)lcdpbuff, Calibration_Mode, VERSION);
			display_screen(Calibration, lcdpbuff);
			wait_PWR_rls();					// Show message as long as Power switch is pressed
			ms_delay(500);					// and wait.
			svc_flag = TRUE;
			service();
			delay_time = 0;
			}
		}
// Beep if delay_time is true, and neither SW1 (DISPLAY/CONFIG), nor SW2 (FAST/VFAST), nor SW5 (MODE) nor SW6 (FILTER) buttons are pressed.
	if(delay_time && SW1 && SW2 && SW5 && SW6) beep(HZ698_45, SHORT_BEEP * 2);

// Check if factory defaults requested
	if(_MODE)								// Reset Factory Defaults
		{
		beep(HZ587_31, cal.calval.beep_len);
		save_settings(1, 4);				// If MODE button pressed, restore and save factory default calibration and configuration settings.
		}

// LCD back light timer
	bl_on();								// Set LCD back light on using EEPROM contrast and brightness settings

// Set last used frequency
	if(Select_VFO == SPLIT_MODE)
		vfo_idx = VFO_A;						// If in split mode, set to VFO-A
	else
		vfo_idx = Select_VFO;					// Copy VFO selection for processing

	freq_in_use = eeprom.defval.vfo[vfo_idx];	// Set last used frequency
	dds_load(freq_in_use);						// Load DDS

// Set User Baud rate
	SetUSART1baud(Baud_Rate);

	if(Serial_Mode == SERIAL_TEST)				// Test Mode selected, so display boot messages
		{
		display_hdr();
		printf(baud_rate_msg, br_txt[Baud_Rate]);
		printf(Display_System_Clk, fcy);
		printf(VM_Option_Found, Not_Installed[isd_1700_installed]);
		printf(Display_EEPROM_Chksum, eeprom_err[y], eeprom_err[w], fd_counter);
		}

	putst2(Display_UART2_msg);					// Say hello to UART2

// RS-232 I/O Test
	if(_DISPLAY)								// RS-232 I/O Test
		{
		beep(HZ587_31, cal.calval.beep_len);
		rs232_test();							// If CONFIG/DISPLAY pressed during startup, run RS-232 test.
		beep(HZ466_85, cal.calval.beep_len);
		}

// Clear TRX-2/PA-100D/Yaesu/Kenwood CAT message receiver buffer
	clear_buffer();
	auto_inform = OFF;							// Set Auto-Inform OFF
	reset_state();								// Reset Auto-Inform data-points

// Display current Region Setting
	if(cal.calval.splash == JUMA_REGION)
		{
		no_adj = TRUE;
		cal_page = 16;
		display_svc_page();
		ms_delay(1250);
		no_adj = FALSE;
		}
	else ms_delay(delay_time);

	if(cal.calval.Band_Limits)					// First set the upper frequency limits for both US licence classes
		{
		lower_limit[1] = 1800000L;				// US has the use of the bottom 10kHz of 160m.
		upper_limit[2] = _80M_UPPER_USA;
		upper_limit[3] = _40M_UPPER_USA;
		}

	if(cal.calval.Band_Limits == USA_GENERAL)	// Now set the lower frequency limits for the US General class
		{
		lower_limit[2] = 3525000L;
		lower_limit[3] = 7025000L;
		lower_limit[5] = 14025000L;
		lower_limit[7] = 21025000L;
		}

	if(cal.calval.alarm_flags & LO_V_AL_ON)		// If Under-Voltage alarm is enabled, set the low voltage warning limit
		low_voltage_warning = cal.calval.undervoltage_trip + (int)int_round(100000L, (long)cal.calval.batt_mult);

	set_chgen(Display_Scale);					// Load bar graph fonts

	if((display_page & 0x07) == LAST_PAGE)
		sub_page0 = (display_page >> 4);		// Restore last saved page
	else
		sub_page0 = display_page & 0x07;		// Restore preset page

	s_meter_timer = eeprom.defval.Hold_Time;
	old_cw_pot = 0x7FFF;						// Ensure CW Speed is set first time round
	A_equals_B_flag = FALSE;
	set_tx_filter_bw();
	power_bar_graph_const = (double)cal.calval.fwd_pwr_mult / PWR_BAR_CONSTANT;		// See note in juma-trx2.h
	id_const = int_round((long)cal.calval.overcurrent_trip, 48L);					// Used as a scale factor for drain current in meter_value()
	batt_mean_val = (double)convert_adc12(BATT_CH) * (double)(cal.calval.batt_mult);// Initial value during start-up
	batt_scale_factor = cal.calval.overvoltage_trip - cal.calval.undervoltage_trip;	// Used as a scale factor for drain current in meter_value()
	RS_232_Mode = port_mode[Serial_Mode];		// Set current Serial Port Mode (Avoids pointless loop invariant address calculation)

// Auto-Equalisation
	if(_VFAST)									// If FAST/VFAST button is pressed
		{
		int err_flag = ABORT;					// Temporary local variable.

		beep(HZ587_31, cal.calval.beep_len);
		display_screen(Automatic, OP_Equalisation);
		wait_FAST_VFAST_rls();					// Wait for FAST/VFAST button release
		display_screen(Proceed, PWR_No_MODE_Yes);

		if(wait_PWR_MODE())						// If MODE was pressed
			{
			err_flag = auto_equalise(FALSE);	// Invoke automatic equalisation.

			if(!(err_flag & 0x00FF))			// Check error flag,
				{
				display_line(LINE2, PWR_Exits);	// First display the exit message,

				do	{							// and now repeatedly display
					display_atten(err_flag);	// the equalisation settings,
					display_line(LINE1, lcdpbuff);
					} while(!PWR_SW);			// and wait for the PWR button to be pressed to exit.

				wait_PWR_rls();					// Prevents spurious VFO lock.
				}

			err_flag &= 0x00FF;					// Mask off the reference value leaving only the error flag.
			}

		if(err_flag)							// If error flag is set,
			{
			display_screen(Equalisation, Aborted);
			ms_delay(1500);						// display the aborted message for 1500mS.
			}
		}

// CW Practice Mode
	if(_FILTER)									// CW Practice Mode
		{
		int word_count, type = 0, words = 5;	// Local variables

		display_screen(CW_Practice_Msg, "");	// Display 'CW Practice Mode'
		wait_FILTER_rls(TRUE);					// Wait for FILTER button to be released

		if(Serial_Mode == SERIAL_TEST) printf(CW_Practice_fmt, New_Line, CW_Practice_msg, dividing_line, New_Line);

		display_line(LINE2, FILTER_Next_msg);

		do	{									// Select LCD scrolling direction
			get_one_zero(&scroll_direction);
			sprintf(lcdpbuff, Scroll_Msg, direction[scroll_direction]);
			display_line(LINE1, lcdpbuff);		// Display the selection
			} while(SW6);						// Repeat as long as FILTER button is not pressed,

		wait_FILTER_rls(TRUE);					// Wait for FILTER button to be released
		reset_encoder();

		do	{
			word_count = 0;
			display_line(LINE2, FILTER_Next_msg);

			do	{									// Select Letters, Figures, or Mixed.
				type += encoder_get_coarse(ENCODER_MEDIUM);
				max_min(&type, 2, 0);				// Ensure that the type is within range
				sprintf(lcdpbuff, Select_Type_fmt, Message_Type[type]);
				display_line(LINE1, lcdpbuff);		// Display the selection
				} while(SW6);						// Repeat as long as FILTER button is not pressed,

			wait_FILTER_rls(TRUE);					// Wait for FILTER button to be released
			display_line(LINE2, FILTER_Next_msg);

			do	{
				words += encoder_get_coarse(ENCODER_MEDIUM);
				max_min(&words, 25, 1);
				sprintf(lcdpbuff, Number_Of_Groups_fmt, words);
				display_line(LINE1, lcdpbuff);		// Display the selection
				} while(SW6);						// Repeat as long as FILTER button is not pressed,

			wait_FILTER_rls(TRUE);					// Wait for FILTER button to be released
			display_line(LINE2, FILTER_Start_msg);	// Display 'FILTER = START'
			srand(ms_counter + 1);					// Seed the random number generator to ensure we do not get the same sequence every time

			do	{									// Display the WPM and Inter-Character spacing,
				dot_time = cw_speed(convert_adc12(CW_POT));
				ics += encoder_get_coarse(ENCODER_MEDIUM);
				max_min(&ics, 15, 3);				// Ensure the inter-character spacing is within range
				sprintf(lcdpbuff, Speed_Space_fmt, 1200 / dot_time, ics);
				display_line(LINE1, lcdpbuff);		// and display the current settings,
				} while(SW6);						// and repeat until the FILTER button is pressed.

				beep(HZ587_31, cal.calval.beep_len);
				sprintf(lcdpbuff, _16s, " ");		// Clear the display buffer
				display_line(LINE2, lcdpbuff);		// and line 2.
				ms_delay(500);						// Pause to allow student to prepare,

				while(word_count++ < words)
					{
					int characters = 5;

					do	{
						select_symbol(type);
						} while(--characters);

					ms_delay(dot_time * (1 + ics));	// Morse word space (Inter-Character space already accounted for)

					if(word_count < words)
						{
						scroll_LCD(LINE2, SPACE);	// Word Space

						if(Serial_Mode == SERIAL_TEST) printf(" ");
						}

					if((Serial_Mode == SERIAL_TEST) && (!(word_count % 5))) printf(New_Line);
					}

				if(Serial_Mode == SERIAL_TEST)
					{
					word_count--;

					if((word_count % 5)) printf(New_Line);

					printf(line_space, dividing_line, New_Line);
					}

				ms_delay(1000);						// Pause, then prompt for repeat.
				display_screen(save_settings_prompt[3], PWR_No_MODE_Yes);
			} while(wait_PWR_MODE());				// Continue until aborted.

		wait_PWR_rls();								// Avoids a spurious VFO lock.
		ics = 3;									// Reset inter-character space to the standard setting.
		}

	ClearUSART1queue();								// Ensure serial buffer is clear
	dot_time = eeprom.defval.cw_annunciation >> 8;
// Main forever loop _____________________________________________________________________________________________________________
	do	{
		vfo_lock = check_bit(vfo_idx);				// Set/Clear VFO Lock for this VFO
		band_in_use = check_freq(freq_in_use);		// Check valid amateur band frequency, 1 - 9 (160m - 10m)
		split_flag = ((maximum_VFO == SPLIT_MODE) && (Select_VFO == SPLIT_MODE));
		tx_enable = ((!eeprom.defval.OOB_Check || band_in_use) && !lcd_mode);
		check_alarm();
		button_count = DEBOUNCE_COUNT;				// Set each time around loop, so that it is ready for debounce count.
		offset = 0;									// Cancel any frequency offset. In RX, the CW/CWR/RIT offsets will be added, in TX there is no offset.
		lcd_cmd(LINE1);								// Start from line 1,
		lcd_dsp[lcd_mode]();						// and display current LCD major page mode data.

// Send CW status. It has to be here to ensure that the frequency display updates before the status is sent when changing VFOs.
		if(cw_status && !mode_ctr)					// Ensure all display blinks are finished.
			cw_status = send_status(cw_status);		// Send the current CW Annunciation status.
/*
 The following module causes the mode or filter display to blink twice, if one of the measurements display pages
 is currently in use. The variable: mode_ctr gets set to MODE_COUNTER in the function: set_mode_blink(), and this
 is defined as:(4 * MODE_CHANGE) - 1, MODE_CHANGE is defined as a value of 80, so mode_ctr gets set to 319.
 If the mode_ctr variable has decremented to 0, then this causes the sub-page to be reset to its initial value.

 The variable: sub_page0 is normally 0, to display the main page with the S-meter and mode/filter settings, but
 pressing the DISPLAY/CONFIG button increments it to 1 to display S-meter + Watt-meter, 2 to display S-meter + SWR,
 3 to display S-meter + Voltmeter, and 4 to display S-meter + Ammeter. So, if we are displaying any page other
 than 0 when we change the mode or filter setting, we save sub_page0, set sub_page0 to 0 and display the mode/filter
 settings for two blinks, then restore the original sub_page value.

 The variable: dsp1_ctr is the counter for the filter setting. The variable dsp2_ctr is the counter for the mode.
 Initially these variables get set by set_mode_blink() to 1, which causes a blank to be displayed in function: dm_0().

 On the first time through they get set to 3, because 319 / 80 is 3 in integer arithmetic. This value persists
 until the mode_ctr has decremented to 239, whereupon 239 / 80 = 2. At this point in the function: dm_0() we now
 display the message. When mode_ctr has decremented to 159, dsp_1_ctr gets set to 1, which causes a blank to be
 displayed again. When mode_ctr has decremented to 79, dsp1_ctr is 0, and this again causes the message to be
 displayed. Finally, mode_ctr decrements to 0, the original display page is restored,and we exit, and it's all over.
 A similar set of operations occurs for dsp2_ctr for the mode display. As the main loop takes about 4mS to execute,
 this gives roughly 400mSec on and 400mSec off.
*/
		if(mode_ctr)
			{
			if(dsp1_ctr) dsp1_ctr = mode_ctr / MODE_CHANGE;	// Mode change blink
			if(dsp2_ctr) dsp2_ctr = mode_ctr / MODE_CHANGE;	// Filter change blink

			mode_ctr--;										// Decrement the blink counter

			if(!mode_ctr) sub_page0 = tmp_sub_page0;		// Restore previous display page
			}
/*
 This test code is only used to measure the loop cycle time. Version 1.07k takes 7 seconds
 between beeps, giving a loop cycle time of 7mSec.
 Version 1.07n takes 14mSec when displaying frequencies to 1Hz.
 When using the "long" method with repeated division and multiplication the loop time is 6.3mSec,
 When displaying to 10Hz using sprintf(), the loop time is 7mSec.
 Version 1.07t loops in 7.8mSec
 Version 1.07w Build 17 loops in 7.9mSec (10 loops in 79 seconds)
 Version 1.08a Build 4 loops in 6.6mSec (10 loops in 66 seconds)
 Version 1.09a Build 4 loops in 8.85mSec (20 loops in 177 seconds)
 Version 1.09a Build 5 loops in 8.85mSec (20 loops in 177 seconds)
 Version 1.10p Build 1 loops in 6.64mSec (50 loops in 332 seconds)
 Version 1.10q Build 7 loops in 7.12mSec (50 loops in 356 seconds)
 Version 3.00a Build 11 Timing
 Fifty loops, each of 1,000 actual main loop cycles
 Page	RX		TX		RX		TX
	0	2:55	2:49	3.50mS	3.38mS	Mode - Filter BW
	1	2:55			3.50mS			Watts
	2	2:56			3.52mS			SWR
	3	3:38			4.36mS			Voltage
	4	2:54			3.48mS			Current
 See notes in lcd-trx2.c for further information
 Set MEASURE_CYCLE_TIME to TRUE to utilise this test code.
*/
#if MEASURE_CYCLE_TIME
		if(loop_ctr2) loop_ctr2--;
		else
			{
			loop_ctr2 = 1000;
			beep(4700, SHORT_BEEP);
			}
#endif
		if(copy_flag && SW5)					// Copy source frequency to destination when SW5 is released and copy_flag is set.
			{
			eeprom.defval.vfo[dst_vfo] = eeprom.defval.vfo[src_vfo];
			eeprom.defval.mode[dst_vfo] = eeprom.defval.mode[src_vfo];

			if(copy_flag == RIGHT_ARROW) changed_flag = TRUE;

			copy_flag = FALSE;					// Clear copy flag
			vfo_memory_copy(TRUE);				// Reset memory copy
			}
/*
 PTT_IN is a copy of the actual logic state, known as PTT_IN_IO, on the RB6 pin of the microprocessor. PTT_IN: 1 = RX, 0 = TX
 This uses fewer instructions than actually reading the input pin itself each time it is required. Reading the I/O pin requires
 15 bytes of memory, 5 instructions. There are 10 instances, thus a saving of 150 bytes.

 The PTT_IN_IO signal is read from pin 21 (RB6) of the microprocessor. This pin is connected to the drain of Q4. The drain is either
 pulled low by the microphone PTT switch via R44, or is driven low by the +ve PTT_OUT signal on the gate of Q4. The PTT_OUT comes from
 pin 22 of the microprocessor, I/O port RB7, and is logically derived from various internal states. (See timers_pwm.c for details.)
*/
		if(PTT_IN_IO)							// RX mode
			PTT_IN = RECEIVE;					// Copy I/O bit to status flag - RX
		else									// TX mode
			{
			bl_on();							// Turn LCD backlighting on

			if(tx_enable)						// Transmit enabled.
				{
				PTT_IN = TRANSMIT;				// TX state
				}
			else								// Transmit disabled.
				{
				PTT_IN = RECEIVE;				// Force to RX state
				display_line(LINE1, (lcd_mode) ? TX_Disabled : out_of_band);
/*
 This logic fixes the bug that allowed transmission in SSB even when out-of-band. The hardware logic is such
 that the PTT switch is connected directly to the TX/RX logic, as the PTT signal on the main board, sheet 3 of 3,
 REGULATORS/CONTROL/CONNECTORS, top left-hand corner, R71/C71 connected to IC4A. However, if the state is set to
 TUNE or CW, then the SSB/!CW is asserted, and this asserts the !TX-SSB signal. This is fed to the microphone
 amplifier on the main board, sheet 2 of 3, TX SECTION, bottom right-hand section, gate of TR5. This ensures that
 the microphone amplifier feedback loop is shorted, giving a large amount of attenuation, and ensuring that little
 or no RF is generated, even though the PTT switch is closed. Note that there may be a brief pulse of RF generated.
 If the PTT switch is closed immediately after this point has been passed, and there is some audio present, then
 RF will be generated until the loop cycles back around to here, whereupon it will be suppressed. It takes about
 3 to 4 mSec to cycle through the main loop, and thus in theory you could generate a brief pulse of RF.
 The state decoder is set to the correct machine state later on in this code - line 5171.
 Adrian Ryan - 5B4AIY 23/JUN/2012
*/
				if(eeprom.defval.mode[vfo_idx] < CW)		// Is the mode LSB or USB?
					{
					int mode;								// Temporary local variable.

					mode = eeprom.defval.mode[vfo_idx];		// Yes, so save the current mode,
					eeprom.defval.mode[vfo_idx] = TUNE;		// and set the mode temporarily to TUNE,
					send_packet_to_74hc595();				// and switch the hardware to the TUNE state,
					eeprom.defval.mode[vfo_idx] = mode;		// and now restore the original mode.
					}

				wait_PTT_rls();						// Wait for PTT switch to be released,
				}
			}

// Evaluate CW keyer enable condition, Split mode needs special conditions
// Using the split_flag instead of the tortuous previous logic eliminated 12 lines of code.
// Select Active VFO
		if(split_flag)								// If Split Mode is active,
			{
			vfo_idx = (PTT_IN) ? VFO_A : VFO_B;		// then use VFO-A for RX and VFO-B for TX.

			if(eeprom.defval.mode[VFO_B] == TUNE) eeprom.defval.mode[VFO_B] = eeprom.defval.mode[VFO_A];

			cw_active = (eeprom.defval.mode[VFO_B] == CW || eeprom.defval.mode[VFO_B] == CWR);
			}
		else
			{
			vfo_idx = Select_VFO;					// Else use currently selected VFO.
			cw_active = (eeprom.defval.mode[vfo_idx] == CW || eeprom.defval.mode[vfo_idx] == CWR);
			}

// Tune Function
		if(eeprom.defval.mode[vfo_idx] == TUNE)		// TUNE mode selected
			{
			if(!PTT_IN && tx_enable)				// KEY follows PTT switch in tune mode
				{
				KEY = ON;							// Enable carrier

				if(!tune_on)
					{
					beep_number = 3;
					tune_on = ON;
					}
				}
			else
				{
				KEY = OFF;							// Remove carrier
				tune_on = OFF;
				}
			}

// Handle rotary encoder ( VFO )
		if(enc_event && (lcd_mode == NORMAL_DISPLAY))// Adjust frequency if encoder rotated and display page 0 selected
			{
			if(!vfo_lock)							// Not locked
				{
				bl_on();							// LCD back light
				eeprom.defval.vfo[vfo_idx] += (encoder_get() * f_steps[Tuning_Step]);

				if(eeprom.defval.vfo[vfo_idx] > MAX_DDS) eeprom.defval.vfo[vfo_idx] = MAX_DDS;
				if(eeprom.defval.vfo[vfo_idx] < MIN_DDS) eeprom.defval.vfo[vfo_idx] = MIN_DDS;
				}
			else
				reset_encoder();
			}
// Set CW period
// Convert CW pot
		cw_pot = convert_adc12(CW_POT);						// cw_pot value is used also for squelch

		if(cw_pot != old_cw_pot)
			{
			if(eeprom.defval.sq)							// If pot function is Squelch
				cw_period = cw_speed(Keyer_Speed & UNLOCKED);
			else											// If pot function is CW Speed
				cw_period = cw_speed(cw_pot);				// cw_period time is in mS

			old_cw_pot = cw_pot;
			}

		if(Keyer_Mode == STRAIGHT_KEY)				// If the keyer mode is STRAIGHT KEY,
			{
			if(eeprom.defval.CW_Release > MIN_CW_RELEASE)	// and the release time is set,
				cw_period = eeprom.defval.CW_Release;		// then CW Release time is the user setting.
			else
				cw_period = 7 * cw_speed(old_cw_pot);		// Else it is the default speed release time.
			}

// Set other keyer parameters
		keyer_mode = Keyer_Mode;					// Copy keyer operating mode from EEPROM data. (See timers_pwm.c)

// Read switches
		if(PTT_IN)				// ****************** RECEIVE ******************
			{					// The MODE/FILTER/RIT/VFO/FAST-VFAST/DISPLAY-CONFIG buttons only operate in the receive mode.
// Squelch code
			if(eeprom.defval.sq)							// Run squelch when squelch ON and RX
				{
				if((s_meter + 2) > (cw_pot >> 6) && (mute == AUDIO_ON))	// Check biased meter value against set value, check mute status
					{
					start_scaf_clock();						// Audio on. (Macro in juma-trx2.h)
					sq_timer = SQ_HOLD;						// Reload squelch open timer, 850mS
					squelch_on = OFF;

					if(eeprom.defval.sq == 2) bl_on();		// If Squelch-B is selected, turn backlighting on
					}
				else
					{
					if(!sq_timer)
						{
						stop_scaf_clock();					// Audio off. (Macro in juma-trx2.h)
						squelch_on = ON;					// Squelch closed flag for Yaesu CAT interface
						}
					}
				}
			else											// Squelch not in use
				{
				squelch_on = OFF;
				if(mute) stop_scaf_clock();					// Audio OFF if mute flag set from test code
				else start_scaf_clock();					// SCAF clock ON squelch not in use
				}

			set_scaf_clock(eeprom.defval.scaf_filters[RX_Bandwidth]);	// Select Receive mode filter
			swr = 0;										// Reset SWR
			rit = get_rit();								// rit is used elsewhere in the serial-trx2.c module

			if(cal.calval.swr_delay && (eeprom.defval.mode[vfo_idx] == TUNE))
				swr_al_dly = cal.calval.swr_delay * 1000;	// If extended delay is enabled, and mode is TUNE, use longer delay,
			else
				swr_al_dly = SWR_AL_DLY;					// otherwise use the normal delay.

			if(lcd_mode == NORMAL_DISPLAY)					// The FAST/VFAST, RIT, and VFO buttons only operate in the normal display mode.
				{
// FAST/VFAST (SW2)
				if(_VFAST)									// Allow Tuning Rate changes only in Receive and not in Setup or Configuration Mode
					{
					bl_on();
					button_debounce(_VFAST);

					if(button_count)			// ******* PRIMARY Function *******
						{
						if(Tuning_Step == KILO_HZ)		// If the Very Fast tuning rate is already selected,
							Tuning_Step = TEN_HZ;		// then return to 10Hz rate (Medium).
						else										// Increment tuning rate
							increment_and_check(&Tuning_Step, 3);
						}
					else						// ****** SECONDARY Function ******
						{
						if(eeprom.defval.cw_annunciation)			// If CW Annunciation is enabled,
							{
							if(Tuning_Step == KILO_HZ) Tuning_Step = TEN_HZ;	// If the Very Fast tuning rate is selected, then return to the 10Hz rate (Medium).

							cw_status = (eeprom.defval.cw_annunciation & 0x0001) ? FULL_STATUS : FREQ_STATUS;	// Set the CW Full or Frequency status flag
							}
						else										// Verify fast tuning rate select or exit
							{
							Tuning_Step = (Tuning_Step == KILO_HZ)
								? ONE_HZ							// If the Very Fast tuning rate is already selected, then return to the 1Hz (Slow) rate, 
								: KILO_HZ;							// or, if not, select the Very Fast tuning rate.
							}
						}

					lcd_cmd(LINE2PLUS15);
					lcdoutch(tuning_step[Tuning_Step]);	// This displays the tuning step immediately
					snap_to_step();									// Round VFO frequency to current step size, if enabled.

					if(eeprom.defval.cw_annunciation) beep(HZ587_31, cal.calval.beep_len);
					else beep(status_beep[Tuning_Step], cal.calval.beep_len);

					wait_FAST_VFAST_rls();							// Wait for button release
					debounce();										// Button de-bounce and encoder reset
					}
// RIT (SW3)
				if(_RIT)						// Only allow RIT/RBS to be selected in RX mode, and not in Setup or User Configuration Mode
					{
					bl_on();
					button_debounce(_RIT);

					if(button_count)			// ******* PRIMARY Function *******
						{
						RIT_On_Off ^= 1;						// Toggle RIT On/Off
						beep_number = RIT_On_Off;
						}
					else						// ****** SECONDARY Function ******
						{
						if(band_in_use && (RBS_Mode == _MODE_B) && !RBS_Flag)
							{									// Save current frequency and mode if User-B mode is selected.
							eeprom.defval.vfo[band_in_use + 29] = eeprom.defval.vfo[vfo_idx];
							eeprom.defval.mode[band_in_use + 29] = eeprom.defval.mode[vfo_idx];
							changed_flag = TRUE;
							}

						rapid_band_switch(FALSE);				// Immediately display Rapid Band Switch screen, but do not allow band selection.

						if(hold_latch == LATCH)					// Latched mode
							{
							latch = TRUE;
							while(_RIT) warning_beep();			// Immediately start warning beep
							synch_beep();

							do	{
								warning_beep();
								rapid_band_switch(TRUE);		// Display the Rapid Band Switch screen, and allow band selection.

								if(PWR_SW || _RIT)
									{
									latch = FALSE;				// Release the page hold latch
									beep_number = 2;
									}
								} while(latch);
							}
						else									// Press & Hold mode
							{
							beep(HZ466_85, cal.calval.beep_len * 5);	// Long beep for band switch
							while(_RIT) rapid_band_switch(TRUE);		// While the RIT button is pressed, display Rapid Band Switch pages...
							}
						}
					while(PWR_SW || _RIT);						// Wait for button to be released
					debounce();									// Button de-bounce and encoder reset
					}
// VFO (SW4)
				if(_VFO)										// Do not change if TX is ON, or if in User Setup Mode!
					{
					bl_on();
					button_debounce(_VFO);

					if(button_count)			// ******* PRIMARY Function *******
						{
						increment_and_check(&Select_VFO, (maximum_VFO == SPLIT_MODE) ? 3 : maximum_VFO);

						if(eeprom.defval.cw_annunciation) cw_status = VFO_STATUS;
						else beep_number = (Select_VFO == VFO_A) ? 1 : 2;
						}
					else						// ****** SECONDARY Function ******
						{
						if(maximum_VFO == SPLIT_MODE)			// ***** A/B + Split Mode *****
							{
							eeprom.defval.mode[SPLIT_MODE] = LSB;			// Bug fix, Split mode phantom VFO #2 should never be in Tune mode (Mode = 3), 03.07.2008

							if(Select_VFO == SPLIT_MODE)					// If we are in the SPLIT mode...
								{
								if(hold_latch == LATCH)					// **** Latched Mode ****
									{
									latch = TRUE;
									Toggle_VFO_Lock(FALSE);					// Immediately display VFO Toggle message
									while(_VFO) warning_beep();				// Immediately start warning beep and wait for button release
									synch_beep();

									do	{
										warning_beep();
										Toggle_VFO_Lock(TRUE);				// PWR button is used to toggle the lock

										if(_VFO)							// Latched mode can only be released with VFO button
											{
											latch = FALSE;					// Release the page hold latch
											beep_number = 2;
											}
										} while(latch);
									}
								else									// **** Push & Hold Mode ****
									{
									beep(HZ466_85, cal.calval.beep_len * 5);// Long beep for Push & Hold mode
									reset_encoder();						// Avoids VFO change if VFO knob rotated whilst initially holding button
									while(_VFO) Toggle_VFO_Lock(TRUE);
									}
								}
							else								// ***** Simplex Mode *****
								{												// Equalise VFO frequency/mode
								int dir = RIGHT_ARROW;							// Temporary local variable

								beep(HZ466_85, cal.calval.beep_len * 5);		// Long beep for VFO A to B or B to A copy

								if(vfo_idx == VFO_B) dir = LEFT_ARROW;

								sprintf(lcdpbuff, copy_vfo, 'A', dir, mv[1], 'B');	// Format copy message
								equalise_VFO(vfo_idx);							// This function will format a locked message if necessary,
								display_line(LINE2, lcdpbuff);					// Display either the locked or copy message.
								}
							}
						else										// ***** VFO Multi-Memory Mode *****
							{
							if(hold_latch == LATCH)				// **** Latched Mode ****
								{
								latch = TRUE;
								VFO_Select(FALSE);

								while(_VFO) warning_beep();						// Immediately start warning beep
								synch_beep();

								do	{
									warning_beep();
									VFO_Select(TRUE);							// Select and either lock or unlock the desired VFO

									if(_VFO)
										{
										latch = FALSE;							// Release the page hold latch
										beep_number = 2;
										}
									} while(latch);
								}
							else								//  **** Push & Hold Mode ****
								{
								beep(HZ466_85, cal.calval.beep_len * 5);		// Long beep for Push & Hold mode
								reset_encoder();								// Avoids spurious VFO change if VFO knob rotated whilst initially holding button
								while(_VFO) VFO_Select(TRUE);					// Select and either lock or unlock the desired VFO
								}
							}
						}
					while(_VFO);								// Wait for VFO button release
					debounce();									// Button de-bounce and encoder reset
					}
				}
// The DISPLAY/CONFIG, MODE and FILTER buttons are operative in both the normal and user configuration modes, but not in the alarm mode.
// DISPLAY/CONFIG (SW1)
			if(_DISPLAY)
				{
				bl_on();
				button_debounce(_DISPLAY);

				if(button_count)				// ******* PRIMARY Function *******
					{
					if(lcd_mode == NORMAL_DISPLAY)			// Increment normal display pages
						increment_and_check(&sub_page0, LAST_PAGE);
					else									// Increment User Configuration pages
						increment_and_check(&sub_page1, MAX_SUB_PAGE1 + 1);

					beep_number = ((lcd_mode == NORMAL_DISPLAY && sub_page0) || (lcd_mode == CONFIG_DISPLAY && sub_page1)) ? 2 : 1;
					}
				else							// ****** SECONDARY Function ******
					{
					beep(HZ466_85, LONG_BEEP);				// Long beep for major page change
					lcd_mode++;

					if(lcd_mode > MAX_LCD_MODE)
						{
						RX_Bandwidth = y;			// Restore the previous RX filter display
						save_settings(0, 2);
						lcd_mode = NORMAL_DISPLAY;			// lcd_mode = 0
						snap_to_step();						// Adjust VFO to account for any change in the settings
						}
					else
						{
						y = RX_Bandwidth;			// Save the current selected filter
						display_screen(User_Menu, Configuration_Msg);
						}
					}
				while(_DISPLAY);							// Wait until button released
				debounce();									// Button de-bounce and encoder reset
				}
// MODE (SW5)
			if(_MODE)
				{
				bl_on();
				button_debounce(_MODE);

				if(button_count)				// ******* PRIMARY Function *******
					{
					if(lcd_mode == NORMAL_DISPLAY)					// Do not allow MODE changes in User Configuration.
						{
						if(sub_page0) dsp2_ctr = set_mode_blink();	// Initialise the mode blink counter if we are displaying a measurement page.

						increment_and_check(&eeprom.defval.mode[vfo_idx], 5);

						if(eeprom.defval.cw_annunciation) cw_status = MODE_STATUS;
						else beep_number = eeprom.defval.mode[vfo_idx];
						}
					}
				else							// ****** SECONDARY Function ******
					{
					reset_encoder();						// Fixes spurious page/memory change if VFO knob rotated whilst holding the button in Latched mode.
					mode_function();						// Display either the current VFO Memory Copy or User Configuration page.

					if(hold_latch == LATCH)					// Second Function = LATCHED Mode
						{
						latch = TRUE;
						while(_MODE) warning_beep();		// Immediately start the warning beep
						synch_beep();

						do	{
							warning_beep();
							mode_function();				// Select VFO Memory Copy or User Configuration page.

							if(PWR_SW || _MODE)
								{
								latch = FALSE;				// Release the page hold latch.
								beep_number = 2;
								}
							} while(latch);
						}
					else									// Second Function = PRESS&HOLD Mode
						{
						beep(HZ466_85, cal.calval.beep_len * 5);
						while(_MODE) mode_function();		// Select VFO Memory Copy or User Configuration page.
						}
					}
				wait_PWR_MODE_rls();						// Wait until button is released
				}
// FILTER (SW6)
// Only permit filter changes in receive mode and in the user configuration mode when displaying the filter bandwidth
			if(_FILTER)
				{
				bl_on();
				button_debounce(_FILTER);
// Do not permit storage of user frequency when in TX, service or setup modes.
				if(button_count)				// ******* PRIMARY Function *******
					{
					if(lcd_mode == NORMAL_DISPLAY)
						{
						if((eeprom.defval.mode[vfo_idx] == CWR) && (eeprom.defval.CW_CWR_Swap == ON))
							{										// If in CWR mode and CW/CWR Swap is On, go back to CW
							if(sub_page0) dsp2_ctr = set_mode_blink();// Initialise the mode blink counter if we are displaying a measurement page.

							eeprom.defval.mode[vfo_idx] = CW;		// Reset the mode to CW,

							if(eeprom.defval.cw_annunciation) cw_status = MODE_STATUS;
							else beep(HZ587_31, cal.calval.beep_len);// Indicate we have seen the button pushed,
							}
						else
							{
							if(sub_page0) dsp1_ctr = set_mode_blink();// Initialise the filter blink counter if we are displaying a measurement page.

							increment_and_check(&RX_Bandwidth, 2);

							if(eeprom.defval.cw_annunciation) cw_status = FILTER_STATUS;
							else beep(status_beep[RX_Bandwidth], cal.calval.beep_len);
							}
						}
					else if((lcd_mode == CONFIG_DISPLAY) && (sub_page1 == 1))
						{
						increment_and_check(&RX_Bandwidth, 3);
						beep_number = RX_Bandwidth;
						}
					}
				else							// ****** SECONDARY Function ******
					{
					if(lcd_mode == NORMAL_DISPLAY)
						{
						int freq = HZ698_45, time = cal.calval.beep_len;

						if(RBS_Mode == _DEFAULT) user_band_prompt = Invalid_Mode;			// If in the DEFAULT mode...
						else if(RBS_Mode == _MODE_A || RBS_Mode == _MODE_B)					// Or, if in Mode-A or Mode-B...
							{
							if(!band_in_use) user_band_prompt = out_of_band;
							else
								{
								eeprom.defval.vfo[band_in_use + 29] = eeprom.defval.vfo[vfo_idx];		// Save the current frequency,
								eeprom.defval.mode[band_in_use + 29] = eeprom.defval.mode[vfo_idx];		// and mode
								sprintf(lcdpbuff, save_to_band, band[band_in_use]);						// and prepare the prompt message
								user_band_prompt = lcdpbuff;
								changed_flag = TRUE;				// This will ensure that any changes are saved when we switch off
								freq = HZ466_85;
								time *= 5;

								if(RBS_Mode == _MODE_B) RBS_Flag = 2;						// Set the RBS temporary Mode-C state.
								}
							}
						else user_band_prompt = user_mem_locked;	// Otherwise, we must be in the LOCKED mode.

						display_line(LINE1, user_band_prompt);		// Display the RBS status message.
						beep(freq, time);
						}
					}
				wait_FILTER_rls(FALSE);								// Wait for FILTER button to be released
				debounce();											// Button debounce and encoder reset
				}

//			offset = (eeprom.defval.mode[vfo_idx] == CW) ? -eeprom.defval.cw_shift : (eeprom.defval.mode[vfo_idx] == CWR) ? eeprom.defval.cw_shift : 0;
// Although the previous line is the elegant way to do this, it actually takes more than 30 bytes of additional code! A.Ryan - 5B4AIY 09/JUL/12
			if(eeprom.defval.mode[vfo_idx] == CW) offset = eeprom.defval.cw_shift;		// Take account of either the CW offset,
			if(eeprom.defval.mode[vfo_idx] == CWR) offset = -eeprom.defval.cw_shift;	// or the CWR offset,
			if(RIT_On_Off) offset += (long)rit;						// finally, take account of RIT offset, if enabled.
			}
		else					// ****************** TRANSMIT ******************
			{
			squelch_on = OFF;
			start_scaf_clock();										// SCAF clock ON in Transmit

			if(eeprom.defval.mode[vfo_idx] < CW)					// SSB TX audio filter
				set_scaf_clock(eeprom.defval.scaf_filters[TX_FILTER]);	// Set TX filter
			else
				set_scaf_clock(SIDE_TONE_SCAF);						// Set filter for side tone when CW or Tune

			swr = get_pwr();										// Convert forward & reverse A/D RF output power channels, and calculate SWR.

// If SWR > trip limit, and SWR delay has timed out, and the SWR alarm flag has not been set
			if((swr > cal.calval.swr_trip) && (!swr_al_dly) && !(alarm_flag & 0x02))
				alarm_flag |= 0x02;									// Set SWR alarm flag
			}
// Select & calculate frequency in use. (Moved here to avoid calling send_packet_to_74hc595() twice when changing bands.)
		freq_in_use = eeprom.defval.vfo[vfo_idx];					// Load frequency from selected VFO
// Load synthesiser with new frequency
		dds_load(freq_in_use + offset);
// Build main board & RF filter board (Only All-Band version) 74HC595 I/O latch data & send it
		send_packet_to_74hc595();
// Announce change of status
		if(beep_number != MINUS_ONE)								// If there is a status change,
			{
			beep(status_beep[beep_number], cal.calval.beep_len);	// sound the new status.
			beep_number = MINUS_ONE;								// Reset the change of status flag.
			}
// Run UART1 Serial Interface functions
		RS_232_Mode();
// Run UART2 / AUX connector serial interface functions. (Voice Memory Control)
		uart2_ext_kb();
// Test shut down
		if(PWR_SW)
			{
			bl_on();												// Set LCD back light
			power_off();											// Go to cancel alarms/shut down/toggle VFO Lock
			}
		} while(TRUE);	// End of infinite DO-loop
	}	// End main

